Sub2ApiAdminApiKey class final

Admin API Key used only by Sub2ApiOpsClient-style automation entrypoints. Stringification is always redacted.

Constructors

Sub2ApiAdminApiKey(String value)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reveal() → String
Explicitly reveals the secret for persistence or an authorized operation.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited