Sub2ApiChannelMonitor class final

One current-user read-only v1 monitor overview.

Constructors

Sub2ApiChannelMonitor({required int id, required String name, required String provider, required String groupName, required String primaryModel, required String primaryStatus, int? primaryLatencyMs, int? primaryPingLatencyMs, required Sub2ApiDecimal availability7d, required List<Sub2ApiMonitorExtraModel> extraModels, required List<Sub2ApiMonitorTimelinePoint> timeline, Sub2ApiMonitorQuotaSnapshot? latestQuota})
const

Properties

availability7d → Sub2ApiDecimal
final
extraModels → List<Sub2ApiMonitorExtraModel>
final
groupName → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
latestQuota → Sub2ApiMonitorQuotaSnapshot?
final
name → String
final
primaryLatencyMs → int?
final
primaryModel → String
final
primaryPingLatencyMs → int?
final
primaryStatus → String
final
provider → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeline → List<Sub2ApiMonitorTimelinePoint>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited