Sub2ApiKeySummary class abstract

A non-secret snapshot of an API key.

Available extensions
Annotations
  • @freezed

Constructors

Sub2ApiKeySummary({required int id, required int userId, required String name, required String status, required List<String> ipWhitelist, required List<String> ipBlacklist, required Sub2ApiDecimal quota, required Sub2ApiDecimal quotaUsed, required int currentConcurrency, required Sub2ApiKeyUsageWindow fiveHourWindow, required Sub2ApiKeyUsageWindow oneDayWindow, required Sub2ApiKeyUsageWindow sevenDayWindow, required DateTime createdAt, required DateTime updatedAt, int? groupId, DateTime? expiresAt, DateTime? lastUsedAt, String? lastUsedIp})
Creates an immutable API key summary without its secret value.
const
factory

Properties

copyWith → $Sub2ApiKeySummaryCopyWith<Sub2ApiKeySummary>
Create a copy of Sub2ApiKeySummary with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
no setterinherited
currentConcurrency → int
no setterinherited
expiresAt → DateTime?
no setterinherited
fiveHourWindow → Sub2ApiKeyUsageWindow
no setterinherited
groupId → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setterinherited
ipBlacklist → List<String>
no setterinherited
ipWhitelist → List<String>
no setterinherited
lastUsedAt → DateTime?
no setterinherited
lastUsedIp → String?
no setterinherited
name → String
no setterinherited
oneDayWindow → Sub2ApiKeyUsageWindow
no setterinherited
quota → Sub2ApiDecimal
no setterinherited
quotaUsed → Sub2ApiDecimal
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sevenDayWindow → Sub2ApiKeyUsageWindow
no setterinherited
status → String
no setterinherited
updatedAt → DateTime
no setterinherited
userId → int
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Sub2ApiKeySummary value)) → TResult

Available on Sub2ApiKeySummary, provided by the Sub2ApiKeySummaryPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Sub2ApiKeySummary value)?) → TResult?

Available on Sub2ApiKeySummary, provided by the Sub2ApiKeySummaryPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Sub2ApiKeySummary value)?, {required TResult orElse()}) → TResult

Available on Sub2ApiKeySummary, provided by the Sub2ApiKeySummaryPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int id, int userId, String name, String status, List<String> ipWhitelist, List<String> ipBlacklist, Sub2ApiDecimal quota, Sub2ApiDecimal quotaUsed, int currentConcurrency, Sub2ApiKeyUsageWindow fiveHourWindow, Sub2ApiKeyUsageWindow oneDayWindow, Sub2ApiKeyUsageWindow sevenDayWindow, DateTime createdAt, DateTime updatedAt, int? groupId, DateTime? expiresAt, DateTime? lastUsedAt, String? lastUsedIp)?, {required TResult orElse()}) → TResult

Available on Sub2ApiKeySummary, provided by the Sub2ApiKeySummaryPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int id, int userId, String name, String status, List<String> ipWhitelist, List<String> ipBlacklist, Sub2ApiDecimal quota, Sub2ApiDecimal quotaUsed, int currentConcurrency, Sub2ApiKeyUsageWindow fiveHourWindow, Sub2ApiKeyUsageWindow oneDayWindow, Sub2ApiKeyUsageWindow sevenDayWindow, DateTime createdAt, DateTime updatedAt, int? groupId, DateTime? expiresAt, DateTime? lastUsedAt, String? lastUsedIp)) → TResult

Available on Sub2ApiKeySummary, provided by the Sub2ApiKeySummaryPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int id, int userId, String name, String status, List<String> ipWhitelist, List<String> ipBlacklist, Sub2ApiDecimal quota, Sub2ApiDecimal quotaUsed, int currentConcurrency, Sub2ApiKeyUsageWindow fiveHourWindow, Sub2ApiKeyUsageWindow oneDayWindow, Sub2ApiKeyUsageWindow sevenDayWindow, DateTime createdAt, DateTime updatedAt, int? groupId, DateTime? expiresAt, DateTime? lastUsedAt, String? lastUsedIp)?) → TResult?

Available on Sub2ApiKeySummary, provided by the Sub2ApiKeySummaryPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited