Sub2ApiMonitorConfig class final

V2 runtime configuration returned in snapshots.

Constructors

Sub2ApiMonitorConfig({required int version, required bool enabled, required int refreshIntervalSeconds, required List<Sub2ApiMonitorPlatformConfig> platforms, required List<int> groupIds, required Sub2ApiMonitorThresholds healthThresholds, required List<String> ignoredErrorCategories, required DateTime updatedAt, int? updatedBy})
const

Properties

enabled → bool
final
groupIds → List<int>
final
hashCode → int
The hash code for this object.
no setterinherited
healthThresholds → Sub2ApiMonitorThresholds
final
ignoredErrorCategories → List<String>
final
platforms → List<Sub2ApiMonitorPlatformConfig>
final
refreshIntervalSeconds → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → DateTime
final
updatedBy → int?
final
version → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited