Sub2ApiMonitorDimension class final

String-valued V2 platform or model dimension.

Constructors

Sub2ApiMonitorDimension({required String value, required String label, required String platform, required int requestCount})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
label → String
final
platform → String
final
requestCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited