Sub2ApiPasskeyRegistrationChallenge class abstract

Server state and typed options required to create a passkey credential.

Available extensions
Annotations
  • @freezed

Constructors

Sub2ApiPasskeyRegistrationChallenge({required Sub2ApiPasskeySessionToken sessionToken, required Sub2ApiWebAuthnCreationOptions options, String? mediation})
const
factory

Properties

copyWith → $Sub2ApiPasskeyRegistrationChallengeCopyWith<Sub2ApiPasskeyRegistrationChallenge>
Create a copy of Sub2ApiPasskeyRegistrationChallenge with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
mediation → String?
no setterinherited
options → Sub2ApiWebAuthnCreationOptions
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionToken → Sub2ApiPasskeySessionToken
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Sub2ApiPasskeyRegistrationChallenge value)) → TResult

Available on Sub2ApiPasskeyRegistrationChallenge, provided by the Sub2ApiPasskeyRegistrationChallengePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Sub2ApiPasskeyRegistrationChallenge value)?) → TResult?

Available on Sub2ApiPasskeyRegistrationChallenge, provided by the Sub2ApiPasskeyRegistrationChallengePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Sub2ApiPasskeyRegistrationChallenge value)?, {required TResult orElse()}) → TResult

Available on Sub2ApiPasskeyRegistrationChallenge, provided by the Sub2ApiPasskeyRegistrationChallengePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(Sub2ApiPasskeySessionToken sessionToken, Sub2ApiWebAuthnCreationOptions options, String? mediation)?, {required TResult orElse()}) → TResult

Available on Sub2ApiPasskeyRegistrationChallenge, provided by the Sub2ApiPasskeyRegistrationChallengePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(Sub2ApiPasskeySessionToken sessionToken, Sub2ApiWebAuthnCreationOptions options, String? mediation)) → TResult

Available on Sub2ApiPasskeyRegistrationChallenge, provided by the Sub2ApiPasskeyRegistrationChallengePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(Sub2ApiPasskeySessionToken sessionToken, Sub2ApiWebAuthnCreationOptions options, String? mediation)?) → TResult?

Available on Sub2ApiPasskeyRegistrationChallenge, provided by the Sub2ApiPasskeyRegistrationChallengePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited