Sub2ApiUserClient class abstract interface

Provides the authenticated user profile operations supported by v0.1.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

changePassword(Sub2ApiChangePasswordRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future<void>
Changes the current user's password.
getAffiliate({Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAffiliateDetail>
Reads the current user's affiliate and invitee facts.
getProfile({Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiUserProfile>
Reads the current authenticated user's profile.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
transferAffiliateQuota({Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAffiliateTransfer>
Transfers all available affiliate quota into the current balance.
updateProfile(Sub2ApiUpdateUserProfileRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiUserProfile>
Updates the supplied fields of the current authenticated user's profile.

Operators

operator ==(Object other) → bool
The equality operator.
inherited