Sub2ApiAdminAcceptComplianceRequest class final

Constructors

Sub2ApiAdminAcceptComplianceRequest({required String phrase, required Sub2ApiAdminComplianceLanguage language})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
language → Sub2ApiAdminComplianceLanguage
final
phrase → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited