Sub2ApiAdminAccountBatchMaintenanceResult class final

Constructors

Sub2ApiAdminAccountBatchMaintenanceResult({required int total, required int success, required int failed, required List<Sub2ApiAdminAccountBatchError> errors, required List<Sub2ApiAdminAccountBatchWarning> warnings})

Properties

errors → List<Sub2ApiAdminAccountBatchError>
final
failed → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → int
final
total → int
final
warnings → List<Sub2ApiAdminAccountBatchWarning>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited