Sub2ApiAdminAccountBatchUsage class final

Constructors

Sub2ApiAdminAccountBatchUsage({required Map<int, Sub2ApiAdminAccountUsage> usage, required Map<int, String> errors})

Properties

errors → Map<int, String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usage → Map<int, Sub2ApiAdminAccountUsage>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited