Sub2ApiAdminAccountDataExportQuery class final

Selection and ordering for an authorized account-data export.

Constructors

Sub2ApiAdminAccountDataExportQuery({Sub2ApiAdminBulkAccountSelector selector = const Sub2ApiAdminBulkAccountSelector.allAccounts(), bool includeProxies = true, Sub2ApiAdminAccountSort sortBy = Sub2ApiAdminAccountSort.name, bool sortDescending = false})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
includeProxies → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selector → Sub2ApiAdminBulkAccountSelector
final
sortBy → Sub2ApiAdminAccountSort
final
sortDescending → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited