Sub2ApiAdminAccountDataImportRequest class final

Idempotent import of an opaque credential-bearing account-data archive.

Constructors

Sub2ApiAdminAccountDataImportRequest({required String idempotencyKey, required Sub2ApiAdminAccountDataArchive archive, bool? skipDefaultGroupBind})
const

Properties

archive → Sub2ApiAdminAccountDataArchive
final
hashCode → int
The hash code for this object.
no setterinherited
idempotencyKey → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipDefaultGroupBind → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited