Sub2ApiAdminAccountEndpointStats class final

Constructors

Sub2ApiAdminAccountEndpointStats({required String endpoint, required int requests, required int totalTokens, required Sub2ApiDecimal cost, required Sub2ApiDecimal actualCost})
const

Properties

actualCost → Sub2ApiDecimal
final
cost → Sub2ApiDecimal
final
endpoint → String
final
hashCode → int
The hash code for this object.
no setterinherited
requests → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalTokens → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited