Sub2ApiAdminAccountListQuery class final
Constructors
- Sub2ApiAdminAccountListQuery({int? page, int? pageSize, Sub2ApiAdminAccountPlatform? platform, Sub2ApiAdminAccountType? type, Sub2ApiAdminAccountStatus? status, String? search, int? groupId, bool ungrouped = false, String? privacyMode, Sub2ApiAdminAccountSort sortBy = Sub2ApiAdminAccountSort.name, bool sortDescending = false, bool lite = false, bool includeSchedulerScore = false})
-
const
Properties
- groupId → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeSchedulerScore → bool
-
final
- lite → bool
-
final
- page → int?
-
final
- pageSize → int?
-
final
- platform → Sub2ApiAdminAccountPlatform?
-
final
- privacyMode → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- search → String?
-
final
- sortBy → Sub2ApiAdminAccountSort
-
final
- sortDescending → bool
-
final
- status → Sub2ApiAdminAccountStatus?
-
final
- type → Sub2ApiAdminAccountType?
-
final
- ungrouped → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited