Sub2ApiAdminAccountProxy class final

Constructors

Sub2ApiAdminAccountProxy({required int id, required String name, required String protocol, required String host, required int port, required String username, required String status, required DateTime createdAt, required DateTime updatedAt, required String fallbackMode, required int expiryWarningDays, DateTime? expiresAt, int? backupProxyId})
const

Properties

backupProxyId → int?
final
createdAt → DateTime
final
expiresAt → DateTime?
final
expiryWarningDays → int
final
fallbackMode → String
final
hashCode → int
The hash code for this object.
no setterinherited
host → String
final
id → int
final
name → String
final
port → int
final
protocol → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
final
updatedAt → DateTime
final
username → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited