Sub2ApiAdminAccountSchedulerScore class final

Constructors

Sub2ApiAdminAccountSchedulerScore({required Sub2ApiDecimal baseScore, required Sub2ApiDecimal stickyScore, required bool stickyScoreInfinity, required bool stickyWeightedEnabled})
const

Properties

baseScore → Sub2ApiDecimal
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickyScore → Sub2ApiDecimal
final
stickyScoreInfinity → bool
final
stickyWeightedEnabled → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited