Sub2ApiAdminAccountStats class final

Constructors

Sub2ApiAdminAccountStats({required List<Sub2ApiAdminAccountUsageHistory> history, required Sub2ApiAdminAccountUsageSummary summary, required List<Sub2ApiAdminAccountModelStats> models, required List<Sub2ApiAdminAccountEndpointStats> endpoints, required List<Sub2ApiAdminAccountEndpointStats> upstreamEndpoints})

Properties

endpoints → List<Sub2ApiAdminAccountEndpointStats>
final
hashCode → int
The hash code for this object.
no setterinherited
history → List<Sub2ApiAdminAccountUsageHistory>
final
models → List<Sub2ApiAdminAccountModelStats>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
summary → Sub2ApiAdminAccountUsageSummary
final
upstreamEndpoints → List<Sub2ApiAdminAccountEndpointStats>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited