Sub2ApiAdminAccountTempUnschedulableState class final

Constructors

Sub2ApiAdminAccountTempUnschedulableState({required DateTime until, required DateTime triggeredAt, required int statusCode, required String matchedKeyword, required int ruleIndex, required String errorMessage, required int triggerCount, required int triggerThreshold, required int triggerWindowMinutes})
const

Properties

errorMessage → String
final
hashCode → int
The hash code for this object.
no setterinherited
matchedKeyword → String
final
ruleIndex → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
final
triggerCount → int
final
triggeredAt → DateTime
final
triggerThreshold → int
final
triggerWindowMinutes → int
final
until → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited