Sub2ApiAdminAccountTestEvent class final

Constructors

Sub2ApiAdminAccountTestEvent({required Sub2ApiAdminAccountTestEventType type, String? text, String? model, Uri? mediaUrl, String? mimeType, bool? success, String? error})
const

Properties

error → String?
final
hashCode → int
The hash code for this object.
no setterinherited
mediaUrl → Uri?
final
mimeType → String?
final
model → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool?
final
text → String?
final
type → Sub2ApiAdminAccountTestEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited