Sub2ApiAdminAccountTestRequest class final
Constructors
- Sub2ApiAdminAccountTestRequest({String? modelId, String? prompt, Sub2ApiAdminAccountTestMode mode = Sub2ApiAdminAccountTestMode.defaultMode, String? imageDataUrl, String? audioDataUrl})
-
const
Properties
- audioDataUrl → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageDataUrl → String?
-
final
- mode → Sub2ApiAdminAccountTestMode
-
final
- modelId → String?
-
final
- prompt → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited