Sub2ApiAdminAccountTodayStats class final

Constructors

Sub2ApiAdminAccountTodayStats({required int requests, required int tokens, required Sub2ApiDecimal cost, required Sub2ApiDecimal standardCost, required Sub2ApiDecimal userCost})
const

Properties

cost → Sub2ApiDecimal
final
hashCode → int
The hash code for this object.
no setterinherited
requests → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
standardCost → Sub2ApiDecimal
final
tokens → int
final
userCost → Sub2ApiDecimal
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited