Sub2ApiAdminAccountUsageHistory class final
Constructors
- Sub2ApiAdminAccountUsageHistory({required String date, required String label, required int requests, required int tokens, required Sub2ApiDecimal cost, required Sub2ApiDecimal actualCost, required Sub2ApiDecimal userCost})
-
const
Properties
- actualCost → Sub2ApiDecimal
-
final
- cost → Sub2ApiDecimal
-
final
- date → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
final
- requests → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokens → int
-
final
- userCost → Sub2ApiDecimal
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited