Sub2ApiAdminAffiliateInviteRecord class final

Constructors

Sub2ApiAdminAffiliateInviteRecord({required int inviterId, required String inviterEmail, required String inviterUsername, required int inviteeId, required String inviteeEmail, required String inviteeUsername, required String affiliateCode, required Sub2ApiDecimal totalRebate, required DateTime createdAt})
const

Properties

affiliateCode → String
final
createdAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
inviteeEmail → String
final
inviteeId → int
final
inviteeUsername → String
final
inviterEmail → String
final
inviterId → int
final
inviterUsername → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalRebate → Sub2ApiDecimal
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited