Sub2ApiAdminAffiliateRebateRecord class final
Constructors
- Sub2ApiAdminAffiliateRebateRecord({required int orderId, required String outTradeNo, required int inviterId, required String inviterEmail, required String inviterUsername, required int inviteeId, required String inviteeEmail, required String inviteeUsername, required Sub2ApiDecimal orderAmount, required Sub2ApiDecimal payAmount, required Sub2ApiDecimal rebateAmount, required String paymentType, required String orderStatus, required DateTime createdAt})
-
const
Properties
- createdAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inviteeEmail → String
-
final
- inviteeId → int
-
final
- inviteeUsername → String
-
final
- inviterEmail → String
-
final
- inviterId → int
-
final
- inviterUsername → String
-
final
- orderAmount → Sub2ApiDecimal
-
final
- orderId → int
-
final
- orderStatus → String
-
final
- outTradeNo → String
-
final
- payAmount → Sub2ApiDecimal
-
final
- paymentType → String
-
final
- rebateAmount → Sub2ApiDecimal
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited