Sub2ApiAdminAffiliateRecordSort enum
Values
- inviter → const Sub2ApiAdminAffiliateRecordSort
- invitee → const Sub2ApiAdminAffiliateRecordSort
- affiliateCode → const Sub2ApiAdminAffiliateRecordSort
- totalRebate → const Sub2ApiAdminAffiliateRecordSort
- order → const Sub2ApiAdminAffiliateRecordSort
- orderAmount → const Sub2ApiAdminAffiliateRecordSort
- payAmount → const Sub2ApiAdminAffiliateRecordSort
- rebateAmount → const Sub2ApiAdminAffiliateRecordSort
- paymentType → const Sub2ApiAdminAffiliateRecordSort
- orderStatus → const Sub2ApiAdminAffiliateRecordSort
- user → const Sub2ApiAdminAffiliateRecordSort
- amount → const Sub2ApiAdminAffiliateRecordSort
- createdAt → const Sub2ApiAdminAffiliateRecordSort
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
Sub2ApiAdminAffiliateRecordSort> - A constant List of the values in this enum, in order of their declaration.