Sub2ApiAdminAnnouncement class final
Constructors
- Sub2ApiAdminAnnouncement({required int id, required String title, required String content, required Sub2ApiAdminAnnouncementStatus status, required Sub2ApiAdminAnnouncementNotifyMode notifyMode, required Sub2ApiAdminAnnouncementTargeting targeting, required DateTime? startsAt, required DateTime? endsAt, required int? createdBy, required int? updatedBy, required DateTime createdAt, required DateTime updatedAt})
-
const
Properties
- content → String
-
final
- createdAt → DateTime
-
final
- createdBy → int?
-
final
- endsAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- notifyMode → Sub2ApiAdminAnnouncementNotifyMode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startsAt → DateTime?
-
final
- status → Sub2ApiAdminAnnouncementStatus
-
final
- targeting → Sub2ApiAdminAnnouncementTargeting
-
final
- title → String
-
final
- updatedAt → DateTime
-
final
- updatedBy → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited