Sub2ApiAdminAnnouncementReadStatus class final

Constructors

Sub2ApiAdminAnnouncementReadStatus({required int userId, required String email, required String username, required Sub2ApiDecimal balance, required bool eligible, required DateTime? readAt})
const

Properties

balance → Sub2ApiDecimal
final
eligible → bool
final
email → String
final
hashCode → int
The hash code for this object.
no setterinherited
readAt → DateTime?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
final
username → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited