Sub2ApiAdminAntigravityExchangeCodeRequest class final
Constructors
- Sub2ApiAdminAntigravityExchangeCodeRequest({required Sub2ApiAdminOAuthSessionId sessionId, required Sub2ApiAdminOAuthState state, required Sub2ApiOAuthAuthorizationCode code, int? proxyId})
-
const
Properties
- code → Sub2ApiOAuthAuthorizationCode
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- proxyId → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → Sub2ApiAdminOAuthSessionId
-
final
- state → Sub2ApiAdminOAuthState
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited