Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
exchangeCode(
Sub2ApiAdminAntigravityExchangeCodeRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminAntigravityTokenInfo> -
generateAuthorization(
{int? proxyId, Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminAntigravityOAuthAuthorization> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validateRefreshToken(
Sub2ApiRefreshToken refreshToken, {int? proxyId, Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminAntigravityTokenInfo>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited