Sub2ApiAdminAntigravityTokenInfo class final

Constructors

Sub2ApiAdminAntigravityTokenInfo({required Sub2ApiAccessToken accessToken, required Sub2ApiRefreshToken? refreshToken, required Duration expiresIn, required DateTime expiresAt, required String tokenType, required String email, required String projectId})
const

Properties

accessToken → Sub2ApiAccessToken
final
email → String
final
expiresAt → DateTime
final
expiresIn → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
projectId → String
final
refreshToken → Sub2ApiRefreshToken?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenType → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited