Sub2ApiAdminApiKeyStatus class final

Constructors

Sub2ApiAdminApiKeyStatus({required bool exists, Sub2ApiAdminMaskedCredential? maskedKey})
const

Properties

exists → bool
final
hashCode → int
The hash code for this object.
no setterinherited
maskedKey → Sub2ApiAdminMaskedCredential?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited