Sub2ApiAdminApplyOAuthCredentialsRequest class final
Constructors
- Sub2ApiAdminApplyOAuthCredentialsRequest({required Sub2ApiAdminAccountType type, required Sub2ApiAdminCredentialSet credentials, Sub2ApiAdminJsonObject extra = const Sub2ApiAdminJsonObject({})})
-
const
Properties
- credentials → Sub2ApiAdminCredentialSet
-
final
- extra → Sub2ApiAdminJsonObject
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Sub2ApiAdminAccountType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited