Sub2ApiAdminAssignSubscriptionRequest class final

Constructors

Sub2ApiAdminAssignSubscriptionRequest({required int userId, required int groupId, int validityDays = 0, String notes = ''})
const

Properties

groupId → int
final
hashCode → int
The hash code for this object.
no setterinherited
notes → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
final
validityDays → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited