Sub2ApiAdminAssociatedMonitor class final

Constructors

Sub2ApiAdminAssociatedMonitor({required int id, required String name, required Sub2ApiAdminMonitorTemplateProvider provider, required Sub2ApiAdminMonitorTemplateApiMode apiMode, required bool enabled})
const

Properties

apiMode → Sub2ApiAdminMonitorTemplateApiMode
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
name → String
final
provider → Sub2ApiAdminMonitorTemplateProvider
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited