Sub2ApiAdminAuditLogMetadata class final

Typed metadata currently emitted for an audit-log clear trace.

Constructors

Sub2ApiAdminAuditLogMetadata({int? deletedRows})
const

Properties

deletedRows → int?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited