Sub2ApiAdminAuditLogQuery class final

Constructors

Sub2ApiAdminAuditLogQuery({int? page, int? pageSize, DateTime? startTime, DateTime? endTime, int? actorUserId, String? actorEmail, String? authMethod, String? action, String? method, String? clientIp, bool? success, String? search})
const

Properties

action → String?
final
actorEmail → String?
final
actorUserId → int?
final
authMethod → String?
final
clientIp → String?
final
endTime → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
method → String?
final
page → int?
final
pageSize → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
final
startTime → DateTime?
final
success → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited