Sub2ApiAdminAuditLogsClient class abstract interface

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear(Sub2ApiVerificationCode totpCode, {Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminClearAuditLogsResult>
Clears all audit logs after a fresh server-side TOTP verification.
get(int id, {Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminAuditLog>
list({Sub2ApiAdminAuditLogQuery query = const Sub2ApiAdminAuditLogQuery(), Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminAuditLogPage>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited