Sub2ApiAdminBackupConnectionResult class final
Constructors
- Sub2ApiAdminBackupConnectionResult({required bool ok, required Sub2ApiAdminOpsErrorContent message})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → Sub2ApiAdminOpsErrorContent
-
final
- ok → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited