Sub2ApiAdminBackupS3ConfigInput class final

Constructors

Sub2ApiAdminBackupS3ConfigInput({Uri? endpoint, required String region, required String bucket, required Sub2ApiAdminBackupAccessKeyId accessKeyId, Sub2ApiAdminBackupSecretAccessKey? secretAccessKey, required String prefix, required bool forcePathStyle})
const

Properties

accessKeyId → Sub2ApiAdminBackupAccessKeyId
final
bucket → String
final
endpoint → Uri?
final
forcePathStyle → bool
final
hashCode → int
The hash code for this object.
no setterinherited
prefix → String
final
region → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretAccessKey → Sub2ApiAdminBackupSecretAccessKey?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited