Sub2ApiAdminBalanceHistoryRecord class final
One balance, concurrency, affiliate, or subscription history record.
Constructors
- Sub2ApiAdminBalanceHistoryRecord({required int id, required String code, required String type, required Sub2ApiDecimal value, required String status, required DateTime createdAt, required int validityDays, required String notes, int? usedBy, DateTime? usedAt, DateTime? expiresAt, int? groupId, Sub2ApiAdminBalanceHistoryUser? user, Sub2ApiAdminBalanceHistoryGroup? group})
-
const
Properties
- code → String
-
final
- createdAt → DateTime
-
final
- expiresAt → DateTime?
-
final
- group → Sub2ApiAdminBalanceHistoryGroup?
-
final
- groupId → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- notes → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
final
- type → String
-
final
- usedAt → DateTime?
-
final
- usedBy → int?
-
final
- user → Sub2ApiAdminBalanceHistoryUser?
-
final
- validityDays → int
-
final
- value → Sub2ApiDecimal
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited