Sub2ApiAdminBalanceHistoryUser class final

Compact user relation embedded by a balance-history record.

Constructors

Sub2ApiAdminBalanceHistoryUser({required int id, required String email})
const

Properties

email → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited