Sub2ApiAdminBatchCreateAccountsRequest class final

Constructors

Sub2ApiAdminBatchCreateAccountsRequest({required String idempotencyKey, required List<Sub2ApiAdminAccountCreateInput> accounts})

Properties

accounts → List<Sub2ApiAdminAccountCreateInput>
final
hashCode → int
The hash code for this object.
no setterinherited
idempotencyKey → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited