Sub2ApiAdminBatchCreateAccountsResult class final

Constructors

Sub2ApiAdminBatchCreateAccountsResult({required int success, required int failed, required List<Sub2ApiAdminBatchCreateAccountItem> results})

Properties

failed → int
final
hashCode → int
The hash code for this object.
no setterinherited
results → List<Sub2ApiAdminBatchCreateAccountItem>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited