Sub2ApiAdminBatchLimitsRequest class abstract

Request to overwrite concurrency and/or RPM limits in one batch.

Available extensions
Annotations
  • @freezed

Constructors

Sub2ApiAdminBatchLimitsRequest({@Default.new(<int>[]) List<int> userIds, @Default.new(false) bool all, int? concurrency, int? rpmLimit})
const
factory

Properties

all → bool
no setterinherited
concurrency → int?
no setterinherited
copyWith → $Sub2ApiAdminBatchLimitsRequestCopyWith<Sub2ApiAdminBatchLimitsRequest>
Create a copy of Sub2ApiAdminBatchLimitsRequest with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
rpmLimit → int?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userIds → List<int>
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Sub2ApiAdminBatchLimitsRequest value)) → TResult

Available on Sub2ApiAdminBatchLimitsRequest, provided by the Sub2ApiAdminBatchLimitsRequestPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Sub2ApiAdminBatchLimitsRequest value)?) → TResult?

Available on Sub2ApiAdminBatchLimitsRequest, provided by the Sub2ApiAdminBatchLimitsRequestPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Sub2ApiAdminBatchLimitsRequest value)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminBatchLimitsRequest, provided by the Sub2ApiAdminBatchLimitsRequestPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<int> userIds, bool all, int? concurrency, int? rpmLimit)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminBatchLimitsRequest, provided by the Sub2ApiAdminBatchLimitsRequestPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(List<int> userIds, bool all, int? concurrency, int? rpmLimit)) → TResult

Available on Sub2ApiAdminBatchLimitsRequest, provided by the Sub2ApiAdminBatchLimitsRequestPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<int> userIds, bool all, int? concurrency, int? rpmLimit)?) → TResult?

Available on Sub2ApiAdminBatchLimitsRequest, provided by the Sub2ApiAdminBatchLimitsRequestPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited