Sub2ApiAdminBatchUpdateRedeemCodesRequest class final

Constructors

Sub2ApiAdminBatchUpdateRedeemCodesRequest({required List<int> ids, Sub2ApiAdminRedeemCodeStatus? status, DateTime? expiresAt, bool clearExpiresAt = false, String? notes, int? groupId, bool clearGroupId = false})

Properties

clearExpiresAt → bool
final
clearGroupId → bool
final
expiresAt → DateTime?
final
groupId → int?
final
hashCode → int
The hash code for this object.
no setterinherited
ids → List<int>
final
notes → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → Sub2ApiAdminRedeemCodeStatus?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited