Sub2ApiAdminBatchUserUsageStats class abstract

Current-day and cumulative usage for one user.

Available extensions
Annotations
  • @freezed

Constructors

Sub2ApiAdminBatchUserUsageStats({required int userId, required Sub2ApiDecimal todayActualCost, required Sub2ApiDecimal totalActualCost, List<Sub2ApiAdminPlatformUsage>? byPlatform})
const
factory

Properties

byPlatform → List<Sub2ApiAdminPlatformUsage>?
no setterinherited
copyWith → $Sub2ApiAdminBatchUserUsageStatsCopyWith<Sub2ApiAdminBatchUserUsageStats>
Create a copy of Sub2ApiAdminBatchUserUsageStats with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
todayActualCost → Sub2ApiDecimal
no setterinherited
totalActualCost → Sub2ApiDecimal
no setterinherited
userId → int
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Sub2ApiAdminBatchUserUsageStats value)) → TResult

Available on Sub2ApiAdminBatchUserUsageStats, provided by the Sub2ApiAdminBatchUserUsageStatsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Sub2ApiAdminBatchUserUsageStats value)?) → TResult?

Available on Sub2ApiAdminBatchUserUsageStats, provided by the Sub2ApiAdminBatchUserUsageStatsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Sub2ApiAdminBatchUserUsageStats value)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminBatchUserUsageStats, provided by the Sub2ApiAdminBatchUserUsageStatsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int userId, Sub2ApiDecimal todayActualCost, Sub2ApiDecimal totalActualCost, List<Sub2ApiAdminPlatformUsage>? byPlatform)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminBatchUserUsageStats, provided by the Sub2ApiAdminBatchUserUsageStatsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int userId, Sub2ApiDecimal todayActualCost, Sub2ApiDecimal totalActualCost, List<Sub2ApiAdminPlatformUsage>? byPlatform)) → TResult

Available on Sub2ApiAdminBatchUserUsageStats, provided by the Sub2ApiAdminBatchUserUsageStatsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int userId, Sub2ApiDecimal todayActualCost, Sub2ApiDecimal totalActualCost, List<Sub2ApiAdminPlatformUsage>? byPlatform)?) → TResult?

Available on Sub2ApiAdminBatchUserUsageStats, provided by the Sub2ApiAdminBatchUserUsageStatsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited