Sub2ApiAdminBetaPolicyRule class final

Constructors

Sub2ApiAdminBetaPolicyRule({required String betaToken, required Sub2ApiAdminBetaPolicyAction action, required Sub2ApiAdminBetaPolicyScope scope, String errorMessage = '', List<String> modelWhitelist = const <String>[], Sub2ApiAdminBetaPolicyAction? fallbackAction, String fallbackErrorMessage = ''})

Properties

action → Sub2ApiAdminBetaPolicyAction
final
betaToken → String
final
errorMessage → String
final
fallbackAction → Sub2ApiAdminBetaPolicyAction?
final
fallbackErrorMessage → String
final
hashCode → int
The hash code for this object.
no setterinherited
modelWhitelist → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → Sub2ApiAdminBetaPolicyScope
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited