Sub2ApiAdminBetaPolicySettings class final
Constructors
-
Sub2ApiAdminBetaPolicySettings({required List<
Sub2ApiAdminBetaPolicyRule> rules})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
rules
→ List<
Sub2ApiAdminBetaPolicyRule> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited