Sub2ApiAdminBindIdentityRequest class final
Request to bind a canonical authentication identity to a user.
Constructors
- Sub2ApiAdminBindIdentityRequest({required String providerType, required String providerKey, required String providerSubject, String? issuer, Sub2ApiAdminJsonObject? metadata, Sub2ApiAdminBindIdentityChannelRequest? channel})
-
const
Properties
- channel → Sub2ApiAdminBindIdentityChannelRequest?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- issuer → String?
-
final
- metadata → Sub2ApiAdminJsonObject?
-
final
- providerKey → String
-
final
- providerSubject → String
-
final
- providerType → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited