Sub2ApiAdminBoundIdentity class final

Canonical identity returned after a manual Admin binding.

Constructors

Sub2ApiAdminBoundIdentity({required int userId, required String providerType, required String providerKey, required String providerSubject, required Sub2ApiAdminJsonObject metadata, required DateTime createdAt, required DateTime updatedAt, DateTime? verifiedAt, String? issuer, Sub2ApiAdminBoundIdentityChannel? channel})
const

Properties

channel → Sub2ApiAdminBoundIdentityChannel?
final
createdAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
issuer → String?
final
metadata → Sub2ApiAdminJsonObject
final
providerKey → String
final
providerSubject → String
final
providerType → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → DateTime
final
userId → int
final
verifiedAt → DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited