Sub2ApiAdminBoundIdentityChannel class final

Channel identity returned after a manual Admin binding.

Constructors

Sub2ApiAdminBoundIdentityChannel({required String channel, required String channelAppId, required String channelSubject, required Sub2ApiAdminJsonObject metadata, required DateTime createdAt, required DateTime updatedAt})
const

Properties

channel → String
final
channelAppId → String
final
channelSubject → String
final
createdAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → Sub2ApiAdminJsonObject
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited