Sub2ApiAdminBulkAssignSubscriptionsResult class final

Constructors

Sub2ApiAdminBulkAssignSubscriptionsResult({required int successCount, required int createdCount, required int reusedCount, required int failedCount, required List<Sub2ApiAdminSubscription> subscriptions, required List<String> errors, required Map<int, String> statuses})

Properties

createdCount → int
final
errors → List<String>
final
failedCount → int
final
hashCode → int
The hash code for this object.
no setterinherited
reusedCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statuses → Map<int, String>
final
subscriptions → List<Sub2ApiAdminSubscription>
final
successCount → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited