Sub2ApiAdminBulkUpdateAccountsRequest class final
Constructors
-
Sub2ApiAdminBulkUpdateAccountsRequest({required Sub2ApiAdminBulkAccountSelector selector, String? name, Sub2ApiAdminProxyUpdate proxy = const Sub2ApiAdminProxyUpdate.unchanged(), int? concurrency, int? priority, Sub2ApiDecimal? rateMultiplier, Sub2ApiAdminLoadFactorUpdate loadFactor = const Sub2ApiAdminLoadFactorUpdate.unchanged(), Sub2ApiAdminAccountStatus? status, bool? schedulable, List<
int> ? groupIds, Sub2ApiAdminCredentialSet? credentials, Sub2ApiAdminJsonObject? extra, bool? upstreamBillingProbeEnabled, bool confirmMixedChannelRisk = false})
Properties
- concurrency → int?
-
final
- confirmMixedChannelRisk → bool
-
final
- credentials → Sub2ApiAdminCredentialSet?
-
final
- extra → Sub2ApiAdminJsonObject?
-
final
-
groupIds
→ List<
int> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- loadFactor → Sub2ApiAdminLoadFactorUpdate
-
final
- name → String?
-
final
- priority → int?
-
final
- proxy → Sub2ApiAdminProxyUpdate
-
final
- rateMultiplier → Sub2ApiDecimal?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schedulable → bool?
-
final
- selector → Sub2ApiAdminBulkAccountSelector
-
final
- status → Sub2ApiAdminAccountStatus?
-
final
- upstreamBillingProbeEnabled → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited