Sub2ApiAdminBulkUpdateAccountsResult class final

Constructors

Sub2ApiAdminBulkUpdateAccountsResult({required int success, required int failed, required List<int> successIds, required List<int> failedIds, required List<Sub2ApiAdminBatchAccountMutationItem> results, required int longContextInheritedCount})

Properties

failed → int
final
failedIds → List<int>
final
hashCode → int
The hash code for this object.
no setterinherited
longContextInheritedCount → int
final
results → List<Sub2ApiAdminBatchAccountMutationItem>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → int
final
successIds → List<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited