Sub2ApiAdminCNBalanceEntry class final
Constructors
- Sub2ApiAdminCNBalanceEntry({required String currency, required Sub2ApiDecimal balance})
-
const
Properties
- balance → Sub2ApiDecimal
-
final
- currency → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited