Sub2ApiAdminCNBalanceResult class final

Constructors

Sub2ApiAdminCNBalanceResult({required Sub2ApiAdminCNProvider provider, required bool success, required Sub2ApiDecimal balance, required String currency, required List<Sub2ApiAdminCNBalanceEntry> balances, required bool available, required int? statusCode, required DateTime fetchedAt, required bool persisted, required String error})

Properties

available → bool
final
balance → Sub2ApiDecimal
final
balances → List<Sub2ApiAdminCNBalanceEntry>
final
currency → String
final
error → String
final
fetchedAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
persisted → bool
final
provider → Sub2ApiAdminCNProvider
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int?
final
success → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited