Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getBalance(
int accountId, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminCNBalanceResult> -
getQuota(
int accountId, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminCNQuotaResult> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited