Sub2ApiAdminCNQuotaTier class final

Constructors

Sub2ApiAdminCNQuotaTier({required Sub2ApiAdminCNQuotaWindow window, required Sub2ApiDecimal usedPercent, required DateTime? resetAt})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
resetAt → DateTime?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usedPercent → Sub2ApiDecimal
final
window → Sub2ApiAdminCNQuotaWindow
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited