Sub2ApiAdminChannelDefaultPricing class final
Constructors
- Sub2ApiAdminChannelDefaultPricing({required bool found, Sub2ApiDecimal? inputPrice, Sub2ApiDecimal? outputPrice, Sub2ApiDecimal? cacheWritePrice, Sub2ApiDecimal? cacheReadPrice, Sub2ApiDecimal? imageInputPrice, Sub2ApiDecimal? imageOutputPrice})
-
const
Properties
- cacheReadPrice → Sub2ApiDecimal?
-
final
- cacheWritePrice → Sub2ApiDecimal?
-
final
- found → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageInputPrice → Sub2ApiDecimal?
-
final
- imageOutputPrice → Sub2ApiDecimal?
-
final
- inputPrice → Sub2ApiDecimal?
-
final
- outputPrice → Sub2ApiDecimal?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited