Sub2ApiAdminChannelListQuery class final

Constructors

Sub2ApiAdminChannelListQuery({int? page, int? pageSize, Sub2ApiAdminChannelStatus? status, String? search, Sub2ApiAdminChannelSortField? sortBy, Sub2ApiAdminChannelSortOrder? sortOrder})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
page → int?
final
pageSize → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
final
sortBy → Sub2ApiAdminChannelSortField?
final
sortOrder → Sub2ApiAdminChannelSortOrder?
final
status → Sub2ApiAdminChannelStatus?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited