Sub2ApiAdminChannelModelPricing class final
Constructors
-
Sub2ApiAdminChannelModelPricing({required int id, required String platform, required List<
String> models, required Sub2ApiAdminChannelBillingMode billingMode, required List<Sub2ApiAdminChannelPricingInterval> intervals, Sub2ApiDecimal? inputPrice, Sub2ApiDecimal? outputPrice, Sub2ApiDecimal? cacheWritePrice, Sub2ApiDecimal? cacheReadPrice, Sub2ApiDecimal? fastMultiplier, Sub2ApiDecimal? flexMultiplier, Sub2ApiDecimal? imageInputPrice, Sub2ApiDecimal? imageOutputPrice, Sub2ApiDecimal? perRequestPrice, Sub2ApiAdminChannelTimePricing? timePricing})
Properties
- billingMode → Sub2ApiAdminChannelBillingMode
-
final
- cacheReadPrice → Sub2ApiDecimal?
-
final
- cacheWritePrice → Sub2ApiDecimal?
-
final
- fastMultiplier → Sub2ApiDecimal?
-
final
- flexMultiplier → Sub2ApiDecimal?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- imageInputPrice → Sub2ApiDecimal?
-
final
- imageOutputPrice → Sub2ApiDecimal?
-
final
- inputPrice → Sub2ApiDecimal?
-
final
-
intervals
→ List<
Sub2ApiAdminChannelPricingInterval> -
final
-
models
→ List<
String> -
final
- outputPrice → Sub2ApiDecimal?
-
final
- perRequestPrice → Sub2ApiDecimal?
-
final
- platform → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timePricing → Sub2ApiAdminChannelTimePricing?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited