Sub2ApiAdminChannelPricingIntervalInput class final
Constructors
- Sub2ApiAdminChannelPricingIntervalInput({required int minTokens, int? maxTokens, String tierLabel = '', Sub2ApiDecimal? inputPrice, Sub2ApiDecimal? outputPrice, Sub2ApiDecimal? cacheWritePrice, Sub2ApiDecimal? cacheReadPrice, Sub2ApiDecimal? inputMultiplier, Sub2ApiDecimal? outputMultiplier, Sub2ApiDecimal? cacheWriteMultiplier, Sub2ApiDecimal? cacheReadMultiplier, Sub2ApiDecimal? perRequestPrice, int sortOrder = 0})
-
const
Properties
- cacheReadMultiplier → Sub2ApiDecimal?
-
final
- cacheReadPrice → Sub2ApiDecimal?
-
final
- cacheWriteMultiplier → Sub2ApiDecimal?
-
final
- cacheWritePrice → Sub2ApiDecimal?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputMultiplier → Sub2ApiDecimal?
-
final
- inputPrice → Sub2ApiDecimal?
-
final
- maxTokens → int?
-
final
- minTokens → int
-
final
- outputMultiplier → Sub2ApiDecimal?
-
final
- outputPrice → Sub2ApiDecimal?
-
final
- perRequestPrice → Sub2ApiDecimal?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortOrder → int
-
final
- tierLabel → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited