Sub2ApiAdminChannelTimePricing class final
Constructors
-
Sub2ApiAdminChannelTimePricing({required String timezone, required bool weekdaysOnly, required List<
Sub2ApiAdminChannelTimePricingPeriod> periods})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
periods
→ List<
Sub2ApiAdminChannelTimePricingPeriod> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timezone → String
-
final
- weekdaysOnly → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited