Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
Sub2ApiAdminCreateChannelRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminChannel> -
delete(
int id, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminDeleteChannelResult> -
get(
int id, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminChannel> -
getDefaultPricing(
String model, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminChannelDefaultPricing> -
list(
{Sub2ApiAdminChannelListQuery query = const Sub2ApiAdminChannelListQuery(), Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminChannelPage> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
syncPricingModels(
Sub2ApiAdminChannelPricingPlatform platform, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminChannelPricingModels> -
toString(
) → String -
A string representation of this object.
inherited
-
update(
int id, Sub2ApiAdminUpdateChannelRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminChannel>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited