Sub2ApiAdminCodexSessionImportItem class final

Constructors

Sub2ApiAdminCodexSessionImportItem({required int index, required String name, required Sub2ApiAdminCodexSessionImportAction action, required String message, int? accountId})
const

Properties

accountId → int?
final
action → Sub2ApiAdminCodexSessionImportAction
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
final
message → String
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited