Sub2ApiAdminCodexSessionImportRequest class final
Constructors
-
Sub2ApiAdminCodexSessionImportRequest({required String idempotencyKey, required List<
Sub2ApiAdminCodexSessionPayload> payloads, String? name, String? notes, List<int> groupIds = const [], int? proxyId, int? concurrency, int? priority, Sub2ApiDecimal? rateMultiplier, int? loadFactor, DateTime? expiresAt, bool? autoPauseOnExpired, Sub2ApiAdminJsonObject credentialExtras = const Sub2ApiAdminJsonObject({}), Sub2ApiAdminJsonObject extra = const Sub2ApiAdminJsonObject({}), bool? updateExisting, bool? skipDefaultGroupBind, bool confirmMixedChannelRisk = false})
Properties
- autoPauseOnExpired → bool?
-
final
- concurrency → int?
-
final
- confirmMixedChannelRisk → bool
-
final
- credentialExtras → Sub2ApiAdminJsonObject
-
final
- expiresAt → DateTime?
-
final
- extra → Sub2ApiAdminJsonObject
-
final
-
groupIds
→ List<
int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idempotencyKey → String
-
final
- loadFactor → int?
-
final
- name → String?
-
final
- notes → String?
-
final
-
payloads
→ List<
Sub2ApiAdminCodexSessionPayload> -
final
- priority → int?
-
final
- proxyId → int?
-
final
- rateMultiplier → Sub2ApiDecimal?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipDefaultGroupBind → bool?
-
final
- updateExisting → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited