toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() =>
    'Sub2ApiAdminCodexSessionImportRequest(idempotencyKey: '
    '${idempotencyKey.isEmpty ? '<empty>' : '<provided>'}, '
    'payloads: ${payloads.length} <redacted>, name: $name, notes: $notes, '
    'groupIds: $groupIds, proxyId: $proxyId, concurrency: $concurrency, '
    'priority: $priority, rateMultiplier: $rateMultiplier, '
    'loadFactor: $loadFactor, expiresAt: $expiresAt, '
    'autoPauseOnExpired: $autoPauseOnExpired, updateExisting: '
    '$updateExisting, skipDefaultGroupBind: $skipDefaultGroupBind, '
    'confirmMixedChannelRisk: $confirmMixedChannelRisk)';