Sub2ApiAdminComplianceAcknowledgement class final

Constructors

Sub2ApiAdminComplianceAcknowledgement({required String version, required String documentZh, required String documentEn, required int adminUserId, required String ipAddress, required String userAgent, required DateTime acceptedAt})
const

Properties

acceptedAt → DateTime
final
adminUserId → int
final
documentEn → String
final
documentZh → String
final
hashCode → int
The hash code for this object.
no setterinherited
ipAddress → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userAgent → String
final
version → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited