Sub2ApiAdminComplianceStatus class final
Constructors
- Sub2ApiAdminComplianceStatus({required bool required, required String version, required String documentPathZh, required String documentPathEn, required Uri documentUrlZh, required Uri documentUrlEn, required String ackPhraseZh, required String ackPhraseEn, required Sub2ApiAdminComplianceAcknowledgement? acknowledgement})
-
const
Properties
- acknowledgement → Sub2ApiAdminComplianceAcknowledgement?
-
final
- ackPhraseEn → String
-
final
- ackPhraseZh → String
-
final
- documentPathEn → String
-
final
- documentPathZh → String
-
final
- documentUrlEn → Uri
-
final
- documentUrlZh → Uri
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- required → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
phraseFor(
Sub2ApiAdminComplianceLanguage language) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited