Sub2ApiAdminCompositeRouteDecision class final
Constructors
- Sub2ApiAdminCompositeRouteDecision({required bool matched, required String source, required int groupId, required String publicModel, required Sub2ApiAdminGroupPlatform targetPlatform, required String upstreamModel, required Sub2ApiAdminCompositeRouteEndpoint endpoint, required String reason, Sub2ApiAdminCompositeRoute? route})
-
const
Properties
- endpoint → Sub2ApiAdminCompositeRouteEndpoint
-
final
- groupId → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- matched → bool
-
final
- publicModel → String
-
final
- reason → String
-
final
- route → Sub2ApiAdminCompositeRoute?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
final
- targetPlatform → Sub2ApiAdminGroupPlatform
-
final
- upstreamModel → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited