Sub2ApiAdminCompositeRoutePreviewRequest class final

Constructors

Sub2ApiAdminCompositeRoutePreviewRequest({required String model, Sub2ApiAdminCompositeRouteEndpoint endpoint = Sub2ApiAdminCompositeRouteEndpoint.any})
const

Properties

endpoint → Sub2ApiAdminCompositeRouteEndpoint
final
hashCode → int
The hash code for this object.
no setterinherited
model → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited