Sub2ApiAdminCreateAndRedeemRequest class final
Constructors
- Sub2ApiAdminCreateAndRedeemRequest({required String idempotencyKey, required Sub2ApiRedeemCodeSecret code, Sub2ApiAdminRedeemCodeType type = Sub2ApiAdminRedeemCodeType.balance, required Sub2ApiDecimal value, required int userId, int? groupId, int validityDays = 0, String notes = '', DateTime? expiresAt, int? expiresInDays})
-
const
Properties
- code → Sub2ApiRedeemCodeSecret
-
final
- expiresAt → DateTime?
-
final
- expiresInDays → int?
-
final
- groupId → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idempotencyKey → String
-
final
- notes → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Sub2ApiAdminRedeemCodeType
-
final
- userId → int
-
final
- validityDays → int
-
final
- value → Sub2ApiDecimal
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited