Sub2ApiAdminCreateAnnouncementRequest class final
Constructors
- Sub2ApiAdminCreateAnnouncementRequest({required String title, required String content, Sub2ApiAdminAnnouncementStatus status = Sub2ApiAdminAnnouncementStatus.draft, Sub2ApiAdminAnnouncementNotifyMode notifyMode = Sub2ApiAdminAnnouncementNotifyMode.silent, Sub2ApiAdminAnnouncementTargeting? targeting, DateTime? startsAt, DateTime? endsAt})
Properties
- content → String
-
final
- endsAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- notifyMode → Sub2ApiAdminAnnouncementNotifyMode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startsAt → DateTime?
-
final
- status → Sub2ApiAdminAnnouncementStatus
-
final
- targeting → Sub2ApiAdminAnnouncementTargeting
-
final
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited