Sub2ApiAdminCreateErrorPassthroughRuleRequest class final

Constructors

Sub2ApiAdminCreateErrorPassthroughRuleRequest({required String name, List<int> errorCodes = const <int>[], List<String> keywords = const <String>[], List<String> platforms = const <String>[], bool enabled = true, int priority = 0, Sub2ApiAdminErrorPassthroughMatchMode matchMode = Sub2ApiAdminErrorPassthroughMatchMode.any, bool passthroughCode = true, int? responseCode, bool passthroughBody = true, String? customMessage, bool skipMonitoring = false, String? description})

Properties

customMessage → String?
final
description → String?
final
enabled → bool
final
errorCodes → List<int>
final
hashCode → int
The hash code for this object.
no setterinherited
keywords → List<String>
final
matchMode → Sub2ApiAdminErrorPassthroughMatchMode
final
name → String
final
passthroughBody → bool
final
passthroughCode → bool
final
platforms → List<String>
final
priority → int
final
responseCode → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipMonitoring → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited