Sub2ApiAdminCreateGroupRequest class final
Constructors
-
Sub2ApiAdminCreateGroupRequest({required String name, String description = '', Sub2ApiAdminGroupPlatform? platform, Sub2ApiDecimal? rateMultiplier, bool isExclusive = false, Sub2ApiAdminGroupSubscriptionType? subscriptionType, Sub2ApiDecimal? dailyLimitUsd, Sub2ApiDecimal? weeklyLimitUsd, Sub2ApiDecimal? monthlyLimitUsd, bool longContextPricingEnabled = false, List<
Sub2ApiAdminModelPricing> modelPricing = const [], bool allowImageGeneration = false, bool allowBatchImageGeneration = false, bool imageRateIndependent = false, Sub2ApiDecimal? imageRateMultiplier, Sub2ApiDecimal? batchImageDiscountMultiplier, Sub2ApiDecimal? batchImageHoldMultiplier, bool videoRateIndependent = false, Sub2ApiDecimal? videoRateMultiplier, bool peakRateEnabled = false, String peakStart = '', String peakEnd = '', Sub2ApiDecimal? peakRateMultiplier, bool profitControlEnabled = false, Sub2ApiDecimal? profitMinMargin, Sub2ApiDecimal? profitSafetyBuffer, Sub2ApiDecimal? imagePrice1k, Sub2ApiDecimal? imagePrice2k, Sub2ApiDecimal? imagePrice4k, Sub2ApiDecimal? videoPrice480p, Sub2ApiDecimal? videoPrice720p, Sub2ApiDecimal? videoPrice1080p, Map<String, Map< videoModelPrices = const {}, Sub2ApiDecimal? webSearchPricePerCall, Sub2ApiDecimal? searchPricePer1k, Sub2ApiDecimal? audioRealtimePricePerMin, Sub2ApiDecimal? audioTtsPricePerMillionChars, Sub2ApiDecimal? audioSttPricePerHour, bool claudeCodeOnly = false, int? fallbackGroupId, int? fallbackGroupIdOnInvalidRequest, Map<String, Sub2ApiDecimal> >String, List< modelRouting = const {}, bool modelRoutingEnabled = false, bool? mcpXmlInject, List<int> >String> supportedModelScopes = const [], bool allowMessagesDispatch = false, bool allowLive = false, bool requireOAuthOnly = false, bool requirePrivacySet = false, String defaultMappedModel = '', Sub2ApiAdminMessagesDispatchModelConfig? messagesDispatchModelConfig, Sub2ApiAdminGroupModelsListConfig? modelsListConfig, int rpmLimit = 0, String maxReasoningEffort = '', List<Sub2ApiAdminReasoningEffortMapping> reasoningEffortMappings = const [], List<int> copyAccountsFromGroupIds = const []})
Properties
- allowBatchImageGeneration → bool
-
final
- allowImageGeneration → bool
-
final
- allowLive → bool
-
final
- allowMessagesDispatch → bool
-
final
- audioRealtimePricePerMin → Sub2ApiDecimal?
-
final
- audioSttPricePerHour → Sub2ApiDecimal?
-
final
- audioTtsPricePerMillionChars → Sub2ApiDecimal?
-
final
- batchImageDiscountMultiplier → Sub2ApiDecimal?
-
final
- batchImageHoldMultiplier → Sub2ApiDecimal?
-
final
- claudeCodeOnly → bool
-
final
-
copyAccountsFromGroupIds
→ List<
int> -
final
- dailyLimitUsd → Sub2ApiDecimal?
-
final
- defaultMappedModel → String
-
final
- description → String
-
final
- fallbackGroupId → int?
-
final
- fallbackGroupIdOnInvalidRequest → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imagePrice1k → Sub2ApiDecimal?
-
final
- imagePrice2k → Sub2ApiDecimal?
-
final
- imagePrice4k → Sub2ApiDecimal?
-
final
- imageRateIndependent → bool
-
final
- imageRateMultiplier → Sub2ApiDecimal?
-
final
- isExclusive → bool
-
final
- longContextPricingEnabled → bool
-
final
- maxReasoningEffort → String
-
final
- mcpXmlInject → bool?
-
final
- messagesDispatchModelConfig → Sub2ApiAdminMessagesDispatchModelConfig
-
final
-
modelPricing
→ List<
Sub2ApiAdminModelPricing> -
final
-
modelRouting
→ Map<
String, List< int> > -
final
- modelRoutingEnabled → bool
-
final
- modelsListConfig → Sub2ApiAdminGroupModelsListConfig
-
final
- monthlyLimitUsd → Sub2ApiDecimal?
-
final
- name → String
-
final
- peakEnd → String
-
final
- peakRateEnabled → bool
-
final
- peakRateMultiplier → Sub2ApiDecimal?
-
final
- peakStart → String
-
final
- platform → Sub2ApiAdminGroupPlatform?
-
final
- profitControlEnabled → bool
-
final
- profitMinMargin → Sub2ApiDecimal?
-
final
- profitSafetyBuffer → Sub2ApiDecimal?
-
final
- rateMultiplier → Sub2ApiDecimal?
-
final
-
reasoningEffortMappings
→ List<
Sub2ApiAdminReasoningEffortMapping> -
final
- requireOAuthOnly → bool
-
final
- requirePrivacySet → bool
-
final
- rpmLimit → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchPricePer1k → Sub2ApiDecimal?
-
final
- subscriptionType → Sub2ApiAdminGroupSubscriptionType?
-
final
-
supportedModelScopes
→ List<
String> -
final
-
videoModelPrices
→ Map<
String, Map< String, Sub2ApiDecimal> > -
final
- videoPrice1080p → Sub2ApiDecimal?
-
final
- videoPrice480p → Sub2ApiDecimal?
-
final
- videoPrice720p → Sub2ApiDecimal?
-
final
- videoRateIndependent → bool
-
final
- videoRateMultiplier → Sub2ApiDecimal?
-
final
- webSearchPricePerCall → Sub2ApiDecimal?
-
final
- weeklyLimitUsd → Sub2ApiDecimal?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited