Sub2ApiAdminCreateOpenAIFromCodexPatRequest class final
Constructors
-
Sub2ApiAdminCreateOpenAIFromCodexPatRequest({required Sub2ApiOpenAICodexPersonalAccessToken accessToken, String name = '', String? notes, List<
int> groupIds = const [], int? proxyId, int? concurrency, int? priority, Sub2ApiDecimal? rateMultiplier, int? loadFactor, DateTime? expiresAt, bool? autoPauseOnExpired, Sub2ApiAdminJsonObject? credentialExtras, Sub2ApiAdminJsonObject? extra, bool? skipDefaultGroupBind, bool? confirmMixedChannelRisk})
Properties
- accessToken → Sub2ApiOpenAICodexPersonalAccessToken
-
final
- autoPauseOnExpired → bool?
-
final
- concurrency → int?
-
final
- confirmMixedChannelRisk → bool?
-
final
- credentialExtras → Sub2ApiAdminJsonObject?
-
final
- expiresAt → DateTime?
-
final
- extra → Sub2ApiAdminJsonObject?
-
final
-
groupIds
→ List<
int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- loadFactor → int?
-
final
- name → String
-
final
- notes → String?
-
final
- priority → int?
-
final
- proxyId → int?
-
final
- rateMultiplier → Sub2ApiDecimal?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipDefaultGroupBind → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited