Sub2ApiAdminCreatePaymentProviderRequest class final

Constructors

Sub2ApiAdminCreatePaymentProviderRequest({required Sub2ApiAdminPaymentProviderKey providerKey, required String name, required Map<String, Sub2ApiAdminCredentialSecret> config, required List<String> supportedTypes, bool enabled = true, String paymentMode = '', int sortOrder = 0, String limits = '', bool refundEnabled = false, bool allowUserRefund = false})

Properties

allowUserRefund → bool
final
config → Map<String, Sub2ApiAdminCredentialSecret>
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
limits → String
final
name → String
final
paymentMode → String
final
providerKey → Sub2ApiAdminPaymentProviderKey
final
refundEnabled → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortOrder → int
final
supportedTypes → List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited