Sub2ApiAdminCreatePromoCodeRequest class final
Constructors
- Sub2ApiAdminCreatePromoCodeRequest({required Sub2ApiDecimal bonusAmount, Sub2ApiPromoCode? code, int maxUses = 0, DateTime? expiresAt, String notes = ''})
-
const
Properties
- bonusAmount → Sub2ApiDecimal
-
final
- code → Sub2ApiPromoCode?
-
final
- expiresAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxUses → int
-
final
- notes → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited