Sub2ApiAdminCreateProxyRequest class final

Constructors

Sub2ApiAdminCreateProxyRequest({required String idempotencyKey, required String name, required Sub2ApiAdminProxyProtocol protocol, required String host, required int port, String? username, Sub2ApiAdminProxyPassword? password, DateTime? expiresAt, Sub2ApiAdminProxyFallbackMode fallbackMode = Sub2ApiAdminProxyFallbackMode.none, int? backupProxyId, int expiryWarnDays = 0})
const

Properties

backupProxyId → int?
final
expiresAt → DateTime?
final
expiryWarnDays → int
final
fallbackMode → Sub2ApiAdminProxyFallbackMode
final
hashCode → int
The hash code for this object.
no setterinherited
host → String
final
idempotencyKey → String
final
name → String
final
password → Sub2ApiAdminProxyPassword?
final
port → int
final
protocol → Sub2ApiAdminProxyProtocol
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited