Sub2ApiAdminCreateScheduledTestPlanRequest class final

Constructors

Sub2ApiAdminCreateScheduledTestPlanRequest({required int accountId, required String cronExpression, String modelId = '', bool enabled = true, int maxResults = 50, bool autoRecover = false})
const

Properties

accountId → int
final
autoRecover → bool
final
cronExpression → String
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
maxResults → int
final
modelId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited