Sub2ApiAdminCreateTLSFingerprintProfileRequest class final

Constructors

Sub2ApiAdminCreateTLSFingerprintProfileRequest({required String name, String? description, bool enableGrease = false, List<int> cipherSuites = const <int>[], List<int> curves = const <int>[], List<int> pointFormats = const <int>[], List<int> signatureAlgorithms = const <int>[], List<String> alpnProtocols = const <String>[], List<int> supportedVersions = const <int>[], List<int> keyShareGroups = const <int>[], List<int> pskModes = const <int>[], List<int> extensions = const <int>[]})

Properties

alpnProtocols → List<String>
final
cipherSuites → List<int>
final
curves → List<int>
final
description → String?
final
enableGrease → bool
final
extensions → List<int>
final
hashCode → int
The hash code for this object.
no setterinherited
keyShareGroups → List<int>
final
name → String
final
pointFormats → List<int>
final
pskModes → List<int>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signatureAlgorithms → List<int>
final
supportedVersions → List<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited