Sub2ApiAdminCreateUserAttributeDefinitionRequest class final

Constructors

Sub2ApiAdminCreateUserAttributeDefinitionRequest({required String key, required String name, required Sub2ApiAdminUserAttributeType type, String description = '', List<Sub2ApiAdminUserAttributeOption> options = const [], bool required = false, Sub2ApiAdminUserAttributeValidation validation = const Sub2ApiAdminUserAttributeValidation(), String placeholder = '', bool enabled = false})

Properties

description → String
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
key → String
final
name → String
final
options → List<Sub2ApiAdminUserAttributeOption>
final
placeholder → String
final
required → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Sub2ApiAdminUserAttributeType
final
validation → Sub2ApiAdminUserAttributeValidation
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited