Sub2ApiAdminCreateUserRequest class final
Request to create a user through the Admin management plane.
Constructors
-
Sub2ApiAdminCreateUserRequest({required String email, required Sub2ApiPassword password, String? username, String? notes, Sub2ApiAdminUserRole? role, Sub2ApiDecimal? balance, int concurrency = 0, int rpmLimit = 0, List<
int> allowedGroups = const <int>[]}) -
const
Properties
-
allowedGroups
→ List<
int> -
final
- balance → Sub2ApiDecimal?
-
final
- concurrency → int
-
final
- email → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- notes → String?
-
final
- password → Sub2ApiPassword
-
final
- role → Sub2ApiAdminUserRole?
-
final
- rpmLimit → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- username → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited