Sub2ApiAdminCrsPreviewRequest class final

Constructors

Sub2ApiAdminCrsPreviewRequest({required Uri baseUrl, required String username, required Sub2ApiPassword password})
const

Properties

baseUrl → Uri
final
hashCode → int
The hash code for this object.
no setterinherited
password → Sub2ApiPassword
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited