Sub2ApiAdminCrsSyncRequest class final

Constructors

Sub2ApiAdminCrsSyncRequest({required Uri baseUrl, required String username, required Sub2ApiPassword password, bool syncProxies = true, List<String>? selectedAccountIds})

Properties

baseUrl → Uri
final
hashCode → int
The hash code for this object.
no setterinherited
password → Sub2ApiPassword
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedAccountIds → List<String>?
null creates all new accounts; an empty list creates none.
final
syncProxies → bool
final
username → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited