Sub2ApiAdminCrsSyncResult class final

Constructors

Sub2ApiAdminCrsSyncResult({required int created, required int updated, required int skipped, required int failed, required List<Sub2ApiAdminCrsSyncItem> items})

Properties

created → int
final
failed → int
final
hashCode → int
The hash code for this object.
no setterinherited
items → List<Sub2ApiAdminCrsSyncItem>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipped → int
final
updated → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited