Sub2ApiAdminCustomMenuItem class final

Constructors

Sub2ApiAdminCustomMenuItem({required String id, required String label, required String iconSvg, required String url, required String pageSlug, required String visibility, required int sortOrder})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
iconSvg → String
final
id → String
final
label → String
final
pageSlug → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortOrder → int
final
url → String
final
visibility → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited