Sub2ApiAdminDashboardFilter class abstract

Filters shared by Admin trend, model, group, and snapshot reads.

Available extensions
Annotations
  • @freezed

Constructors

Sub2ApiAdminDashboardFilter({DateTime? startDate, DateTime? endDate, String? timezone, int? userId, int? apiKeyId, int? accountId, int? groupId, Sub2ApiAdminUsageRequestType? requestType, bool? stream, Sub2ApiAdminBillingType? billingType, bool? upstreamModelMismatch})
const
factory

Properties

accountId → int?
no setterinherited
apiKeyId → int?
no setterinherited
billingType → Sub2ApiAdminBillingType?
no setterinherited
copyWith → $Sub2ApiAdminDashboardFilterCopyWith<Sub2ApiAdminDashboardFilter>
Create a copy of Sub2ApiAdminDashboardFilter with the given fields replaced by the non-null parameter values.
no setterinherited
endDate → DateTime?
no setterinherited
groupId → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
requestType → Sub2ApiAdminUsageRequestType?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate → DateTime?
no setterinherited
stream → bool?
no setterinherited
timezone → String?
no setterinherited
upstreamModelMismatch → bool?
no setterinherited
userId → int?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Sub2ApiAdminDashboardFilter value)) → TResult

Available on Sub2ApiAdminDashboardFilter, provided by the Sub2ApiAdminDashboardFilterPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Sub2ApiAdminDashboardFilter value)?) → TResult?

Available on Sub2ApiAdminDashboardFilter, provided by the Sub2ApiAdminDashboardFilterPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Sub2ApiAdminDashboardFilter value)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminDashboardFilter, provided by the Sub2ApiAdminDashboardFilterPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(DateTime? startDate, DateTime? endDate, String? timezone, int? userId, int? apiKeyId, int? accountId, int? groupId, Sub2ApiAdminUsageRequestType? requestType, bool? stream, Sub2ApiAdminBillingType? billingType, bool? upstreamModelMismatch)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminDashboardFilter, provided by the Sub2ApiAdminDashboardFilterPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(DateTime? startDate, DateTime? endDate, String? timezone, int? userId, int? apiKeyId, int? accountId, int? groupId, Sub2ApiAdminUsageRequestType? requestType, bool? stream, Sub2ApiAdminBillingType? billingType, bool? upstreamModelMismatch)) → TResult

Available on Sub2ApiAdminDashboardFilter, provided by the Sub2ApiAdminDashboardFilterPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(DateTime? startDate, DateTime? endDate, String? timezone, int? userId, int? apiKeyId, int? accountId, int? groupId, Sub2ApiAdminUsageRequestType? requestType, bool? stream, Sub2ApiAdminBillingType? billingType, bool? upstreamModelMismatch)?) → TResult?

Available on Sub2ApiAdminDashboardFilter, provided by the Sub2ApiAdminDashboardFilterPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited