Sub2ApiAdminDashboardGroupStats class abstract

One group aggregate, including the upstream account cost.

Available extensions
Annotations
  • @freezed

Constructors

Sub2ApiAdminDashboardGroupStats({required int groupId, required String groupName, required int requests, required int totalTokens, required Sub2ApiDecimal cost, required Sub2ApiDecimal actualCost, required Sub2ApiDecimal accountCost})
const
factory

Properties

accountCost → Sub2ApiDecimal
no setterinherited
actualCost → Sub2ApiDecimal
no setterinherited
copyWith → $Sub2ApiAdminDashboardGroupStatsCopyWith<Sub2ApiAdminDashboardGroupStats>
Create a copy of Sub2ApiAdminDashboardGroupStats with the given fields replaced by the non-null parameter values.
no setterinherited
cost → Sub2ApiDecimal
no setterinherited
groupId → int
no setterinherited
groupName → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
requests → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalTokens → int
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Sub2ApiAdminDashboardGroupStats value)) → TResult

Available on Sub2ApiAdminDashboardGroupStats, provided by the Sub2ApiAdminDashboardGroupStatsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Sub2ApiAdminDashboardGroupStats value)?) → TResult?

Available on Sub2ApiAdminDashboardGroupStats, provided by the Sub2ApiAdminDashboardGroupStatsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Sub2ApiAdminDashboardGroupStats value)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminDashboardGroupStats, provided by the Sub2ApiAdminDashboardGroupStatsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int groupId, String groupName, int requests, int totalTokens, Sub2ApiDecimal cost, Sub2ApiDecimal actualCost, Sub2ApiDecimal accountCost)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminDashboardGroupStats, provided by the Sub2ApiAdminDashboardGroupStatsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int groupId, String groupName, int requests, int totalTokens, Sub2ApiDecimal cost, Sub2ApiDecimal actualCost, Sub2ApiDecimal accountCost)) → TResult

Available on Sub2ApiAdminDashboardGroupStats, provided by the Sub2ApiAdminDashboardGroupStatsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int groupId, String groupName, int requests, int totalTokens, Sub2ApiDecimal cost, Sub2ApiDecimal actualCost, Sub2ApiDecimal accountCost)?) → TResult?

Available on Sub2ApiAdminDashboardGroupStats, provided by the Sub2ApiAdminDashboardGroupStatsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited