Sub2ApiAdminDashboardModelStats class abstract

One model aggregate, including the upstream account cost.

Available extensions
Annotations
  • @freezed

Constructors

Sub2ApiAdminDashboardModelStats({required String model, required int requests, required int inputTokens, required int outputTokens, required int cacheCreationTokens, required int cacheReadTokens, required int totalTokens, required Sub2ApiDecimal cost, required Sub2ApiDecimal actualCost, required Sub2ApiDecimal accountCost})
const
factory

Properties

accountCost → Sub2ApiDecimal
no setterinherited
actualCost → Sub2ApiDecimal
no setterinherited
cacheCreationTokens → int
no setterinherited
cacheReadTokens → int
no setterinherited
copyWith → $Sub2ApiAdminDashboardModelStatsCopyWith<Sub2ApiAdminDashboardModelStats>
Create a copy of Sub2ApiAdminDashboardModelStats with the given fields replaced by the non-null parameter values.
no setterinherited
cost → Sub2ApiDecimal
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
inputTokens → int
no setterinherited
model → String
no setterinherited
outputTokens → int
no setterinherited
requests → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalTokens → int
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Sub2ApiAdminDashboardModelStats value)) → TResult

Available on Sub2ApiAdminDashboardModelStats, provided by the Sub2ApiAdminDashboardModelStatsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Sub2ApiAdminDashboardModelStats value)?) → TResult?

Available on Sub2ApiAdminDashboardModelStats, provided by the Sub2ApiAdminDashboardModelStatsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Sub2ApiAdminDashboardModelStats value)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminDashboardModelStats, provided by the Sub2ApiAdminDashboardModelStatsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String model, int requests, int inputTokens, int outputTokens, int cacheCreationTokens, int cacheReadTokens, int totalTokens, Sub2ApiDecimal cost, Sub2ApiDecimal actualCost, Sub2ApiDecimal accountCost)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminDashboardModelStats, provided by the Sub2ApiAdminDashboardModelStatsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String model, int requests, int inputTokens, int outputTokens, int cacheCreationTokens, int cacheReadTokens, int totalTokens, Sub2ApiDecimal cost, Sub2ApiDecimal actualCost, Sub2ApiDecimal accountCost)) → TResult

Available on Sub2ApiAdminDashboardModelStats, provided by the Sub2ApiAdminDashboardModelStatsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String model, int requests, int inputTokens, int outputTokens, int cacheCreationTokens, int cacheReadTokens, int totalTokens, Sub2ApiDecimal cost, Sub2ApiDecimal actualCost, Sub2ApiDecimal accountCost)?) → TResult?

Available on Sub2ApiAdminDashboardModelStats, provided by the Sub2ApiAdminDashboardModelStatsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited