Sub2ApiAdminDashboardSnapshotRequest class abstract

Inclusion flags and filters for the aggregated Admin dashboard snapshot.

Available extensions
Annotations
  • @freezed

Constructors

Sub2ApiAdminDashboardSnapshotRequest({@Default.new(Sub2ApiAdminDashboardFilter()) Sub2ApiAdminDashboardFilter filter, @Default.new(Sub2ApiAdminUsageGranularity.day) Sub2ApiAdminUsageGranularity granularity, String? model, @Default.new(true) bool includeStats, @Default.new(true) bool includeTrend, @Default.new(true) bool includeModelStats, @Default.new(false) bool includeGroupStats, @Default.new(false) bool includeUsersTrend, @Default.new(12) int usersTrendLimit})
const
factory

Properties

copyWith → $Sub2ApiAdminDashboardSnapshotRequestCopyWith<Sub2ApiAdminDashboardSnapshotRequest>
Create a copy of Sub2ApiAdminDashboardSnapshotRequest with the given fields replaced by the non-null parameter values.
no setterinherited
filter → Sub2ApiAdminDashboardFilter
no setterinherited
granularity → Sub2ApiAdminUsageGranularity
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
includeGroupStats → bool
no setterinherited
includeModelStats → bool
no setterinherited
includeStats → bool
no setterinherited
includeTrend → bool
no setterinherited
includeUsersTrend → bool
no setterinherited
model → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usersTrendLimit → int
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Sub2ApiAdminDashboardSnapshotRequest value)) → TResult

Available on Sub2ApiAdminDashboardSnapshotRequest, provided by the Sub2ApiAdminDashboardSnapshotRequestPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Sub2ApiAdminDashboardSnapshotRequest value)?) → TResult?

Available on Sub2ApiAdminDashboardSnapshotRequest, provided by the Sub2ApiAdminDashboardSnapshotRequestPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Sub2ApiAdminDashboardSnapshotRequest value)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminDashboardSnapshotRequest, provided by the Sub2ApiAdminDashboardSnapshotRequestPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(Sub2ApiAdminDashboardFilter filter, Sub2ApiAdminUsageGranularity granularity, String? model, bool includeStats, bool includeTrend, bool includeModelStats, bool includeGroupStats, bool includeUsersTrend, int usersTrendLimit)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminDashboardSnapshotRequest, provided by the Sub2ApiAdminDashboardSnapshotRequestPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(Sub2ApiAdminDashboardFilter filter, Sub2ApiAdminUsageGranularity granularity, String? model, bool includeStats, bool includeTrend, bool includeModelStats, bool includeGroupStats, bool includeUsersTrend, int usersTrendLimit)) → TResult

Available on Sub2ApiAdminDashboardSnapshotRequest, provided by the Sub2ApiAdminDashboardSnapshotRequestPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(Sub2ApiAdminDashboardFilter filter, Sub2ApiAdminUsageGranularity granularity, String? model, bool includeStats, bool includeTrend, bool includeModelStats, bool includeGroupStats, bool includeUsersTrend, int usersTrendLimit)?) → TResult?

Available on Sub2ApiAdminDashboardSnapshotRequest, provided by the Sub2ApiAdminDashboardSnapshotRequestPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited