Sub2ApiAdminDashboardTrendPoint class abstract

One system-wide dashboard trend bucket.

Available extensions
Annotations
  • @freezed

Constructors

Sub2ApiAdminDashboardTrendPoint({required String date, required int requests, required int inputTokens, required int outputTokens, required int cacheCreationTokens, required int cacheReadTokens, required int totalTokens, required Sub2ApiDecimal cost, required Sub2ApiDecimal actualCost})
const
factory

Properties

actualCost → Sub2ApiDecimal
no setterinherited
cacheCreationTokens → int
no setterinherited
cacheReadTokens → int
no setterinherited
copyWith → $Sub2ApiAdminDashboardTrendPointCopyWith<Sub2ApiAdminDashboardTrendPoint>
Create a copy of Sub2ApiAdminDashboardTrendPoint with the given fields replaced by the non-null parameter values.
no setterinherited
cost → Sub2ApiDecimal
no setterinherited
date → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
inputTokens → int
no setterinherited
outputTokens → int
no setterinherited
requests → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalTokens → int
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Sub2ApiAdminDashboardTrendPoint value)) → TResult

Available on Sub2ApiAdminDashboardTrendPoint, provided by the Sub2ApiAdminDashboardTrendPointPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Sub2ApiAdminDashboardTrendPoint value)?) → TResult?

Available on Sub2ApiAdminDashboardTrendPoint, provided by the Sub2ApiAdminDashboardTrendPointPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Sub2ApiAdminDashboardTrendPoint value)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminDashboardTrendPoint, provided by the Sub2ApiAdminDashboardTrendPointPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String date, int requests, int inputTokens, int outputTokens, int cacheCreationTokens, int cacheReadTokens, int totalTokens, Sub2ApiDecimal cost, Sub2ApiDecimal actualCost)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminDashboardTrendPoint, provided by the Sub2ApiAdminDashboardTrendPointPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String date, int requests, int inputTokens, int outputTokens, int cacheCreationTokens, int cacheReadTokens, int totalTokens, Sub2ApiDecimal cost, Sub2ApiDecimal actualCost)) → TResult

Available on Sub2ApiAdminDashboardTrendPoint, provided by the Sub2ApiAdminDashboardTrendPointPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String date, int requests, int inputTokens, int outputTokens, int cacheCreationTokens, int cacheReadTokens, int totalTokens, Sub2ApiDecimal cost, Sub2ApiDecimal actualCost)?) → TResult?

Available on Sub2ApiAdminDashboardTrendPoint, provided by the Sub2ApiAdminDashboardTrendPointPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited