Sub2ApiAdminDataAgentHealth class final

Constructors

Sub2ApiAdminDataAgentHealth({required bool enabled, required String reason, required Sub2ApiAdminDataManagementPath socketPath, Sub2ApiAdminDataAgentInfo? agent})
const

Properties

agent → Sub2ApiAdminDataAgentInfo?
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
reason → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socketPath → Sub2ApiAdminDataManagementPath
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited