Sub2ApiAdminDataBackupJobPage class final
Constructors
-
Sub2ApiAdminDataBackupJobPage({required List<
Sub2ApiAdminDataBackupJob> items, required String nextPageToken})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
Sub2ApiAdminDataBackupJob> -
final
- nextPageToken → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited