Sub2ApiAdminDataSourceConfig class final

Constructors

Sub2ApiAdminDataSourceConfig({String host = '', int port = 0, String user = '', Sub2ApiAdminCredentialSecret? password, String database = '', String sslMode = '', String address = '', String username = '', int databaseIndex = 0, String containerName = ''})
const

Properties

address → String
final
containerName → String
final
database → String
final
databaseIndex → int
final
hashCode → int
The hash code for this object.
no setterinherited
host → String
final
password → Sub2ApiAdminCredentialSecret?
final
port → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sslMode → String
final
user → String
final
username → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited