Sub2ApiAdminDataSourceProfile class final

Constructors

Sub2ApiAdminDataSourceProfile({required Sub2ApiAdminDataSourceType sourceType, required String profileId, required String name, required bool isActive, required Sub2ApiAdminDataSourceConfig config, required bool passwordConfigured, DateTime? createdAt, DateTime? updatedAt})
const

Properties

config → Sub2ApiAdminDataSourceConfig
final
createdAt → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
isActive → bool
final
name → String
final
passwordConfigured → bool
final
profileId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceType → Sub2ApiAdminDataSourceType
final
updatedAt → DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited