Sub2ApiAdminEmailTemplateDetail class final

Constructors

Sub2ApiAdminEmailTemplateDetail({required String event, required String locale, required String subject, required Sub2ApiAdminEmailTemplateContent html, required bool isCustom, required List<String> placeholders, DateTime? updatedAt})

Properties

event → String
final
hashCode → int
The hash code for this object.
no setterinherited
html → Sub2ApiAdminEmailTemplateContent
final
isCustom → bool
final
locale → String
final
placeholders → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String
final
updatedAt → DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited