Sub2ApiAdminEmailTemplateEvent class final

Constructors

Sub2ApiAdminEmailTemplateEvent({required String value, required String label, required String description, required String category, required bool optional})
const

Properties

category → String
final
description → String
final
hashCode → int
The hash code for this object.
no setterinherited
label → String
final
optional → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited