Sub2ApiAdminEmailTemplateSummary class final

Constructors

Sub2ApiAdminEmailTemplateSummary({required String event, required String locale, required String subject, required bool isCustom, DateTime? updatedAt})
const

Properties

event → String
final
hashCode → int
The hash code for this object.
no setterinherited
isCustom → bool
final
locale → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String
final
updatedAt → DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited