Sub2ApiAdminEntityTrendQuery class abstract
Query for top API-key or user trend series.
- Available extensions
- Annotations
-
- @freezed
Constructors
- Sub2ApiAdminEntityTrendQuery({DateTime? startDate, DateTime? endDate, String? timezone, @Default.new(Sub2ApiAdminUsageGranularity.day) Sub2ApiAdminUsageGranularity granularity, int? limit})
-
constfactory
Properties
-
copyWith
→ $Sub2ApiAdminEntityTrendQueryCopyWith<
Sub2ApiAdminEntityTrendQuery> -
Create a copy of Sub2ApiAdminEntityTrendQuery
with the given fields replaced by the non-null parameter values.
no setterinherited
- endDate → DateTime?
-
no setterinherited
- granularity → Sub2ApiAdminUsageGranularity
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate → DateTime?
-
no setterinherited
- timezone → String?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_Sub2ApiAdminEntityTrendQuery value)) → TResult -
Available on Sub2ApiAdminEntityTrendQuery, provided by the Sub2ApiAdminEntityTrendQueryPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_Sub2ApiAdminEntityTrendQuery value)?) → TResult? -
Available on Sub2ApiAdminEntityTrendQuery, provided by the Sub2ApiAdminEntityTrendQueryPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_Sub2ApiAdminEntityTrendQuery value)?, {required TResult orElse()}) → TResult -
Available on Sub2ApiAdminEntityTrendQuery, provided by the Sub2ApiAdminEntityTrendQueryPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(DateTime? startDate, DateTime? endDate, String? timezone, Sub2ApiAdminUsageGranularity granularity, int? limit)?, {required TResult orElse()}) → TResult -
Available on Sub2ApiAdminEntityTrendQuery, provided by the Sub2ApiAdminEntityTrendQueryPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(DateTime? startDate, DateTime? endDate, String? timezone, Sub2ApiAdminUsageGranularity granularity, int? limit)) → TResult -
Available on Sub2ApiAdminEntityTrendQuery, provided by the Sub2ApiAdminEntityTrendQueryPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(DateTime? startDate, DateTime? endDate, String? timezone, Sub2ApiAdminUsageGranularity granularity, int? limit)?) → TResult? -
Available on Sub2ApiAdminEntityTrendQuery, provided by the Sub2ApiAdminEntityTrendQueryPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited