Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
Sub2ApiAdminCreateErrorPassthroughRuleRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminErrorPassthroughRule> -
delete(
int id, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminDeleteErrorPassthroughRuleResult> -
get(
int id, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminErrorPassthroughRule> -
list(
{Sub2ApiRequestOptions? requestOptions}) → Future< List< Sub2ApiAdminErrorPassthroughRule> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
int id, Sub2ApiAdminUpdateErrorPassthroughRuleRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminErrorPassthroughRule>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited