Sub2ApiAdminGeminiDriveStorage class final
Constructors
- Sub2ApiAdminGeminiDriveStorage({required int limitBytes, required int usageBytes, required DateTime updatedAt})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- limitBytes → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → DateTime
-
final
- usageBytes → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited