Sub2ApiAdminGeminiOAuthCapabilities class final
Constructors
-
Sub2ApiAdminGeminiOAuthCapabilities({required bool aiStudioOAuthEnabled, required List<
Uri> requiredRedirectUris})
Properties
- aiStudioOAuthEnabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
requiredRedirectUris
→ List<
Uri> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited