Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
exchangeCode(
Sub2ApiAdminGeminiExchangeCodeRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminGeminiTokenInfo> -
generateAuthorization(
{int? proxyId, String? projectId, Sub2ApiAdminGeminiOAuthType oauthType = Sub2ApiAdminGeminiOAuthType.codeAssist, String? tierId, Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminGeminiOAuthAuthorization> -
getCapabilities(
{Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminGeminiOAuthCapabilities> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited