Sub2ApiAdminGeminiTokenInfo class final

Constructors

Sub2ApiAdminGeminiTokenInfo({required Sub2ApiAccessToken accessToken, required Sub2ApiRefreshToken? refreshToken, required String tokenType, required String scope, required Duration expiresIn, required DateTime expiresAt, required String projectId, required Sub2ApiAdminGeminiOAuthType oauthType, required String tierId, required Sub2ApiAdminGeminiDriveStorage? driveStorage})
const

Properties

accessToken → Sub2ApiAccessToken
final
driveStorage → Sub2ApiAdminGeminiDriveStorage?
final
expiresAt → DateTime
final
expiresIn → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
oauthType → Sub2ApiAdminGeminiOAuthType
final
projectId → String
final
refreshToken → Sub2ApiRefreshToken?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → String
final
tierId → String
final
tokenType → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited