Sub2ApiAdminGenerateRedeemCodesRequest class final

Constructors

Sub2ApiAdminGenerateRedeemCodesRequest({required String idempotencyKey, required int count, required Sub2ApiAdminRedeemCodeType type, required Sub2ApiDecimal value, int? groupId, int validityDays = 0, DateTime? expiresAt, int? expiresInDays})
const

Properties

count → int
final
expiresAt → DateTime?
final
expiresInDays → int?
final
groupId → int?
final
hashCode → int
The hash code for this object.
no setterinherited
idempotencyKey → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Sub2ApiAdminRedeemCodeType
final
validityDays → int
final
value → Sub2ApiDecimal
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited