Sub2ApiAdminGrokBillingProduct class final
Constructors
- Sub2ApiAdminGrokBillingProduct({required String product, Sub2ApiDecimal? usagePercent})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- product → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usagePercent → Sub2ApiDecimal?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited