Sub2ApiAdminGrokCreateAccountFromOAuthRequest class final
Constructors
-
Sub2ApiAdminGrokCreateAccountFromOAuthRequest({required Sub2ApiGrokOAuthSessionId sessionId, required Sub2ApiOAuthAuthorizationCode code, required Sub2ApiGrokOAuthState state, Uri? redirectUri, int? proxyId, String name = '', int concurrency = 0, int priority = 0, List<
int> groupIds = const <int>[]})
Properties
- code → Sub2ApiOAuthAuthorizationCode
-
final
- concurrency → int
-
final
-
groupIds
→ List<
int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- priority → int
-
final
- proxyId → int?
-
final
- redirectUri → Uri?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → Sub2ApiGrokOAuthSessionId
-
final
- state → Sub2ApiGrokOAuthState
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited