Sub2ApiAdminGrokImportCredentials class final

Constructors

Sub2ApiAdminGrokImportCredentials({Uri? baseUrl, Sub2ApiAdminJsonObject modelMapping = const Sub2ApiAdminJsonObject({}), Sub2ApiAdminJsonObject headerOverride = const Sub2ApiAdminJsonObject({}), Sub2ApiAdminJsonObject headerOverrides = const Sub2ApiAdminJsonObject({}), bool? headerOverrideEnabled, Sub2ApiAdminJsonObject customHeaders = const Sub2ApiAdminJsonObject({})})
const

Properties

baseUrl → Uri?
final
customHeaders → Sub2ApiAdminJsonObject
final
hashCode → int
The hash code for this object.
no setterinherited
headerOverride → Sub2ApiAdminJsonObject
final
headerOverrideEnabled → bool?
final
headerOverrides → Sub2ApiAdminJsonObject
final
modelMapping → Sub2ApiAdminJsonObject
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited