Sub2ApiAdminGrokQuotaResult class final

Constructors

Sub2ApiAdminGrokQuotaResult({required String source, required String model, Sub2ApiAdminGrokBillingSummary? billing, Sub2ApiAdminGrokQuotaSnapshot? snapshot, Sub2ApiAdminGrokUsageWindow? localUsage24h, Sub2ApiAdminGrokUsageWindow? localUsage7d, Sub2ApiAdminGrokUsageWindow? localUsageMonthly, required int statusCode, required bool headersObserved, required bool resetSupported, required DateTime fetchedAt, required bool persisted, required String probeError})
const

Properties

billing → Sub2ApiAdminGrokBillingSummary?
final
fetchedAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
headersObserved → bool
final
localUsage24h → Sub2ApiAdminGrokUsageWindow?
final
localUsage7d → Sub2ApiAdminGrokUsageWindow?
final
localUsageMonthly → Sub2ApiAdminGrokUsageWindow?
final
model → String
final
persisted → bool
final
probeError → String
final
resetSupported → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshot → Sub2ApiAdminGrokQuotaSnapshot?
final
source → String
final
statusCode → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited