Sub2ApiAdminGrokQuotaSnapshot class final

Constructors

Sub2ApiAdminGrokQuotaSnapshot({Sub2ApiAdminGrokQuotaWindow? requests, Sub2ApiAdminGrokQuotaWindow? tokens, int? retryAfterSeconds, required String subscriptionTier, required String entitlementStatus, required int statusCode, required Map<String, String> headers, required bool headersObserved, required String observationSource, DateTime? lastProbeAt, DateTime? lastHeadersSeenAt, required DateTime updatedAt, required String model, required String planFrom45Responses, DateTime? planFrom45ResponsesAt})

Properties

entitlementStatus → String
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
final
headersObserved → bool
final
lastHeadersSeenAt → DateTime?
final
lastProbeAt → DateTime?
final
model → String
final
observationSource → String
final
planFrom45Responses → String
final
planFrom45ResponsesAt → DateTime?
final
requests → Sub2ApiAdminGrokQuotaWindow?
final
retryAfterSeconds → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
final
subscriptionTier → String
final
tokens → Sub2ApiAdminGrokQuotaWindow?
final
updatedAt → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited