Sub2ApiAdminGrokReconcileRequest class final

Constructors

Sub2ApiAdminGrokReconcileRequest({bool apply = false, int afterId = 0, int limit = 50, Duration refreshWindow = const Duration(minutes: 5)})
const

Properties

afterId → int
final
apply → bool
final
hashCode → int
The hash code for this object.
no setterinherited
limit → int
final
refreshWindow → Duration
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited