Sub2ApiAdminGrokRefreshTokenRequest class final
Constructors
- Sub2ApiAdminGrokRefreshTokenRequest({required Sub2ApiRefreshToken refreshToken, String clientId = '', int? proxyId})
-
const
Properties
- clientId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- proxyId → int?
-
final
- refreshToken → Sub2ApiRefreshToken
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited