Sub2ApiAdminGrokRuntimeCheck class final
Constructors
- Sub2ApiAdminGrokRuntimeCheck({required String value, required bool valid, required String error, required bool isDefault})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited