Sub2ApiAdminGrokSsoImportItem class final

Constructors

Sub2ApiAdminGrokSsoImportItem({required int index, required String name, required String email, required String error, Sub2ApiAdminAccount? account})
const

Properties

account → Sub2ApiAdminAccount?
final
email → String
final
error → String
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited