Sub2ApiAdminGrokSsoImportRequest class final
Constructors
-
Sub2ApiAdminGrokSsoImportRequest({required List<
Sub2ApiGrokSsoToken> ssoTokens, String name = '', String? notes, int? proxyId, List<int> groupIds = const <int>[], Sub2ApiAdminGrokImportCredentials credentials = const Sub2ApiAdminGrokImportCredentials(), Sub2ApiAdminJsonObject extra = const Sub2ApiAdminJsonObject({}), int concurrency = 0, int? loadFactor, int priority = 0, Sub2ApiDecimal? rateMultiplier, DateTime? expiresAt, bool? autoPauseOnExpired})
Properties
- autoPauseOnExpired → bool?
-
final
- concurrency → int
-
final
- credentials → Sub2ApiAdminGrokImportCredentials
-
final
- expiresAt → DateTime?
-
final
- extra → Sub2ApiAdminJsonObject
-
final
-
groupIds
→ List<
int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- loadFactor → int?
-
final
- name → String
-
final
- notes → String?
-
final
- priority → int
-
final
- proxyId → int?
-
final
- rateMultiplier → Sub2ApiDecimal?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
ssoTokens
→ List<
Sub2ApiGrokSsoToken> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited