Sub2ApiAdminGrokSsoTokenRequest class final

Constructors

Sub2ApiAdminGrokSsoTokenRequest({required Sub2ApiGrokSsoToken ssoToken, int? proxyId})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
proxyId → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ssoToken → Sub2ApiGrokSsoToken
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited