Sub2ApiAdminGroupCapacitySummary class final

Constructors

Sub2ApiAdminGroupCapacitySummary({required int groupId, required int concurrencyUsed, required int concurrencyMax, required int sessionsUsed, required int sessionsMax, required int rpmUsed, required int rpmMax})
const

Properties

concurrencyMax → int
final
concurrencyUsed → int
final
groupId → int
final
hashCode → int
The hash code for this object.
no setterinherited
rpmMax → int
final
rpmUsed → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionsMax → int
final
sessionsUsed → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited