Sub2ApiAdminGroupListQuery class final

Constructors

Sub2ApiAdminGroupListQuery({int? page, int? pageSize, Sub2ApiAdminGroupPlatform? platform, Sub2ApiAdminGroupStatus? status, String? search, bool? isExclusive, String? sortBy, String? sortOrder})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isExclusive → bool?
final
page → int?
final
pageSize → int?
final
platform → Sub2ApiAdminGroupPlatform?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
final
sortBy → String?
final
sortOrder → String?
final
status → Sub2ApiAdminGroupStatus?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited