Sub2ApiAdminGroupRateMultiplierInput class final
Constructors
- Sub2ApiAdminGroupRateMultiplierInput({required int userId, required Sub2ApiDecimal rateMultiplier})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- rateMultiplier → Sub2ApiDecimal
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited