Sub2ApiAdminGroupStats class final

Constructors

Sub2ApiAdminGroupStats({required int totalApiKeys, required int activeApiKeys, required int totalRequests, required Sub2ApiDecimal totalCost})
const

Properties

activeApiKeys → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalApiKeys → int
final
totalCost → Sub2ApiDecimal
final
totalRequests → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited