Sub2ApiAdminGroupUsageSummary class final

Constructors

Sub2ApiAdminGroupUsageSummary({required int groupId, required Sub2ApiDecimal todayCost, required Sub2ApiDecimal yesterdayCost, required Sub2ApiDecimal totalCost})
const

Properties

groupId → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
todayCost → Sub2ApiDecimal
final
totalCost → Sub2ApiDecimal
final
yesterdayCost → Sub2ApiDecimal
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited