Sub2ApiAdminIdentity class final

Verified administrator identity returned by the JWT facade bootstrap.

Constructors

Sub2ApiAdminIdentity({required Sub2ApiCurrentUser currentUser})
const

Properties

currentUser → Sub2ApiCurrentUser
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited