Sub2ApiAdminJsonNull class final
JSON null metadata value.
- Inheritance
-
- Object
- Sub2ApiAdminJsonValue
- Sub2ApiAdminJsonNull
Constructors
- Sub2ApiAdminJsonNull()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toWire(
) → Object? -
Converts this typed value to the package-internal JSON wire shape.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited