Sub2ApiAdminMessagesDispatchModelConfig class final

Constructors

Sub2ApiAdminMessagesDispatchModelConfig({required String opusMappedModel, required String sonnetMappedModel, required String haikuMappedModel, required Map<String, String> exactModelMappings})

Properties

exactModelMappings → Map<String, String>
final
haikuMappedModel → String
final
hashCode → int
The hash code for this object.
no setterinherited
opusMappedModel → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sonnetMappedModel → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited