Sub2ApiAdminMixedChannelCheck class final

Constructors

Sub2ApiAdminMixedChannelCheck({required bool hasRisk, required String error, required String message, Sub2ApiAdminMixedChannelRiskDetails? details})
const

Properties

details → Sub2ApiAdminMixedChannelRiskDetails?
final
error → String
final
hashCode → int
The hash code for this object.
no setterinherited
hasRisk → bool
final
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited