Sub2ApiAdminMixedChannelRiskDetails class final

Constructors

Sub2ApiAdminMixedChannelRiskDetails({required int groupId, required String groupName, required String currentPlatform, required String otherPlatform})
const

Properties

currentPlatform → String
final
groupId → int
final
groupName → String
final
hashCode → int
The hash code for this object.
no setterinherited
otherPlatform → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited