Sub2ApiAdminModelPricing class final
Constructors
-
Sub2ApiAdminModelPricing({required int id, required int channelId, required String platform, required List<
String> models, required String billingMode, required List<Sub2ApiAdminPricingInterval> intervals, Sub2ApiDecimal? inputPrice, Sub2ApiDecimal? outputPrice, Sub2ApiDecimal? cacheWritePrice, Sub2ApiDecimal? cacheReadPrice, Sub2ApiDecimal? fastMultiplier, Sub2ApiDecimal? flexMultiplier, Sub2ApiDecimal? imageInputPrice, Sub2ApiDecimal? imageOutputPrice, Sub2ApiDecimal? perRequestPrice, Sub2ApiAdminTimePricing? timePricing, DateTime? createdAt, DateTime? updatedAt})
Properties
- billingMode → String
-
final
- cacheReadPrice → Sub2ApiDecimal?
-
final
- cacheWritePrice → Sub2ApiDecimal?
-
final
- channelId → int
-
final
- createdAt → DateTime?
-
final
- fastMultiplier → Sub2ApiDecimal?
-
final
- flexMultiplier → Sub2ApiDecimal?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- imageInputPrice → Sub2ApiDecimal?
-
final
- imageOutputPrice → Sub2ApiDecimal?
-
final
- inputPrice → Sub2ApiDecimal?
-
final
-
intervals
→ List<
Sub2ApiAdminPricingInterval> -
final
-
models
→ List<
String> -
final
- outputPrice → Sub2ApiDecimal?
-
final
- perRequestPrice → Sub2ApiDecimal?
-
final
- platform → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timePricing → Sub2ApiAdminTimePricing?
-
final
- updatedAt → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited