Sub2ApiAdminModelStatsQuery class abstract

Query for system-wide requested, upstream, or mapped model aggregates.

Available extensions
Annotations
  • @freezed

Constructors

Sub2ApiAdminModelStatsQuery({@Default.new(Sub2ApiAdminDashboardFilter()) Sub2ApiAdminDashboardFilter filter, @Default.new(Sub2ApiAdminModelSource.requested) Sub2ApiAdminModelSource modelSource})
const
factory

Properties

copyWith → $Sub2ApiAdminModelStatsQueryCopyWith<Sub2ApiAdminModelStatsQuery>
Create a copy of Sub2ApiAdminModelStatsQuery with the given fields replaced by the non-null parameter values.
no setterinherited
filter → Sub2ApiAdminDashboardFilter
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
modelSource → Sub2ApiAdminModelSource
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Sub2ApiAdminModelStatsQuery value)) → TResult

Available on Sub2ApiAdminModelStatsQuery, provided by the Sub2ApiAdminModelStatsQueryPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Sub2ApiAdminModelStatsQuery value)?) → TResult?

Available on Sub2ApiAdminModelStatsQuery, provided by the Sub2ApiAdminModelStatsQueryPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Sub2ApiAdminModelStatsQuery value)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminModelStatsQuery, provided by the Sub2ApiAdminModelStatsQueryPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(Sub2ApiAdminDashboardFilter filter, Sub2ApiAdminModelSource modelSource)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminModelStatsQuery, provided by the Sub2ApiAdminModelStatsQueryPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(Sub2ApiAdminDashboardFilter filter, Sub2ApiAdminModelSource modelSource)) → TResult

Available on Sub2ApiAdminModelStatsQuery, provided by the Sub2ApiAdminModelStatsQueryPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(Sub2ApiAdminDashboardFilter filter, Sub2ApiAdminModelSource modelSource)?) → TResult?

Available on Sub2ApiAdminModelStatsQuery, provided by the Sub2ApiAdminModelStatsQueryPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited