Sub2ApiAdminMonitorV2ErrorCategory enum

Inheritance
Available extensions

Values

contentPolicy → const Sub2ApiAdminMonitorV2ErrorCategory
authentication → const Sub2ApiAdminMonitorV2ErrorCategory
contextLimit → const Sub2ApiAdminMonitorV2ErrorCategory
invalidRequest → const Sub2ApiAdminMonitorV2ErrorCategory
modelUnsupported → const Sub2ApiAdminMonitorV2ErrorCategory
groupAccess → const Sub2ApiAdminMonitorV2ErrorCategory
quotaOrBalance → const Sub2ApiAdminMonitorV2ErrorCategory
accountPoolUnavailable → const Sub2ApiAdminMonitorV2ErrorCategory
rateOrCapacity → const Sub2ApiAdminMonitorV2ErrorCategory
timeout → const Sub2ApiAdminMonitorV2ErrorCategory
transportOrStream → const Sub2ApiAdminMonitorV2ErrorCategory
upstreamForbidden → const Sub2ApiAdminMonitorV2ErrorCategory
notFound → const Sub2ApiAdminMonitorV2ErrorCategory
clientCancelled → const Sub2ApiAdminMonitorV2ErrorCategory
upstream5xx → const Sub2ApiAdminMonitorV2ErrorCategory
internal → const Sub2ApiAdminMonitorV2ErrorCategory
other → const Sub2ApiAdminMonitorV2ErrorCategory

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<Sub2ApiAdminMonitorV2ErrorCategory>
A constant List of the values in this enum, in order of their declaration.