Sub2ApiAdminOllamaCloudUsageData class final

Properties

balance → String
final
fiveHour → Sub2ApiAdminOllamaCloudUsageWindow?
final
hashCode → int
The hash code for this object.
no setterinherited
models → List<Sub2ApiAdminOllamaCloudUsageModel>
final
plan → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sevenDay → Sub2ApiAdminOllamaCloudUsageWindow?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited