Sub2ApiAdminOllamaCloudUsageSettings class final

Constructors

Sub2ApiAdminOllamaCloudUsageSettings({required bool enabled, required int intervalMinutes, required int debounceMinutes})
const

Properties

debounceMinutes → int
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
intervalMinutes → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited