Sub2ApiAdminOllamaCloudUsageSnapshot class final
Constructors
- Sub2ApiAdminOllamaCloudUsageSnapshot({required String status, required DateTime lastAttemptAt, required DateTime nextRefreshAt, required int failureCount, required int httpStatus, required String lastError, Sub2ApiAdminOllamaCloudUsageData? data, DateTime? fetchedAt})
-
const
Properties
- data → Sub2ApiAdminOllamaCloudUsageData?
-
final
- failureCount → int
-
final
- fetchedAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpStatus → int
-
final
- lastAttemptAt → DateTime
-
final
- lastError → String
-
final
- nextRefreshAt → DateTime
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited