Sub2ApiAdminOllamaCloudUsageWindow class final

Constructors

Sub2ApiAdminOllamaCloudUsageWindow({required Sub2ApiDecimal usedPercent, required String resetText, DateTime? resetAt})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
resetAt → DateTime?
final
resetText → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usedPercent → Sub2ApiDecimal
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited