Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createFromCodexPat(
Sub2ApiAdminCreateOpenAIFromCodexPatRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminAccount> -
createFromOAuth(
Sub2ApiAdminCreateOpenAIFromOAuthRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminAccount> -
exchangeCode(
Sub2ApiAdminOpenAIExchangeCodeRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminOpenAITokenInfo> -
generateAuthUrl(
{Sub2ApiAdminOpenAIAuthUrlRequest request = const Sub2ApiAdminOpenAIAuthUrlRequest(), Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminOpenAIAuthUrl> -
getQuota(
int accountId, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminOpenAIQuotaUsage> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshAccountToken(
int accountId, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminAccount> -
refreshQuota(
int accountId, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminOpenAIQuotaUsage> -
refreshToken(
Sub2ApiAdminOpenAIRefreshTokenRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminOpenAITokenInfo> -
resetQuota(
int accountId, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminOpenAIQuotaResetResult> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited