Sub2ApiAdminOpenAIConsumedResetCredit class final

Constructors

Sub2ApiAdminOpenAIConsumedResetCredit({required String id, required String resetType, required String status, DateTime? grantedAt, DateTime? expiresAt, DateTime? redeemStartedAt, DateTime? redeemedAt})
const

Properties

expiresAt → DateTime?
final
grantedAt → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
redeemedAt → DateTime?
final
redeemStartedAt → DateTime?
final
resetType → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited