Sub2ApiAdminOpenAIExchangeCodeRequest class final

Constructors

Sub2ApiAdminOpenAIExchangeCodeRequest({required Sub2ApiAdminOAuthSessionId sessionId, required Sub2ApiOAuthAuthorizationCode code, required Sub2ApiAdminOAuthState state, Uri? redirectUri, int? proxyId})
const

Properties

code → Sub2ApiOAuthAuthorizationCode
final
hashCode → int
The hash code for this object.
no setterinherited
proxyId → int?
final
redirectUri → Uri?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → Sub2ApiAdminOAuthSessionId
final
state → Sub2ApiAdminOAuthState
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited