Sub2ApiAdminOpenAIFastPolicyRule class final

Constructors

Sub2ApiAdminOpenAIFastPolicyRule({required String serviceTier, required String action, required String scope, List<int> userIds = const <int>[], String errorMessage = '', List<String> modelWhitelist = const <String>[], String fallbackAction = '', String fallbackErrorMessage = ''})

Properties

action → String
final
errorMessage → String
final
fallbackAction → String
final
fallbackErrorMessage → String
final
hashCode → int
The hash code for this object.
no setterinherited
modelWhitelist → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → String
final
serviceTier → String
final
userIds → List<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited