Sub2ApiAdminOpenAIQuotaResetResult class final
Constructors
- Sub2ApiAdminOpenAIQuotaResetResult({required String code, required int windowsReset, required bool cacheRefreshed, required bool accountStateRecovered, required String warningCode, Sub2ApiAdminOpenAIConsumedResetCredit? credit, Sub2ApiAdminOpenAIQuotaUsage? quota, Sub2ApiAdminAccount? account})
-
const
Properties
- account → Sub2ApiAdminAccount?
-
final
- accountStateRecovered → bool
-
final
- cacheRefreshed → bool
-
final
- code → String
-
final
- credit → Sub2ApiAdminOpenAIConsumedResetCredit?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- quota → Sub2ApiAdminOpenAIQuotaUsage?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- warningCode → String
-
final
- windowsReset → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited