Sub2ApiAdminOpenAIQuotaUsage class final
Constructors
-
Sub2ApiAdminOpenAIQuotaUsage({required String userId, required String accountId, required String email, required String planType, required List<
Sub2ApiAdminOpenAIAdditionalRateLimit> additionalRateLimits, required DateTime fetchedAt, Sub2ApiAdminOpenAIRateLimit? rateLimit, Sub2ApiAdminOpenAIResetCredits? resetCredits, bool? cachePersisted})
Properties
- accountId → String
-
final
-
additionalRateLimits
→ List<
Sub2ApiAdminOpenAIAdditionalRateLimit> -
final
- cachePersisted → bool?
-
final
- email → String
-
final
- fetchedAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- planType → String
-
final
- rateLimit → Sub2ApiAdminOpenAIRateLimit?
-
final
- resetCredits → Sub2ApiAdminOpenAIResetCredits?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited