Sub2ApiAdminOpenAIResetCredits class final

Constructors

Sub2ApiAdminOpenAIResetCredits({required int availableCount, required List<Sub2ApiAdminOpenAIResetCreditDetail> credits})

Properties

availableCount → int
final
credits → List<Sub2ApiAdminOpenAIResetCreditDetail>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited