Sub2ApiAdminOpenAITokenInfo class final
Constructors
- Sub2ApiAdminOpenAITokenInfo({required Sub2ApiAccessToken accessToken, required Sub2ApiRefreshToken refreshToken, required Duration expiresIn, required DateTime expiresAt, required String clientId, required String authMode, required String email, required String chatGptAccountId, required String chatGptUserId, required bool chatGptAccountFedRamp, required String organizationId, required String planType, required DateTime? subscriptionExpiresAt, required String privacyMode, Sub2ApiOpenAIIdToken? idToken})
-
const
Properties
- accessToken → Sub2ApiAccessToken
-
final
- authMode → String
-
final
- chatGptAccountFedRamp → bool
-
final
- chatGptAccountId → String
-
final
- chatGptUserId → String
-
final
- clientId → String
-
final
- email → String
-
final
- expiresAt → DateTime
-
final
- expiresIn → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idToken → Sub2ApiOpenAIIdToken?
-
final
- organizationId → String
-
final
- planType → String
-
final
- privacyMode → String
-
final
- refreshToken → Sub2ApiRefreshToken
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriptionExpiresAt → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited