Sub2ApiAdminOpsAccountAvailability class final
Constructors
- Sub2ApiAdminOpsAccountAvailability({required int accountId, required String accountName, required String platform, required int groupId, required String groupName, required String status, required bool isAvailable, required bool isRateLimited, required bool isOverloaded, required bool hasError, DateTime? rateLimitResetAt, int? rateLimitRemainingSeconds, DateTime? overloadUntil, int? overloadRemainingSeconds, required String errorMessage, DateTime? tempUnschedulableUntil})
-
const
Properties
- accountId → int
-
final
- accountName → String
-
final
- errorMessage → String
-
final
- groupId → int
-
final
- groupName → String
-
final
- hasError → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAvailable → bool
-
final
- isOverloaded → bool
-
final
- isRateLimited → bool
-
final
- overloadRemainingSeconds → int?
-
final
- overloadUntil → DateTime?
-
final
- platform → String
-
final
- rateLimitRemainingSeconds → int?
-
final
- rateLimitResetAt → DateTime?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
final
- tempUnschedulableUntil → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited