Sub2ApiAdminOpsAccountConcurrency class final

Constructors

Sub2ApiAdminOpsAccountConcurrency({required int accountId, required String accountName, required String platform, required int groupId, required String groupName, required int currentInUse, required int maxCapacity, required Sub2ApiDecimal loadPercentage, required int waitingInQueue})
const

Properties

accountId → int
final
accountName → String
final
currentInUse → int
final
groupId → int
final
groupName → String
final
hashCode → int
The hash code for this object.
no setterinherited
loadPercentage → Sub2ApiDecimal
final
maxCapacity → int
final
platform → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
waitingInQueue → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited