Sub2ApiAdminOpsAdvancedSettings class final
Constructors
- Sub2ApiAdminOpsAdvancedSettings({required Sub2ApiAdminOpsDataRetentionSettings dataRetention, required Sub2ApiAdminOpsAggregationSettings aggregation, required Sub2ApiAdminOpsQuotaAutoPauseSettings openAIAccountQuotaAutoPause, required bool ignoreCountTokensErrors, required bool ignoreContextCanceled, required bool ignoreNoAvailableAccounts, required bool ignoreInvalidApiKeyErrors, required bool ignoreInsufficientBalanceErrors, required bool displayOpenAITokenStats, required bool displayAlertEvents, required bool autoRefreshEnabled, required int autoRefreshIntervalSeconds})
-
const
Properties
- aggregation → Sub2ApiAdminOpsAggregationSettings
-
final
- autoRefreshEnabled → bool
-
final
- autoRefreshIntervalSeconds → int
-
final
- dataRetention → Sub2ApiAdminOpsDataRetentionSettings
-
final
- displayAlertEvents → bool
-
final
- displayOpenAITokenStats → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ignoreContextCanceled → bool
-
final
- ignoreCountTokensErrors → bool
-
final
- ignoreInsufficientBalanceErrors → bool
-
final
- ignoreInvalidApiKeyErrors → bool
-
final
- ignoreNoAvailableAccounts → bool
-
final
- openAIAccountQuotaAutoPause → Sub2ApiAdminOpsQuotaAutoPauseSettings
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited