Sub2ApiAdminOpsAlertMetricType enum

Inheritance
Available extensions

Values

successRate → const Sub2ApiAdminOpsAlertMetricType
errorRate → const Sub2ApiAdminOpsAlertMetricType
upstreamErrorRate → const Sub2ApiAdminOpsAlertMetricType
cpuUsagePercent → const Sub2ApiAdminOpsAlertMetricType
memoryUsagePercent → const Sub2ApiAdminOpsAlertMetricType
concurrencyQueueDepth → const Sub2ApiAdminOpsAlertMetricType
groupAvailableAccounts → const Sub2ApiAdminOpsAlertMetricType
groupAvailableRatio → const Sub2ApiAdminOpsAlertMetricType
groupRateLimitRatio → const Sub2ApiAdminOpsAlertMetricType
accountRateLimitedCount → const Sub2ApiAdminOpsAlertMetricType
accountErrorCount → const Sub2ApiAdminOpsAlertMetricType
accountErrorRatio → const Sub2ApiAdminOpsAlertMetricType
accountTempUnscheduledCount → const Sub2ApiAdminOpsAlertMetricType
overloadAccountCount → const Sub2ApiAdminOpsAlertMetricType
proxyExpiredCount → const Sub2ApiAdminOpsAlertMetricType
proxyExpiringSoonCount → const Sub2ApiAdminOpsAlertMetricType

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<Sub2ApiAdminOpsAlertMetricType>
A constant List of the values in this enum, in order of their declaration.