Sub2ApiAdminOpsAlertRule class final

Constructors

Sub2ApiAdminOpsAlertRule({required int id, required String name, required String description, required bool enabled, required Sub2ApiAdminOpsAlertSeverity severity, required Sub2ApiAdminOpsAlertMetricType metricType, required Sub2ApiAdminOpsAlertOperator operator, required Sub2ApiDecimal threshold, required int windowMinutes, required int sustainedMinutes, required int cooldownMinutes, required bool notifyEmail, required Sub2ApiAdminJsonObject filters, DateTime? lastTriggeredAt, required DateTime createdAt, required DateTime updatedAt})
const

Properties

cooldownMinutes → int
final
createdAt → DateTime
final
description → String
final
enabled → bool
final
filters → Sub2ApiAdminJsonObject
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
lastTriggeredAt → DateTime?
final
metricType → Sub2ApiAdminOpsAlertMetricType
final
name → String
final
notifyEmail → bool
final
operator → Sub2ApiAdminOpsAlertOperator
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity → Sub2ApiAdminOpsAlertSeverity
final
sustainedMinutes → int
final
threshold → Sub2ApiDecimal
final
updatedAt → DateTime
final
windowMinutes → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited