Sub2ApiAdminOpsAlertRuntimeSettings class final
Constructors
- Sub2ApiAdminOpsAlertRuntimeSettings({required int evaluationIntervalSeconds, required Sub2ApiAdminOpsDistributedLockSettings distributedLock, required Sub2ApiAdminOpsAlertSilencingSettings silencing, required Sub2ApiAdminOpsMetricThresholds thresholds})
-
const
Properties
- distributedLock → Sub2ApiAdminOpsDistributedLockSettings
-
final
- evaluationIntervalSeconds → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- silencing → Sub2ApiAdminOpsAlertSilencingSettings
-
final
- thresholds → Sub2ApiAdminOpsMetricThresholds
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited