Sub2ApiAdminOpsAlertSilence class final
Constructors
Properties
- createdAt → DateTime
-
final
- createdByUserId → int?
-
final
- groupId → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- platform → String
-
final
- reason → String
-
final
- region → String?
-
final
- ruleId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- until → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited