Sub2ApiAdminOpsAlertSilenceEntry class final

Constructors

Sub2ApiAdminOpsAlertSilenceEntry({int? ruleId, List<Sub2ApiAdminOpsAlertSeverity> severities = const <Sub2ApiAdminOpsAlertSeverity>[], required DateTime until, String reason = ''})

Properties

hashCode → int
The hash code for this object.
no setterinherited
reason → String
final
ruleId → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severities → List<Sub2ApiAdminOpsAlertSeverity>
final
until → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited