Sub2ApiAdminOpsAuthCacheInvalidationHealth class final

Properties

hashCode → int
The hash code for this object.
no setterinherited
invalidAbuse → Sub2ApiAdminOpsInvalidAuthAbuseHealth
final
lookup → Sub2ApiAdminOpsAuthLookupHealth
final
outbox → Sub2ApiAdminOpsAuthCacheOutboxHealth
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriber → Sub2ApiAdminOpsAuthCacheSubscriberHealth
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited