Sub2ApiAdminOpsAuthCacheOutboxHealth class final

Constructors

Sub2ApiAdminOpsAuthCacheOutboxHealth({required bool running, required int processed, required int failures, required int pending, required Duration oldestLag, required String lastError, required String statsError, required Duration healthySla, required Duration recoverySla, required int maxAttempts})
const

Properties

failures → int
final
hashCode → int
The hash code for this object.
no setterinherited
healthySla → Duration
final
lastError → String
final
maxAttempts → int
final
oldestLag → Duration
final
pending → int
final
processed → int
final
recoverySla → Duration
final
running → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statsError → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited