Sub2ApiAdminOpsAvailabilitySnapshot class final

Constructors

Sub2ApiAdminOpsAvailabilitySnapshot({required bool enabled, required Map<String, Sub2ApiAdminOpsPlatformAvailability> platforms, required Map<int, Sub2ApiAdminOpsGroupAvailability> groups, required Map<int, Sub2ApiAdminOpsAccountAvailability> accounts, required DateTime timestamp})

Properties

accounts → Map<int, Sub2ApiAdminOpsAccountAvailability>
final
enabled → bool
final
groups → Map<int, Sub2ApiAdminOpsGroupAvailability>
final
hashCode → int
The hash code for this object.
no setterinherited
platforms → Map<String, Sub2ApiAdminOpsPlatformAvailability>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited