Sub2ApiAdminOpsDashboardSnapshot class final

Constructors

Sub2ApiAdminOpsDashboardSnapshot({required DateTime generatedAt, required Sub2ApiAdminOpsDashboardOverview overview, required Sub2ApiAdminOpsThroughputTrend throughputTrend, required Sub2ApiAdminOpsErrorTrend errorTrend})
const

Properties

errorTrend → Sub2ApiAdminOpsErrorTrend
final
generatedAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
overview → Sub2ApiAdminOpsDashboardOverview
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
throughputTrend → Sub2ApiAdminOpsThroughputTrend
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited