Sub2ApiAdminOpsDataRetentionSettings class final

Constructors

Sub2ApiAdminOpsDataRetentionSettings({required bool cleanupEnabled, required String cleanupSchedule, required int errorLogRetentionDays, required int minuteMetricsRetentionDays, required int hourlyMetricsRetentionDays})
const

Properties

cleanupEnabled → bool
final
cleanupSchedule → String
final
errorLogRetentionDays → int
final
hashCode → int
The hash code for this object.
no setterinherited
hourlyMetricsRetentionDays → int
final
minuteMetricsRetentionDays → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited