Sub2ApiAdminOpsEmailNotificationConfig class final
Constructors
- Sub2ApiAdminOpsEmailNotificationConfig({required Sub2ApiAdminOpsEmailAlertConfig alert, required Sub2ApiAdminOpsEmailReportConfig report})
-
const
Properties
- alert → Sub2ApiAdminOpsEmailAlertConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- report → Sub2ApiAdminOpsEmailReportConfig
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited