Sub2ApiAdminOpsErrorDistribution class final

Constructors

Sub2ApiAdminOpsErrorDistribution({required int total, required List<Sub2ApiAdminOpsErrorDistributionItem> items})

Properties

hashCode → int
The hash code for this object.
no setterinherited
items → List<Sub2ApiAdminOpsErrorDistributionItem>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited