Sub2ApiAdminOpsErrorDistributionItem class final

Constructors

Sub2ApiAdminOpsErrorDistributionItem({required int statusCode, required int total, required int sla, required int businessLimited})
const

Properties

businessLimited → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sla → int
final
statusCode → int
final
total → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited