Sub2ApiAdminOpsErrorQuery class final
Constructors
-
Sub2ApiAdminOpsErrorQuery({int page = 1, int pageSize = 20, Sub2ApiAdminOpsTimeRange timeRange = Sub2ApiAdminOpsTimeRange.oneHour, DateTime? startAt, DateTime? endAt, Sub2ApiAdminOpsErrorView view = Sub2ApiAdminOpsErrorView.errors, String? phase, String? owner, String? source, String? query, String? userQuery, String? model, String? category, String? platform, int? groupId, int? accountId, int? userId, int? apiKeyId, bool? resolved, List<
int> statusCodes = const <int>[], Sub2ApiAdminOpsErrorSortBy sortBy = Sub2ApiAdminOpsErrorSortBy.createdAt, Sub2ApiAdminOpsSortOrder sortOrder = Sub2ApiAdminOpsSortOrder.descending}) -
const
Properties
- accountId → int?
-
final
- apiKeyId → int?
-
final
- category → String?
-
final
- endAt → DateTime?
-
final
- groupId → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- model → String?
-
final
- owner → String?
-
final
- page → int
-
final
- pageSize → int
-
final
- phase → String?
-
final
- platform → String?
-
final
- query → String?
-
final
- resolved → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortBy → Sub2ApiAdminOpsErrorSortBy
-
final
- sortOrder → Sub2ApiAdminOpsSortOrder
-
final
- source → String?
-
final
- startAt → DateTime?
-
final
-
statusCodes
→ List<
int> -
final
- timeRange → Sub2ApiAdminOpsTimeRange
-
final
- userId → int?
-
final
- userQuery → String?
-
final
- view → Sub2ApiAdminOpsErrorView
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited