Sub2ApiAdminOpsErrorTrend class final

Constructors

Sub2ApiAdminOpsErrorTrend({required String bucket, required List<Sub2ApiAdminOpsErrorTrendPoint> points})

Properties

bucket → String
final
hashCode → int
The hash code for this object.
no setterinherited
points → List<Sub2ApiAdminOpsErrorTrendPoint>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited