Sub2ApiAdminOpsErrorTrendPoint class final

Constructors

Sub2ApiAdminOpsErrorTrendPoint({required DateTime bucketStart, required int errorCountTotal, required int businessLimitedCount, required int errorCountSla, required int upstreamErrorCountExcluding429And529, required int upstream429Count, required int upstream529Count})
const

Properties

bucketStart → DateTime
final
businessLimitedCount → int
final
errorCountSla → int
final
errorCountTotal → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
upstream429Count → int
final
upstream529Count → int
final
upstreamErrorCountExcluding429And529 → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited