Sub2ApiAdminOpsGroupAvailability class final

Constructors

Sub2ApiAdminOpsGroupAvailability({required int groupId, required String groupName, required String platform, required int totalAccounts, required int availableCount, required int rateLimitCount, required int errorCount})
const

Properties

availableCount → int
final
errorCount → int
final
groupId → int
final
groupName → String
final
hashCode → int
The hash code for this object.
no setterinherited
platform → String
final
rateLimitCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalAccounts → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited