Sub2ApiAdminOpsIngressRejectHealth class final
Constructors
- Sub2ApiAdminOpsIngressRejectHealth({required int cardinality, required int capacity, required int pendingBatches, required int pendingRows, required int overflowedCount, required int droppedCount, required int flushedRequestCount, required int flushFailureCount, required bool accepting, required String lastError})
-
const
Properties
- accepting → bool
-
final
- capacity → int
-
final
- cardinality → int
-
final
- droppedCount → int
-
final
- flushedRequestCount → int
-
final
- flushFailureCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastError → String
-
final
- overflowedCount → int
-
final
- pendingBatches → int
-
final
- pendingRows → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited