Sub2ApiAdminOpsIngressRejectReason enum
Values
- queryApiKeyDeprecated → const Sub2ApiAdminOpsIngressRejectReason
- apiKeyRequired → const Sub2ApiAdminOpsIngressRejectReason
- invalidApiKey → const Sub2ApiAdminOpsIngressRejectReason
- invalidAuthRateLimited → const Sub2ApiAdminOpsIngressRejectReason
- apiKeyAuthOverloaded → const Sub2ApiAdminOpsIngressRejectReason
- apiKeyDisabled → const Sub2ApiAdminOpsIngressRejectReason
- ipRestricted → const Sub2ApiAdminOpsIngressRejectReason
- userInactive → const Sub2ApiAdminOpsIngressRejectReason
- groupDeleted → const Sub2ApiAdminOpsIngressRejectReason
- groupDisabled → const Sub2ApiAdminOpsIngressRejectReason
- groupNotAllowed → const Sub2ApiAdminOpsIngressRejectReason
- groupUnassigned → const Sub2ApiAdminOpsIngressRejectReason
- other → const Sub2ApiAdminOpsIngressRejectReason
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
Sub2ApiAdminOpsIngressRejectReason> - A constant List of the values in this enum, in order of their declaration.