Sub2ApiAdminOpsIngressRejectRecord class final
Constructors
- Sub2ApiAdminOpsIngressRejectRecord({required int id, required DateTime bucketStart, required Sub2ApiAdminOpsIngressRejectReason reason, required Sub2ApiAdminOpsIngressRouteFamily routeFamily, required Sub2ApiAdminOpsIngressProtocol protocol, Sub2ApiAdminOpsClientAddress? clientAddress, int? userId, int? apiKeyId, required int requestCount, required DateTime firstSeen, required DateTime lastSeen})
-
const
Properties
- apiKeyId → int?
-
final
- bucketStart → DateTime
-
final
- clientAddress → Sub2ApiAdminOpsClientAddress?
-
final
- firstSeen → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- lastSeen → DateTime
-
final
- protocol → Sub2ApiAdminOpsIngressProtocol
-
final
- reason → Sub2ApiAdminOpsIngressRejectReason
-
final
- requestCount → int
-
final
- routeFamily → Sub2ApiAdminOpsIngressRouteFamily
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited