Sub2ApiAdminOpsInvalidAuthAbuseHealth class final

Constructors

Sub2ApiAdminOpsInvalidAuthAbuseHealth({required bool enabled, required int tracked, required int capacity, required int recorded, required int blocks, required int rejected, required int expired, required int overflowed, required int globalBlocked})
const

Properties

blocks → int
final
capacity → int
final
enabled → bool
final
expired → int
final
globalBlocked → int
final
hashCode → int
The hash code for this object.
no setterinherited
overflowed → int
final
recorded → int
final
rejected → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tracked → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited