Sub2ApiAdminOpsJobHeartbeat class final

Constructors

Sub2ApiAdminOpsJobHeartbeat({required String jobName, DateTime? lastRunAt, DateTime? lastSuccessAt, DateTime? lastErrorAt, required String lastError, int? lastDurationMs, required String lastResult, required DateTime updatedAt})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
jobName → String
final
lastDurationMs → int?
final
lastError → String
final
lastErrorAt → DateTime?
final
lastResult → String
final
lastRunAt → DateTime?
final
lastSuccessAt → DateTime?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited