Sub2ApiAdminOpsMetricThresholds class final

Constructors

Sub2ApiAdminOpsMetricThresholds({Sub2ApiDecimal? slaPercentMin, Sub2ApiDecimal? ttftP99MsMax, Sub2ApiDecimal? requestErrorRatePercentMax, Sub2ApiDecimal? upstreamErrorRatePercentMax})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
requestErrorRatePercentMax → Sub2ApiDecimal?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slaPercentMin → Sub2ApiDecimal?
final
ttftP99MsMax → Sub2ApiDecimal?
final
upstreamErrorRatePercentMax → Sub2ApiDecimal?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited