Sub2ApiAdminOpsObservabilityClient class abstract interface

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cleanupSystemLogs(Sub2ApiAdminOpsSystemLogCleanupRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminOpsSystemLogCleanupResult>
getAuthCacheHealth({Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminOpsAuthCacheInvalidationHealth>
getIngressRejectHealth({Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminOpsIngressRejectHealth>
getSystemLogHealth({Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminOpsSystemLogSinkHealth>
listIngressRejects({Sub2ApiAdminOpsIngressRejectQuery query = const Sub2ApiAdminOpsIngressRejectQuery(), Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminOpsIngressRejectPage>
listSystemLogs({Sub2ApiAdminOpsSystemLogQuery query = const Sub2ApiAdminOpsSystemLogQuery(), Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminOpsSystemLogPage>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited