Sub2ApiAdminOpsOpenAITokenStats class final

Constructors

Sub2ApiAdminOpsOpenAITokenStats({required String timeRange, required DateTime startAt, required DateTime endAt, required String platform, int? groupId, required List<Sub2ApiAdminOpsOpenAITokenStatsItem> items, required int total, required int page, required int pageSize, int? topN})

Properties

endAt → DateTime
final
groupId → int?
final
hashCode → int
The hash code for this object.
no setterinherited
items → List<Sub2ApiAdminOpsOpenAITokenStatsItem>
final
page → int
final
pageSize → int
final
platform → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startAt → DateTime
final
timeRange → String
final
topN → int?
final
total → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited