Sub2ApiAdminOpsOpenAITokenStatsItem class final

Constructors

Sub2ApiAdminOpsOpenAITokenStatsItem({required String model, required int requestCount, Sub2ApiDecimal? averageTokensPerSecond, Sub2ApiDecimal? averageFirstTokenMs, required int totalOutputTokens, required int averageDurationMs, required int requestsWithFirstToken})
const

Properties

averageDurationMs → int
final
averageFirstTokenMs → Sub2ApiDecimal?
final
averageTokensPerSecond → Sub2ApiDecimal?
final
hashCode → int
The hash code for this object.
no setterinherited
model → String
final
requestCount → int
final
requestsWithFirstToken → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalOutputTokens → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited