Sub2ApiAdminOpsOpenAITokenStatsQuery class final

Constructors

Sub2ApiAdminOpsOpenAITokenStatsQuery({Sub2ApiAdminOpsOpenAITimeRange timeRange = Sub2ApiAdminOpsOpenAITimeRange.thirtyDays, String? platform, int? groupId, int page = 1, int pageSize = 20, int? topN})
const

Properties

groupId → int?
final
hashCode → int
The hash code for this object.
no setterinherited
page → int
final
pageSize → int
final
platform → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeRange → Sub2ApiAdminOpsOpenAITimeRange
final
topN → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited