Sub2ApiAdminOpsPercentiles class final

Constructors

Sub2ApiAdminOpsPercentiles({int? p50Ms, int? p90Ms, int? p95Ms, int? p99Ms, int? averageMs, int? maxMs})
const

Properties

averageMs → int?
final
hashCode → int
The hash code for this object.
no setterinherited
maxMs → int?
final
p50Ms → int?
final
p90Ms → int?
final
p95Ms → int?
final
p99Ms → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited