Sub2ApiAdminOpsQuotaAutoPauseSettings class final
Constructors
- Sub2ApiAdminOpsQuotaAutoPauseSettings({required Sub2ApiDecimal defaultThreshold5h, required Sub2ApiDecimal defaultThreshold7d})
-
const
Properties
- defaultThreshold5h → Sub2ApiDecimal
-
final
- defaultThreshold7d → Sub2ApiDecimal
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited