Sub2ApiAdminOpsRealtimeTrafficQuery class final

Constructors

Sub2ApiAdminOpsRealtimeTrafficQuery({Sub2ApiAdminOpsRealtimeWindow window = Sub2ApiAdminOpsRealtimeWindow.oneMinute, String? platform, int? groupId})
const

Properties

groupId → int?
final
hashCode → int
The hash code for this object.
no setterinherited
platform → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
window → Sub2ApiAdminOpsRealtimeWindow
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited