Sub2ApiAdminOpsRequestRecord class final
Constructors
- Sub2ApiAdminOpsRequestRecord({required Sub2ApiAdminOpsRequestKind kind, required DateTime createdAt, required String requestId, required String platform, required String model, int? durationMs, int? statusCode, int? errorId, required String phase, required String severity, Sub2ApiAdminOpsErrorContent? message, int? userId, int? apiKeyId, int? accountId, int? groupId, required bool stream})
-
const
Properties
- accountId → int?
-
final
- apiKeyId → int?
-
final
- createdAt → DateTime
-
final
- durationMs → int?
-
final
- errorId → int?
-
final
- groupId → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → Sub2ApiAdminOpsRequestKind
-
final
- message → Sub2ApiAdminOpsErrorContent?
-
final
- model → String
-
final
- phase → String
-
final
- platform → String
-
final
- requestId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → String
-
final
- statusCode → int?
-
final
- stream → bool
-
final
- userId → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited