Sub2ApiAdminOpsRuntimeLogConfig class final

Constructors

Sub2ApiAdminOpsRuntimeLogConfig({required Sub2ApiAdminOpsRuntimeLogLevel level, required bool enableSampling, required int samplingInitial, required int samplingThereafter, required bool caller, required Sub2ApiAdminOpsStacktraceLevel stacktraceLevel, required int retentionDays, required String source, DateTime? updatedAt, int? updatedByUserId, required Sub2ApiAdminJsonObject extra})
const

Properties

caller → bool
final
enableSampling → bool
final
extra → Sub2ApiAdminJsonObject
final
hashCode → int
The hash code for this object.
no setterinherited
level → Sub2ApiAdminOpsRuntimeLogLevel
final
retentionDays → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplingInitial → int
final
samplingThereafter → int
final
source → String
final
stacktraceLevel → Sub2ApiAdminOpsStacktraceLevel
final
updatedAt → DateTime?
final
updatedByUserId → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited