Sub2ApiAdminOpsRuntimeLogInput class final

Constructors

Sub2ApiAdminOpsRuntimeLogInput({required Sub2ApiAdminOpsRuntimeLogLevel level, required bool enableSampling, required int samplingInitial, required int samplingThereafter, required bool caller, required Sub2ApiAdminOpsStacktraceLevel stacktraceLevel, required int retentionDays})
const

Properties

caller → bool
final
enableSampling → bool
final
hashCode → int
The hash code for this object.
no setterinherited
level → Sub2ApiAdminOpsRuntimeLogLevel
final
retentionDays → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplingInitial → int
final
samplingThereafter → int
final
stacktraceLevel → Sub2ApiAdminOpsStacktraceLevel
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited