Sub2ApiAdminOpsSystemLogFilter class final

Constructors

Sub2ApiAdminOpsSystemLogFilter({DateTime? startAt, DateTime? endAt, String? host, String? level, String? component, String? requestId, String? clientRequestId, int? userId, int? apiKeyId, int? accountId, String? platform, String? model, String? query})
const

Properties

accountId → int?
final
apiKeyId → int?
final
clientRequestId → String?
final
component → String?
final
endAt → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
host → String?
final
level → String?
final
model → String?
final
platform → String?
final
query → String?
final
requestId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startAt → DateTime?
final
userId → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited