Sub2ApiAdminOpsSystemLogRecord class final

Constructors

Sub2ApiAdminOpsSystemLogRecord({required int id, required DateTime createdAt, required String host, required String level, required String component, required Sub2ApiAdminOpsSystemLogContent message, required String requestId, required String clientRequestId, int? userId, int? apiKeyId, int? accountId, required String platform, required String model, Sub2ApiAdminOpsSystemLogContent? extra})
const

Properties

accountId → int?
final
apiKeyId → int?
final
clientRequestId → String
final
component → String
final
createdAt → DateTime
final
extra → Sub2ApiAdminOpsSystemLogContent?
final
hashCode → int
The hash code for this object.
no setterinherited
host → String
final
id → int
final
level → String
final
message → Sub2ApiAdminOpsSystemLogContent
final
model → String
final
platform → String
final
requestId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited