Sub2ApiAdminOpsSystemLogSinkHealth class final

Constructors

Sub2ApiAdminOpsSystemLogSinkHealth({required int queueDepth, required int queueCapacity, required int droppedCount, required int writeFailedCount, required int writtenCount, required Duration averageWriteDelay, required String lastError})
const

Properties

averageWriteDelay → Duration
final
droppedCount → int
final
hashCode → int
The hash code for this object.
no setterinherited
lastError → String
final
queueCapacity → int
final
queueDepth → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
writeFailedCount → int
final
writtenCount → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited