Sub2ApiAdminOpsThroughputGroup class final
Constructors
- Sub2ApiAdminOpsThroughputGroup({required int groupId, required String groupName, required int requestCount, required int tokenConsumed})
-
const
Properties
- groupId → int
-
final
- groupName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenConsumed → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited