Sub2ApiAdminOpsThroughputPoint class final

Constructors

Sub2ApiAdminOpsThroughputPoint({required DateTime bucketStart, required int requestCount, required int tokenConsumed, required int switchCount, required Sub2ApiDecimal qps, required Sub2ApiDecimal tps})
const

Properties

bucketStart → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
qps → Sub2ApiDecimal
final
requestCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
switchCount → int
final
tokenConsumed → int
final
tps → Sub2ApiDecimal
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited