Sub2ApiAdminOpsThroughputTrend class final

Constructors

Sub2ApiAdminOpsThroughputTrend({required String bucket, required List<Sub2ApiAdminOpsThroughputPoint> points, required List<Sub2ApiAdminOpsThroughputPlatform> byPlatform, required List<Sub2ApiAdminOpsThroughputGroup> topGroups})

Properties

bucket → String
final
byPlatform → List<Sub2ApiAdminOpsThroughputPlatform>
final
hashCode → int
The hash code for this object.
no setterinherited
points → List<Sub2ApiAdminOpsThroughputPoint>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topGroups → List<Sub2ApiAdminOpsThroughputGroup>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited