Sub2ApiAdminOpsUserConcurrencySnapshot class final

Constructors

Sub2ApiAdminOpsUserConcurrencySnapshot({required bool enabled, required Map<int, Sub2ApiAdminOpsUserConcurrency> users, required DateTime timestamp})

Properties

enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
final
users → Map<int, Sub2ApiAdminOpsUserConcurrency>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited