Sub2ApiAdminPanelRateLimitSettings class final

Constructors

Sub2ApiAdminPanelRateLimitSettings({required bool enabled, required int userRpm, required int heavyRpm, required bool exemptAdmin, required int publicIpRpm})
const

Properties

enabled → bool
final
exemptAdmin → bool
final
hashCode → int
The hash code for this object.
no setterinherited
heavyRpm → int
final
publicIpRpm → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userRpm → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited