Sub2ApiAdminPaymentDashboard class final

Constructors

Sub2ApiAdminPaymentDashboard({required Map<String, Sub2ApiDecimal> todayAmount, required Map<String, Sub2ApiDecimal> totalAmount, required int todayCount, required int totalCount, required Map<String, Sub2ApiDecimal> averageAmount, required int pendingOrders, required List<Sub2ApiAdminPaymentDailyStat> dailySeries, required List<Sub2ApiAdminPaymentMethodStat> paymentMethods, required Map<String, List<Sub2ApiAdminPaymentTopUser>> topUsers})

Properties

averageAmount → Map<String, Sub2ApiDecimal>
final
dailySeries → List<Sub2ApiAdminPaymentDailyStat>
final
hashCode → int
The hash code for this object.
no setterinherited
paymentMethods → List<Sub2ApiAdminPaymentMethodStat>
final
pendingOrders → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
todayAmount → Map<String, Sub2ApiDecimal>
final
todayCount → int
final
topUsers → Map<String, List<Sub2ApiAdminPaymentTopUser>>
final
totalAmount → Map<String, Sub2ApiDecimal>
final
totalCount → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited