Sub2ApiAdminPaymentMethodStat class final

Constructors

Sub2ApiAdminPaymentMethodStat({required String type, required Map<String, Sub2ApiDecimal> amount, required int count})

Properties

amount → Map<String, Sub2ApiDecimal>
final
count → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited