Sub2ApiAdminPaymentOrder class final

Constructors

Sub2ApiAdminPaymentOrder({required int id, required int userId, required String userEmail, required String userName, required Sub2ApiDecimal amount, required Sub2ApiDecimal payAmount, required Sub2ApiDecimal feeRate, required String currency, required String outTradeNo, required String paymentType, required String paymentTradeNo, required String orderType, required String status, required Sub2ApiDecimal refundAmount, required bool forceRefund, required DateTime expiresAt, required String clientIp, required String srcHost, required DateTime createdAt, required DateTime updatedAt, String? userNotes, Sub2ApiRedeemCodeSecret? rechargeCode, Sub2ApiAdminPaymentCheckoutSecret? payUrl, Sub2ApiAdminPaymentCheckoutSecret? qrCode, Sub2ApiAdminPaymentCheckoutSecret? qrCodeImage, int? planId, int? subscriptionGroupId, int? subscriptionDays, String? providerInstanceId, String? providerKey, String? refundReason, DateTime? refundAt, DateTime? refundRequestedAt, String? refundRequestReason, String? refundRequestedBy, DateTime? paidAt, DateTime? completedAt, DateTime? failedAt, String? failedReason, String? srcUrl})
const

Properties

amount → Sub2ApiDecimal
final
clientIp → String
final
completedAt → DateTime?
final
createdAt → DateTime
final
currency → String
final
expiresAt → DateTime
final
failedAt → DateTime?
final
failedReason → String?
final
feeRate → Sub2ApiDecimal
final
forceRefund → bool
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
orderType → String
final
outTradeNo → String
final
paidAt → DateTime?
final
payAmount → Sub2ApiDecimal
final
paymentTradeNo → String
final
paymentType → String
final
payUrl → Sub2ApiAdminPaymentCheckoutSecret?
final
planId → int?
final
providerInstanceId → String?
final
providerKey → String?
final
qrCode → Sub2ApiAdminPaymentCheckoutSecret?
final
qrCodeImage → Sub2ApiAdminPaymentCheckoutSecret?
final
rechargeCode → Sub2ApiRedeemCodeSecret?
final
refundAmount → Sub2ApiDecimal
final
refundAt → DateTime?
final
refundReason → String?
final
refundRequestedAt → DateTime?
final
refundRequestedBy → String?
final
refundRequestReason → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
srcHost → String
final
srcUrl → String?
final
status → String
final
subscriptionDays → int?
final
subscriptionGroupId → int?
final
updatedAt → DateTime
final
userEmail → String
final
userId → int
final
userName → String
final
userNotes → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited