Sub2ApiAdminPaymentOrderDetail class final
Constructors
-
Sub2ApiAdminPaymentOrderDetail({required Sub2ApiAdminPaymentOrder order, required List<
Sub2ApiAdminPaymentAuditLog> auditLogs})
Properties
-
auditLogs
→ List<
Sub2ApiAdminPaymentAuditLog> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- order → Sub2ApiAdminPaymentOrder
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited