Sub2ApiAdminPaymentOrderQuery class final

Constructors

Sub2ApiAdminPaymentOrderQuery({int page = 1, int pageSize = 20, int? userId, String? status, String? orderType, String? paymentType, String? keyword})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyword → String?
final
orderType → String?
final
page → int
final
pageSize → int
final
paymentType → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
final
userId → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited