Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(
int id, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminPaymentActionResult> -
get(
int id, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminPaymentOrderDetail> -
getDashboard(
{int days = 30, Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminPaymentDashboard> -
list(
{Sub2ApiAdminPaymentOrderQuery query = const Sub2ApiAdminPaymentOrderQuery(), Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminPaymentOrderPage> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryRefund(
int id, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminPaymentRefundResult> -
refund(
int id, Sub2ApiAdminProcessRefundRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminPaymentRefundResult> -
retryFulfillment(
int id, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminPaymentActionResult> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited