Sub2ApiAdminPaymentProvider class final

Constructors

Sub2ApiAdminPaymentProvider({required int id, required Sub2ApiAdminPaymentProviderKey providerKey, required String name, required Map<String, String> visibleConfig, required List<String> supportedTypes, required bool enabled, required String paymentMode, required int sortOrder, required String limits, required bool refundEnabled, required bool allowUserRefund})

Properties

allowUserRefund → bool
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
limits → String
final
name → String
final
paymentMode → String
final
providerKey → Sub2ApiAdminPaymentProviderKey
final
refundEnabled → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortOrder → int
final
supportedTypes → List<String>
final
visibleConfig → Map<String, String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited