Sub2ApiAdminPaymentRefundResult class final

Constructors

Sub2ApiAdminPaymentRefundResult({required bool success, required String warning, required bool requireForce, required Sub2ApiDecimal balanceDeducted, required int subscriptionDaysDeducted})
const

Properties

balanceDeducted → Sub2ApiDecimal
final
hashCode → int
The hash code for this object.
no setterinherited
requireForce → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriptionDaysDeducted → int
final
success → bool
final
warning → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited