Sub2ApiAdminPaymentTopUser class final

Constructors

Sub2ApiAdminPaymentTopUser({required int userId, required String email, required Sub2ApiDecimal amount})
const

Properties

amount → Sub2ApiDecimal
final
email → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited