Sub2ApiAdminPlatformQuota class final
Constructors
- Sub2ApiAdminPlatformQuota({Sub2ApiDecimal? dailyLimitUsd, Sub2ApiDecimal? weeklyLimitUsd, Sub2ApiDecimal? monthlyLimitUsd})
-
const
Properties
- dailyLimitUsd → Sub2ApiDecimal?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- monthlyLimitUsd → Sub2ApiDecimal?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- weeklyLimitUsd → Sub2ApiDecimal?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited