Sub2ApiAdminPluginBinding class final

Constructors

Sub2ApiAdminPluginBinding({required int id, required int pluginId, required String capability, required String platform, required String accountType, required bool enabled, required int rolloutPercent, required DateTime createdAt, required DateTime updatedAt})
const

Properties

accountType → String
final
capability → String
final
createdAt → DateTime
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
platform → String
final
pluginId → int
final
rolloutPercent → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited