Sub2ApiAdminPluginCapability class final

Constructors

Sub2ApiAdminPluginCapability({required String id, required String platform, required String accountType})
const

Properties

accountType → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
platform → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited