Sub2ApiAdminPluginCompatibility class final
Constructors
- Sub2ApiAdminPluginCompatibility({required bool compatible, required bool tested, required String status, required String message, required String currentSub2apiVersion, required String requiredSub2apiVersion, required String recommendedSub2apiVersion, required int pluginProtocol, required int transportApi, required int uiBridge})
-
const
Properties
- compatible → bool
-
final
- currentSub2apiVersion → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- pluginProtocol → int
-
final
- recommendedSub2apiVersion → String
-
final
- requiredSub2apiVersion → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
final
- tested → bool
-
final
- transportApi → int
-
final
- uiBridge → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited