Sub2ApiAdminPluginRequirements class final

Constructors

Sub2ApiAdminPluginRequirements({required String sub2api, required String recommendedSub2apiVersion, required List<String> testedSub2apiVersions, required int pluginProtocol, required int transportApi, required int uiBridge})

Properties

hashCode → int
The hash code for this object.
no setterinherited
pluginProtocol → int
final
recommendedSub2apiVersion → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sub2api → String
final
testedSub2apiVersions → List<String>
final
transportApi → int
final
uiBridge → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited