Sub2ApiAdminPluginUiSession class final

Constructors

Sub2ApiAdminPluginUiSession({required Sub2ApiAdminPluginUiUrl url, required Sub2ApiAdminPluginBridgeToken bridgeToken, required int uiBridgeVersion, required DateTime expiresAt})
const

Properties

bridgeToken → Sub2ApiAdminPluginBridgeToken
final
expiresAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uiBridgeVersion → int
final
url → Sub2ApiAdminPluginUiUrl
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited