Sub2ApiAdminProcessRefundRequest class final
Constructors
- Sub2ApiAdminProcessRefundRequest({required Sub2ApiDecimal amount, String reason = '', bool force = false, bool deductBalance = false})
-
const
Properties
- amount → Sub2ApiDecimal
-
final
- deductBalance → bool
-
final
- force → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- reason → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited