Sub2ApiAdminPromoCodeRecord class final

Constructors

Sub2ApiAdminPromoCodeRecord({required int id, required Sub2ApiPromoCode code, required Sub2ApiDecimal bonusAmount, required int maxUses, required int usedCount, required Sub2ApiAdminPromoCodeStatus status, required DateTime? expiresAt, required String notes, required DateTime createdAt, required DateTime updatedAt})
const

Properties

bonusAmount → Sub2ApiDecimal
final
code → Sub2ApiPromoCode
final
createdAt → DateTime
final
expiresAt → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
maxUses → int
final
notes → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → Sub2ApiAdminPromoCodeStatus
final
updatedAt → DateTime
final
usedCount → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited