Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
Sub2ApiAdminCreatePromoCodeRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminPromoCodeRecord> -
delete(
int id, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminDeletePromoCodeResult> -
get(
int id, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminPromoCodeRecord> -
list(
{Sub2ApiAdminPromoCodeQuery query = const Sub2ApiAdminPromoCodeQuery(), Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminPromoCodePage> -
listUsages(
int id, {int? page, int? pageSize, Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminPromoCodeUsagePage> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
int id, Sub2ApiAdminUpdatePromoCodeRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminPromoCodeRecord>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited