Sub2ApiAdminPromptAuditConfig class final
Constructors
-
Sub2ApiAdminPromptAuditConfig({required bool enabled, required bool blockingEnabled, required bool blockingLatestTurnOnly, required bool storePassEvents, required Sub2ApiAdminPromptAuditMode effectiveMode, required Sub2ApiAdminPromptAuditStrategy strategy, required int workerCount, required int queueCapacity, required List<
String> scanners, required bool allGroups, required List<int> groupIds, required List<Sub2ApiAdminPromptAuditEndpoint> endpoints, required int configVersion, required DateTime updatedAt, required int updatedBy, required String changeSummary})
Properties
- allGroups → bool
-
final
- blockingEnabled → bool
-
final
- blockingLatestTurnOnly → bool
-
final
- changeSummary → String
-
final
- configVersion → int
-
final
- effectiveMode → Sub2ApiAdminPromptAuditMode
-
final
- enabled → bool
-
final
-
endpoints
→ List<
Sub2ApiAdminPromptAuditEndpoint> -
final
-
groupIds
→ List<
int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- queueCapacity → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scanners
→ List<
String> -
final
- storePassEvents → bool
-
final
- strategy → Sub2ApiAdminPromptAuditStrategy
-
final
- updatedAt → DateTime
-
final
- updatedBy → int
-
final
- workerCount → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited