Sub2ApiAdminPromptAuditDeleteByFilterRequest class final
Constructors
- Sub2ApiAdminPromptAuditDeleteByFilterRequest({required Sub2ApiAdminPromptAuditEventFilter filter, required int snapshotMaxId, required Sub2ApiAdminPromptAuditHash filterHash, required Sub2ApiAdminPromptAuditDeleteToken confirmationToken, bool confirm = true})
-
const
Properties
- confirm → bool
-
final
- confirmationToken → Sub2ApiAdminPromptAuditDeleteToken
-
final
- filter → Sub2ApiAdminPromptAuditEventFilter
-
final
- filterHash → Sub2ApiAdminPromptAuditHash
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapshotMaxId → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited