Sub2ApiAdminPromptAuditDeletePreview class final

Constructors

Sub2ApiAdminPromptAuditDeletePreview({required int matchedCount, required Sub2ApiAdminPromptAuditEventFilter filterSummary, required int snapshotMaxId, required Sub2ApiAdminPromptAuditHash filterHash, required Sub2ApiAdminPromptAuditDeleteToken confirmationToken, required DateTime expiresAt})
const

Properties

confirmationToken → Sub2ApiAdminPromptAuditDeleteToken
final
expiresAt → DateTime
final
filterHash → Sub2ApiAdminPromptAuditHash
final
filterSummary → Sub2ApiAdminPromptAuditEventFilter
final
hashCode → int
The hash code for this object.
no setterinherited
matchedCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotMaxId → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited