Sub2ApiAdminPromptAuditEndpoint class final

Constructors

Sub2ApiAdminPromptAuditEndpoint({required String id, required String name, required String protocol, required Uri baseUrl, required String model, required Duration timeout, required int inputLimit, required bool enabled, required bool hasToken, required String tokenStatus})
const

Properties

baseUrl → Uri
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
hasToken → bool
final
id → String
final
inputLimit → int
final
model → String
final
name → String
final
protocol → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeout → Duration
final
tokenStatus → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited