Sub2ApiAdminPromptAuditEndpointUpdate class final

Constructors

Sub2ApiAdminPromptAuditEndpointUpdate({required String id, required String name, required Uri baseUrl, String protocol = 'openai_compatible', String model = 'sileader/qwen3guard:0.6b', Sub2ApiAdminPromptAuditEndpointToken? token, bool clearToken = false, Duration timeout = const Duration(seconds: 3), int inputLimit = 4000, bool enabled = true})
const

Properties

baseUrl → Uri
final
clearToken → bool
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
inputLimit → int
final
model → String
final
name → String
final
protocol → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeout → Duration
final
token → Sub2ApiAdminPromptAuditEndpointToken?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited