Sub2ApiAdminPromptAuditEventFilter class final
Constructors
- Sub2ApiAdminPromptAuditEventFilter({Sub2ApiAdminPromptAuditDecision? decision, Sub2ApiAdminPromptAuditRiskLevel? riskLevel, String? endpoint, int? groupId, int? userId, int? apiKeyId, String? requestId, Sub2ApiAdminPromptAuditHash? promptHash, String? keyword, DateTime? startAt, DateTime? endAt})
-
const
Properties
- apiKeyId → int?
-
final
- decision → Sub2ApiAdminPromptAuditDecision?
-
final
- endAt → DateTime?
-
final
- endpoint → String?
-
final
- groupId → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyword → String?
-
final
- promptHash → Sub2ApiAdminPromptAuditHash?
-
final
- requestId → String?
-
final
- riskLevel → Sub2ApiAdminPromptAuditRiskLevel?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startAt → DateTime?
-
final
- userId → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited