Sub2ApiAdminPromptAuditEventQuery class final

Constructors

Sub2ApiAdminPromptAuditEventQuery({int page = 1, int pageSize = 20, Sub2ApiAdminPromptAuditEventFilter filter = const Sub2ApiAdminPromptAuditEventFilter()})
const

Properties

filter → Sub2ApiAdminPromptAuditEventFilter
final
hashCode → int
The hash code for this object.
no setterinherited
page → int
final
pageSize → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited