Sub2ApiAdminPromptAuditIssue class final

Constructors

Sub2ApiAdminPromptAuditIssue({required String category, required String scannerId, required String title, required String description, required String severity, required String severityLabel, required String action, required String actionLabel, required String code, required Sub2ApiDecimal score, required Sub2ApiAdminPromptAuditEvidence evidence, required Sub2ApiAdminPromptAuditHash evidenceHash, int? startRune, int? endRune})
const

Properties

action → String
final
actionLabel → String
final
category → String
final
code → String
final
description → String
final
endRune → int?
final
evidence → Sub2ApiAdminPromptAuditEvidence
final
evidenceHash → Sub2ApiAdminPromptAuditHash
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scannerId → String
final
score → Sub2ApiDecimal
final
severity → String
final
severityLabel → String
final
startRune → int?
final
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited