Sub2ApiAdminPromptAuditProbeResult class final

Constructors

Sub2ApiAdminPromptAuditProbeResult({required bool ok, required String status, required String errorCode, required String message, required Duration latency, required int httpStatus, required bool retryable, required DateTime checkedAt, required bool tokenApplied})
const

Properties

checkedAt → DateTime
final
errorCode → String
final
hashCode → int
The hash code for this object.
no setterinherited
httpStatus → int
final
latency → Duration
final
message → String
final
ok → bool
final
retryable → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
final
tokenApplied → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited