Sub2ApiAdminPromptAuditQueueStats class final

Constructors

Sub2ApiAdminPromptAuditQueueStats({required int staging, required int queued, required int processing, required int retry, required int done, required int failed, required int active})
const

Properties

active → int
final
done → int
final
failed → int
final
hashCode → int
The hash code for this object.
no setterinherited
processing → int
final
queued → int
final
retry → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
staging → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited