Sub2ApiAdminProxyBatchDeleteResult class final
Constructors
-
Sub2ApiAdminProxyBatchDeleteResult({required List<
int> deletedIds, required List<Sub2ApiAdminProxyBatchDeleteSkipped> skipped})
Properties
-
deletedIds
→ List<
int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
skipped
→ List<
Sub2ApiAdminProxyBatchDeleteSkipped> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited