Sub2ApiAdminProxyDataExportQuery class final
Constructors
- Sub2ApiAdminProxyDataExportQuery({Sub2ApiAdminProxyDataSelector selector = const Sub2ApiAdminProxyDataSelector.all(), Sub2ApiAdminProxySort sortBy = Sub2ApiAdminProxySort.id, bool sortDescending = true})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selector → Sub2ApiAdminProxyDataSelector
-
final
- sortBy → Sub2ApiAdminProxySort
-
final
- sortDescending → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited