Sub2ApiAdminProxyDataImportResult class final

Constructors

Sub2ApiAdminProxyDataImportResult({required int created, required int reused, required int failed, required List<Sub2ApiAdminProxyDataImportError> errors})

Properties

created → int
final
errors → List<Sub2ApiAdminProxyDataImportError>
final
failed → int
final
hashCode → int
The hash code for this object.
no setterinherited
reused → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited