Sub2ApiAdminProxyListQuery class final

Constructors

Sub2ApiAdminProxyListQuery({int? page, int? pageSize, Sub2ApiAdminProxyProtocol? protocol, Sub2ApiAdminProxyStatus? status, String? search, Sub2ApiAdminProxySort sortBy = Sub2ApiAdminProxySort.id, bool sortDescending = true})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
page → int?
final
pageSize → int?
final
protocol → Sub2ApiAdminProxyProtocol?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
final
sortBy → Sub2ApiAdminProxySort
final
sortDescending → bool
final
status → Sub2ApiAdminProxyStatus?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited