Sub2ApiAdminProxyQualityResult class final
Constructors
-
Sub2ApiAdminProxyQualityResult({required int proxyId, required int score, required String grade, required String summary, required String exitIp, required String country, required String countryCode, required int? baseLatencyMs, required int passedCount, required int warnCount, required int failedCount, required int challengeCount, required DateTime checkedAt, required List<
Sub2ApiAdminProxyQualityItem> items})
Properties
- baseLatencyMs → int?
-
final
- challengeCount → int
-
final
- checkedAt → DateTime
-
final
- country → String
-
final
- countryCode → String
-
final
- exitIp → String
-
final
- failedCount → int
-
final
- grade → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
Sub2ApiAdminProxyQualityItem> -
final
- passedCount → int
-
final
- proxyId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score → int
-
final
- summary → String
-
final
- warnCount → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited