Sub2ApiAdminProxySort enum

Inheritance
Available extensions

Values

id → const Sub2ApiAdminProxySort
name → const Sub2ApiAdminProxySort
protocol → const Sub2ApiAdminProxySort
status → const Sub2ApiAdminProxySort
createdAt → const Sub2ApiAdminProxySort
expiry → const Sub2ApiAdminProxySort
accountCount → const Sub2ApiAdminProxySort

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<Sub2ApiAdminProxySort>
A constant List of the values in this enum, in order of their declaration.