Sub2ApiAdminRectifierSettings class final

Constructors

Sub2ApiAdminRectifierSettings({required bool enabled, required bool thinkingSignatureEnabled, required bool thinkingBudgetEnabled, required bool apiKeySignatureEnabled, required List<String> apiKeySignaturePatterns})

Properties

apiKeySignatureEnabled → bool
final
apiKeySignaturePatterns → List<String>
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thinkingBudgetEnabled → bool
final
thinkingSignatureEnabled → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited