Sub2ApiAdminRedeemCode class final
Constructors
- Sub2ApiAdminRedeemCode({required int id, required Sub2ApiRedeemCodeSecret code, required Sub2ApiAdminRedeemCodeType type, required Sub2ApiDecimal value, required Sub2ApiAdminRedeemCodeStatus status, required DateTime createdAt, required int validityDays, required String notes, int? usedBy, DateTime? usedAt, DateTime? expiresAt, int? groupId, Sub2ApiAdminRedeemUserSummary? user, Sub2ApiAdminRedeemGroupSummary? group})
-
const
Properties
- code → Sub2ApiRedeemCodeSecret
-
final
- createdAt → DateTime
-
final
- expiresAt → DateTime?
-
final
- group → Sub2ApiAdminRedeemGroupSummary?
-
final
- groupId → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- notes → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → Sub2ApiAdminRedeemCodeStatus
-
final
- type → Sub2ApiAdminRedeemCodeType
-
final
- usedAt → DateTime?
-
final
- usedBy → int?
-
final
- user → Sub2ApiAdminRedeemUserSummary?
-
final
- validityDays → int
-
final
- value → Sub2ApiDecimal
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited