Sub2ApiAdminRedeemCodeListQuery class final

Constructors

Sub2ApiAdminRedeemCodeListQuery({int page = 1, int pageSize = 20, Sub2ApiAdminRedeemCodeType? type, Sub2ApiAdminRedeemCodeStatus? status, String? search, Sub2ApiAdminRedeemCodeSortBy sortBy = Sub2ApiAdminRedeemCodeSortBy.id, Sub2ApiAdminRedeemCodeSortOrder sortOrder = Sub2ApiAdminRedeemCodeSortOrder.descending})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
page → int
final
pageSize → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
final
sortBy → Sub2ApiAdminRedeemCodeSortBy
final
sortOrder → Sub2ApiAdminRedeemCodeSortOrder
final
status → Sub2ApiAdminRedeemCodeStatus?
final
type → Sub2ApiAdminRedeemCodeType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited