Sub2ApiAdminRedeemCodeStats class final

Constructors

Sub2ApiAdminRedeemCodeStats({required int totalCodes, required int activeCodes, required int usedCodes, required int expiredCodes, required Sub2ApiDecimal totalValueDistributed, required Map<String, int> byType})

Properties

activeCodes → int
final
byType → Map<String, int>
final
expiredCodes → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCodes → int
final
totalValueDistributed → Sub2ApiDecimal
final
usedCodes → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited