Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
batchDelete(
List< int> ids, {Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminRedeemCodeBatchResult> -
batchUpdate(
Sub2ApiAdminBatchUpdateRedeemCodesRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminRedeemCodeBatchResult> -
createAndRedeem(
Sub2ApiAdminCreateAndRedeemRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminRedeemCode> -
delete(
int id, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminRedeemCodeActionResult> -
expire(
int id, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminRedeemCode> -
export(
{Sub2ApiAdminRedeemCodeExportQuery query = const Sub2ApiAdminRedeemCodeExportQuery(), Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminRedeemCodeExport> -
generate(
Sub2ApiAdminGenerateRedeemCodesRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future< List< Sub2ApiAdminRedeemCode> > -
get(
int id, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminRedeemCode> -
getStats(
{Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminRedeemCodeStats> -
list(
{Sub2ApiAdminRedeemCodeListQuery query = const Sub2ApiAdminRedeemCodeListQuery(), Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminRedeemCodePage> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited