Sub2ApiAdminReplaceUserGroupRequest class abstract

Request to replace one exclusive group grant and migrate matching keys.

Available extensions
Annotations
  • @freezed

Constructors

Sub2ApiAdminReplaceUserGroupRequest({required int oldGroupId, required int newGroupId})
const
factory

Properties

copyWith → $Sub2ApiAdminReplaceUserGroupRequestCopyWith<Sub2ApiAdminReplaceUserGroupRequest>
Create a copy of Sub2ApiAdminReplaceUserGroupRequest with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
newGroupId → int
no setterinherited
oldGroupId → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Sub2ApiAdminReplaceUserGroupRequest value)) → TResult

Available on Sub2ApiAdminReplaceUserGroupRequest, provided by the Sub2ApiAdminReplaceUserGroupRequestPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Sub2ApiAdminReplaceUserGroupRequest value)?) → TResult?

Available on Sub2ApiAdminReplaceUserGroupRequest, provided by the Sub2ApiAdminReplaceUserGroupRequestPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Sub2ApiAdminReplaceUserGroupRequest value)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminReplaceUserGroupRequest, provided by the Sub2ApiAdminReplaceUserGroupRequestPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int oldGroupId, int newGroupId)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminReplaceUserGroupRequest, provided by the Sub2ApiAdminReplaceUserGroupRequestPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int oldGroupId, int newGroupId)) → TResult

Available on Sub2ApiAdminReplaceUserGroupRequest, provided by the Sub2ApiAdminReplaceUserGroupRequestPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int oldGroupId, int newGroupId)?) → TResult?

Available on Sub2ApiAdminReplaceUserGroupRequest, provided by the Sub2ApiAdminReplaceUserGroupRequestPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited