Sub2ApiAdminResetSubscriptionQuotaRequest class final

Constructors

Sub2ApiAdminResetSubscriptionQuotaRequest({bool daily = false, bool weekly = false, bool monthly = false})
const

Properties

daily → bool
final
hashCode → int
The hash code for this object.
no setterinherited
monthly → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weekly → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited