Sub2ApiAdminRiskControlAuditResult class final
Constructors
-
Sub2ApiAdminRiskControlAuditResult({required bool flagged, required String highestCategory, required Sub2ApiDecimal highestScore, required Sub2ApiDecimal compositeScore, required Map<
String, Sub2ApiDecimal> categoryScores, required Map<String, Sub2ApiDecimal> thresholds})
Properties
-
categoryScores
→ Map<
String, Sub2ApiDecimal> -
final
- compositeScore → Sub2ApiDecimal
-
final
- flagged → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highestCategory → String
-
final
- highestScore → Sub2ApiDecimal
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
thresholds
→ Map<
String, Sub2ApiDecimal> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited