Sub2ApiAdminScheduledTestPlan class final

Constructors

Sub2ApiAdminScheduledTestPlan({required int id, required int accountId, required String modelId, required String cronExpression, required bool enabled, required int maxResults, required bool autoRecover, required DateTime createdAt, required DateTime updatedAt, DateTime? lastRunAt, DateTime? nextRunAt})
const

Properties

accountId → int
final
autoRecover → bool
final
createdAt → DateTime
final
cronExpression → String
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
lastRunAt → DateTime?
final
maxResults → int
final
modelId → String
final
nextRunAt → DateTime?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited