Sub2ApiAdminScheduledTestResult class final

Constructors

Sub2ApiAdminScheduledTestResult({required int id, required int planId, required String status, required String responseText, required String errorMessage, required Duration latency, required DateTime startedAt, required DateTime finishedAt, required DateTime createdAt})
const

Properties

createdAt → DateTime
final
errorMessage → String
final
finishedAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
latency → Duration
final
planId → int
final
responseText → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startedAt → DateTime
final
status → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited