Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
Sub2ApiAdminCreateScheduledTestPlanRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminScheduledTestPlan> -
delete(
int planId, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminDeleteScheduledTestPlanResult> -
listResults(
int planId, {int limit = 50, Sub2ApiRequestOptions? requestOptions}) → Future< List< Sub2ApiAdminScheduledTestResult> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
int planId, Sub2ApiAdminUpdateScheduledTestPlanRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminScheduledTestPlan>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited