Sub2ApiAdminSendTestEmailRequest class final

Constructors

Sub2ApiAdminSendTestEmailRequest({required String email, String host = '', int port = 0, String username = '', Sub2ApiAdminSmtpPassword? password, String fromEmail = '', String fromName = '', bool useTls = true})
const

Properties

email → String
final
fromEmail → String
final
fromName → String
final
hashCode → int
The hash code for this object.
no setterinherited
host → String
final
password → Sub2ApiAdminSmtpPassword?
final
port → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → String
final
useTls → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited