Sub2ApiAdminStreamTimeoutSettings class final

Constructors

Sub2ApiAdminStreamTimeoutSettings({required bool enabled, required Sub2ApiAdminStreamTimeoutAction action, required int tempUnschedMinutes, required int thresholdCount, required int thresholdWindowMinutes})
const

Properties

action → Sub2ApiAdminStreamTimeoutAction
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tempUnschedMinutes → int
final
thresholdCount → int
final
thresholdWindowMinutes → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited