Sub2ApiAdminSubscriptionPlan class final
Constructors
-
Sub2ApiAdminSubscriptionPlan({required int id, required int groupId, required String name, required String description, required Sub2ApiDecimal price, required String currency, required int validityDays, required String validityUnit, required String features, required String productName, required bool forSale, required int sortOrder, required DateTime createdAt, required DateTime updatedAt, Sub2ApiDecimal? originalPrice, String? groupPlatform, String? groupName, Sub2ApiDecimal? rateMultiplier, Sub2ApiDecimal? dailyLimitUsd, Sub2ApiDecimal? weeklyLimitUsd, Sub2ApiDecimal? monthlyLimitUsd, List<
String> supportedModelScopes = const <String>[]})
Properties
- createdAt → DateTime
-
final
- currency → String
-
final
- dailyLimitUsd → Sub2ApiDecimal?
-
final
- description → String
-
final
- features → String
-
final
- forSale → bool
-
final
- groupId → int
-
final
- groupName → String?
-
final
- groupPlatform → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- monthlyLimitUsd → Sub2ApiDecimal?
-
final
- name → String
-
final
- originalPrice → Sub2ApiDecimal?
-
final
- price → Sub2ApiDecimal
-
final
- productName → String
-
final
- rateMultiplier → Sub2ApiDecimal?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortOrder → int
-
final
-
supportedModelScopes
→ List<
String> -
final
- updatedAt → DateTime
-
final
- validityDays → int
-
final
- validityUnit → String
-
final
- weeklyLimitUsd → Sub2ApiDecimal?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited