Sub2ApiAdminSystemAlreadyCurrent class final

Inheritance

Constructors

Sub2ApiAdminSystemAlreadyCurrent({required String message, required String operationId, required String currentVersion, required String latestVersion})
const

Properties

currentVersion → String
final
hashCode → int
The hash code for this object.
no setterinherited
latestVersion → String
final
message → String
finalinherited
operationId → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited