Sub2ApiAdminSystemReleaseInfo class final

Constructors

Sub2ApiAdminSystemReleaseInfo({required String name, required String body, required DateTime publishedAt, required Uri htmlUrl, required List<Sub2ApiAdminSystemReleaseAsset> assets})

Properties

assets → List<Sub2ApiAdminSystemReleaseAsset>
final
body → String
final
hashCode → int
The hash code for this object.
no setterinherited
htmlUrl → Uri
final
name → String
final
publishedAt → DateTime
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited