Sub2ApiAdminSystemRollbackResult class final

Constructors

Sub2ApiAdminSystemRollbackResult({required String message, required bool needRestart, required String? version, required String operationId})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
final
needRestart → bool
final
operationId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited