Sub2ApiAdminSystemSettingsPatch class final

Constructors

Sub2ApiAdminSystemSettingsPatch.empty()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
withValue<T>(Sub2ApiAdminSystemSettingUpdate<T> field, T value) → Sub2ApiAdminSystemSettingsPatch

Operators

operator ==(Object other) → bool
The equality operator.
inherited