Sub2ApiAdminSystemUpdated class final
- Inheritance
-
- Object
- Sub2ApiAdminSystemUpdateResult
- Sub2ApiAdminSystemUpdated
Constructors
- Sub2ApiAdminSystemUpdated({required String message, required String operationId, required bool needRestart})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
finalinherited
- needRestart → bool
-
final
- operationId → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited