Sub2ApiAdminTLSFingerprintProfile class final
Constructors
-
Sub2ApiAdminTLSFingerprintProfile({required int id, required String name, required String? description, required bool enableGrease, required List<
int> cipherSuites, required List<int> curves, required List<int> pointFormats, required List<int> signatureAlgorithms, required List<String> alpnProtocols, required List<int> supportedVersions, required List<int> pskModes, required List<int> extensions, required DateTime createdAt, required DateTime updatedAt})
Properties
-
alpnProtocols
→ List<
String> -
final
-
cipherSuites
→ List<
int> -
final
- createdAt → DateTime
-
final
-
curves
→ List<
int> -
final
- description → String?
-
final
- enableGrease → bool
-
final
-
extensions
→ List<
int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
-
final
- name → String
-
final
-
pointFormats
→ List<
int> -
final
-
pskModes
→ List<
int> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
signatureAlgorithms
→ List<
int> -
final
-
supportedVersions
→ List<
int> -
final
- updatedAt → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited