Sub2ApiAdminTimePricingPeriod class final

Constructors

Sub2ApiAdminTimePricingPeriod({required String startTime, required String endTime, required Sub2ApiDecimal multiplier})
const

Properties

endTime → String
final
hashCode → int
The hash code for this object.
no setterinherited
multiplier → Sub2ApiDecimal
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited