Sub2ApiAdminUpdateAccountRequest class final
Constructors
-
Sub2ApiAdminUpdateAccountRequest({String? name, String? notes, Sub2ApiAdminAccountType? type, Sub2ApiAdminCredentialSet? credentials, Sub2ApiAdminJsonObject? extra, Sub2ApiAdminProxyUpdate proxy = const Sub2ApiAdminProxyUpdate.unchanged(), int? concurrency, int? priority, Sub2ApiDecimal? rateMultiplier, Sub2ApiAdminLoadFactorUpdate loadFactor = const Sub2ApiAdminLoadFactorUpdate.unchanged(), Sub2ApiAdminAccountStatus? status, List<
int> ? groupIds, Sub2ApiAdminExpiresAtUpdate expiresAt = const Sub2ApiAdminExpiresAtUpdate.unchanged(), bool? autoPauseOnExpired, bool? upstreamBillingProbeEnabled, bool? upstreamBillingRateSyncEnabled, bool confirmMixedChannelRisk = false})
Properties
- autoPauseOnExpired → bool?
-
final
- concurrency → int?
-
final
- confirmMixedChannelRisk → bool
-
final
- credentials → Sub2ApiAdminCredentialSet?
-
final
- expiresAt → Sub2ApiAdminExpiresAtUpdate
-
final
- extra → Sub2ApiAdminJsonObject?
-
nullleaves extra unchanged; an empty object clears user-owned keys.final -
groupIds
→ List<
int> ? -
nullleaves bindings unchanged; an empty list clears all bindings.final - hashCode → int
-
The hash code for this object.
no setterinherited
- loadFactor → Sub2ApiAdminLoadFactorUpdate
-
final
- name → String?
-
final
- notes → String?
-
final
- priority → int?
-
final
- proxy → Sub2ApiAdminProxyUpdate
-
final
- rateMultiplier → Sub2ApiDecimal?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → Sub2ApiAdminAccountStatus?
-
final
- type → Sub2ApiAdminAccountType?
-
final
- upstreamBillingProbeEnabled → bool?
-
final
- upstreamBillingRateSyncEnabled → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited