Sub2ApiAdminUpdateAffiliateUserRequest class final

Constructors

Sub2ApiAdminUpdateAffiliateUserRequest({String? affiliateCode, Sub2ApiDecimal? rebateRatePercent, bool clearRebateRate = false})
const

Properties

affiliateCode → String?
final
clearRebateRate → bool
final
hashCode → int
The hash code for this object.
no setterinherited
rebateRatePercent → Sub2ApiDecimal?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited