Sub2ApiAdminUpdateApiKeyRequest class final

Constructors

Sub2ApiAdminUpdateApiKeyRequest({Sub2ApiAdminApiKeyGroupUpdate group = const Sub2ApiAdminApiKeyGroupUpdate.unchanged(), bool resetRateLimitUsage = false})
const

Properties

group → Sub2ApiAdminApiKeyGroupUpdate
final
hashCode → int
The hash code for this object.
no setterinherited
resetRateLimitUsage → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited