Sub2ApiAdminUpdateApiKeyResult class final

Constructors

Sub2ApiAdminUpdateApiKeyResult({required Sub2ApiKeyDetails apiKey, required bool autoGrantedGroupAccess, required int? grantedGroupId, required String grantedGroupName})
const

Properties

apiKey → Sub2ApiKeyDetails
final
autoGrantedGroupAccess → bool
final
grantedGroupId → int?
final
grantedGroupName → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited