Sub2ApiAdminUpdateBalanceRequest class final

Idempotent Admin balance update.

Constructors

Sub2ApiAdminUpdateBalanceRequest({required Sub2ApiDecimal amount, required Sub2ApiAdminBalanceOperation operation, required String idempotencyKey, String notes = ''})
const

Properties

amount → Sub2ApiDecimal
final
hashCode → int
The hash code for this object.
no setterinherited
idempotencyKey → String
final
notes → String
final
operation → Sub2ApiAdminBalanceOperation
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited