Sub2ApiAdminUpdateChannelMonitorRequest class final

Constructors

Sub2ApiAdminUpdateChannelMonitorRequest({String? name, Sub2ApiAdminChannelMonitorProvider? provider, Sub2ApiAdminChannelMonitorApiMode? apiMode, Uri? endpoint, bool clearEndpoint = false, Sub2ApiAdminCredentialSecret? apiKey, String? primaryModel, List<String>? extraModels, String? groupName, bool? enabled, int? intervalSeconds, int? jitterSeconds, int? templateId, bool clearTemplate = false, Map<String, String>? extraHeaders, Sub2ApiAdminChannelMonitorBodyMode? bodyOverrideMode, Sub2ApiAdminJsonObject? bodyOverride, Sub2ApiAdminChannelMonitorCheckMode? checkMode, int? accountId})

Properties

accountId → int?
Positive ID sets the account; zero explicitly clears it.
final
apiKey → Sub2ApiAdminCredentialSecret?
final
apiMode → Sub2ApiAdminChannelMonitorApiMode?
final
bodyOverride → Sub2ApiAdminJsonObject?
final
bodyOverrideMode → Sub2ApiAdminChannelMonitorBodyMode?
final
checkMode → Sub2ApiAdminChannelMonitorCheckMode?
final
clearEndpoint → bool
final
clearTemplate → bool
final
enabled → bool?
final
endpoint → Uri?
final
extraHeaders → Map<String, String>?
final
extraModels → List<String>?
final
groupName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
intervalSeconds → int?
final
jitterSeconds → int?
final
name → String?
final
primaryModel → String?
final
provider → Sub2ApiAdminChannelMonitorProvider?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templateId → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited