Sub2ApiAdminUpdateChannelMonitorTemplateRequest class final
Constructors
-
Sub2ApiAdminUpdateChannelMonitorTemplateRequest({String? name, Sub2ApiAdminMonitorTemplateApiMode? apiMode, String? description, Map<
String, String> ? extraHeaders, Sub2ApiAdminMonitorTemplateBodyMode? bodyOverrideMode, Sub2ApiAdminJsonObject? bodyOverride})
Properties
- apiMode → Sub2ApiAdminMonitorTemplateApiMode?
-
final
- bodyOverride → Sub2ApiAdminJsonObject?
-
final
- bodyOverrideMode → Sub2ApiAdminMonitorTemplateBodyMode?
-
final
- description → String?
-
final
-
extraHeaders
→ Map<
String, String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited