Sub2ApiAdminUpdateChannelRequest class final

Constructors

Sub2ApiAdminUpdateChannelRequest({String? name, String? description, Sub2ApiAdminChannelStatus? status, List<int>? groupIds, List<Sub2ApiAdminChannelModelPricingInput>? modelPricing, Map<String, Map<String, String>>? modelMapping, Sub2ApiAdminChannelBillingModelSource? billingModelSource, bool? restrictModels, String? features, Sub2ApiAdminJsonObject? featuresConfig, bool? applyPricingToAccountStats, List<Sub2ApiAdminChannelAccountStatsPricingRuleInput>? accountStatsPricingRules})

Properties

accountStatsPricingRules → List<Sub2ApiAdminChannelAccountStatsPricingRuleInput>?
final
applyPricingToAccountStats → bool?
final
billingModelSource → Sub2ApiAdminChannelBillingModelSource?
final
description → String?
final
features → String?
final
featuresConfig → Sub2ApiAdminJsonObject?
final
groupIds → List<int>?
final
hashCode → int
The hash code for this object.
no setterinherited
modelMapping → Map<String, Map<String, String>>?
final
modelPricing → List<Sub2ApiAdminChannelModelPricingInput>?
final
name → String?
final
restrictModels → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → Sub2ApiAdminChannelStatus?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited