Sub2ApiAdminUpdateGroupRequest class final
Constructors
-
Sub2ApiAdminUpdateGroupRequest({String? name, String? description, Sub2ApiAdminGroupPlatform? platform, Sub2ApiDecimal? rateMultiplier, bool? isExclusive, Sub2ApiAdminGroupStatus? status, Sub2ApiAdminGroupSubscriptionType? subscriptionType, Sub2ApiAdminLimitUpdate dailyLimitUsd = const Sub2ApiAdminLimitUpdate.unchanged(), Sub2ApiAdminLimitUpdate weeklyLimitUsd = const Sub2ApiAdminLimitUpdate.unchanged(), Sub2ApiAdminLimitUpdate monthlyLimitUsd = const Sub2ApiAdminLimitUpdate.unchanged(), bool? longContextPricingEnabled, List<
Sub2ApiAdminModelPricing> ? modelPricing, bool? allowImageGeneration, bool? allowBatchImageGeneration, bool? imageRateIndependent, Sub2ApiDecimal? imageRateMultiplier, Sub2ApiDecimal? batchImageDiscountMultiplier, Sub2ApiDecimal? batchImageHoldMultiplier, bool? videoRateIndependent, Sub2ApiDecimal? videoRateMultiplier, bool? peakRateEnabled, String? peakStart, String? peakEnd, Sub2ApiDecimal? peakRateMultiplier, bool? profitControlEnabled, Sub2ApiDecimal? profitMinMargin, Sub2ApiDecimal? profitSafetyBuffer, Sub2ApiDecimal? imagePrice1k, Sub2ApiDecimal? imagePrice2k, Sub2ApiDecimal? imagePrice4k, Sub2ApiDecimal? videoPrice480p, Sub2ApiDecimal? videoPrice720p, Sub2ApiDecimal? videoPrice1080p, Map<String, Map< ? videoModelPrices, Sub2ApiDecimal? webSearchPricePerCall, Sub2ApiDecimal? searchPricePer1k, Sub2ApiDecimal? audioRealtimePricePerMin, Sub2ApiDecimal? audioTtsPricePerMillionChars, Sub2ApiDecimal? audioSttPricePerHour, bool? claudeCodeOnly, int? fallbackGroupId, int? fallbackGroupIdOnInvalidRequest, Map<String, Sub2ApiDecimal> >String, List< ? modelRouting, bool? modelRoutingEnabled, bool? mcpXmlInject, List<int> >String> ? supportedModelScopes, bool? allowMessagesDispatch, bool? allowLive, bool? requireOAuthOnly, bool? requirePrivacySet, String? defaultMappedModel, Sub2ApiAdminMessagesDispatchModelConfig? messagesDispatchModelConfig, Sub2ApiAdminGroupModelsListConfig? modelsListConfig, int? rpmLimit, String? maxReasoningEffort, List<Sub2ApiAdminReasoningEffortMapping> ? reasoningEffortMappings, List<int> ? copyAccountsFromGroupIds})
Properties
- allowBatchImageGeneration → bool?
-
final
- allowImageGeneration → bool?
-
final
- allowLive → bool?
-
final
- allowMessagesDispatch → bool?
-
final
- audioRealtimePricePerMin → Sub2ApiDecimal?
-
final
- audioSttPricePerHour → Sub2ApiDecimal?
-
final
- audioTtsPricePerMillionChars → Sub2ApiDecimal?
-
final
- batchImageDiscountMultiplier → Sub2ApiDecimal?
-
final
- batchImageHoldMultiplier → Sub2ApiDecimal?
-
final
- claudeCodeOnly → bool?
-
final
-
copyAccountsFromGroupIds
→ List<
int> ? -
final
- dailyLimitUsd → Sub2ApiAdminLimitUpdate
-
final
- defaultMappedModel → String?
-
final
- description → String?
-
final
- fallbackGroupId → int?
-
final
- fallbackGroupIdOnInvalidRequest → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imagePrice1k → Sub2ApiDecimal?
-
final
- imagePrice2k → Sub2ApiDecimal?
-
final
- imagePrice4k → Sub2ApiDecimal?
-
final
- imageRateIndependent → bool?
-
final
- imageRateMultiplier → Sub2ApiDecimal?
-
final
- isExclusive → bool?
-
final
- longContextPricingEnabled → bool?
-
final
- maxReasoningEffort → String?
-
final
- mcpXmlInject → bool?
-
final
- messagesDispatchModelConfig → Sub2ApiAdminMessagesDispatchModelConfig?
-
final
-
modelPricing
→ List<
Sub2ApiAdminModelPricing> ? -
final
-
modelRouting
→ Map<
String, List< ?int> > -
final
- modelRoutingEnabled → bool?
-
final
- modelsListConfig → Sub2ApiAdminGroupModelsListConfig?
-
final
- monthlyLimitUsd → Sub2ApiAdminLimitUpdate
-
final
- name → String?
-
final
- peakEnd → String?
-
final
- peakRateEnabled → bool?
-
final
- peakRateMultiplier → Sub2ApiDecimal?
-
final
- peakStart → String?
-
final
- platform → Sub2ApiAdminGroupPlatform?
-
final
- profitControlEnabled → bool?
-
final
- profitMinMargin → Sub2ApiDecimal?
-
final
- profitSafetyBuffer → Sub2ApiDecimal?
-
final
- rateMultiplier → Sub2ApiDecimal?
-
final
-
reasoningEffortMappings
→ List<
Sub2ApiAdminReasoningEffortMapping> ? -
final
- requireOAuthOnly → bool?
-
final
- requirePrivacySet → bool?
-
final
- rpmLimit → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchPricePer1k → Sub2ApiDecimal?
-
final
- status → Sub2ApiAdminGroupStatus?
-
final
- subscriptionType → Sub2ApiAdminGroupSubscriptionType?
-
final
-
supportedModelScopes
→ List<
String> ? -
final
-
videoModelPrices
→ Map<
String, Map< ?String, Sub2ApiDecimal> > -
final
- videoPrice1080p → Sub2ApiDecimal?
-
final
- videoPrice480p → Sub2ApiDecimal?
-
final
- videoPrice720p → Sub2ApiDecimal?
-
final
- videoRateIndependent → bool?
-
final
- videoRateMultiplier → Sub2ApiDecimal?
-
final
- webSearchPricePerCall → Sub2ApiDecimal?
-
final
- weeklyLimitUsd → Sub2ApiAdminLimitUpdate
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited