Sub2ApiAdminUpdatePaymentConfigRequest class final
Constructors
-
Sub2ApiAdminUpdatePaymentConfigRequest({bool? enabled, Sub2ApiDecimal? minAmount, Sub2ApiDecimal? maxAmount, Sub2ApiDecimal? dailyLimit, int? orderTimeoutMinutes, int? maxPendingOrders, List<
String> ? enabledPaymentTypes, bool? balanceDisabled, Sub2ApiDecimal? balanceRechargeMultiplier, Sub2ApiDecimal? subscriptionUsdToCnyRate, Sub2ApiDecimal? rechargeFeeRate, String? loadBalanceStrategy, String? productNamePrefix, String? productNameSuffix, String? helpImageUrl, String? helpText, bool? cancelRateLimitEnabled, int? cancelRateLimitMax, int? cancelRateLimitWindow, String? cancelRateLimitUnit, String? cancelRateLimitMode, bool? alipayForceQrCode, bool? alipayMobilePrecreateDeepLink, String? visibleMethodAlipaySource, String? visibleMethodWxpaySource, bool? visibleMethodAlipayEnabled, bool? visibleMethodWxpayEnabled})
Properties
- alipayForceQrCode → bool?
-
final
- alipayMobilePrecreateDeepLink → bool?
-
final
- balanceDisabled → bool?
-
final
- balanceRechargeMultiplier → Sub2ApiDecimal?
-
final
- cancelRateLimitEnabled → bool?
-
final
- cancelRateLimitMax → int?
-
final
- cancelRateLimitMode → String?
-
final
- cancelRateLimitUnit → String?
-
final
- cancelRateLimitWindow → int?
-
final
- dailyLimit → Sub2ApiDecimal?
-
final
- enabled → bool?
-
final
-
enabledPaymentTypes
→ List<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helpImageUrl → String?
-
final
- helpText → String?
-
final
- loadBalanceStrategy → String?
-
final
- maxAmount → Sub2ApiDecimal?
-
final
- maxPendingOrders → int?
-
final
- minAmount → Sub2ApiDecimal?
-
final
- orderTimeoutMinutes → int?
-
final
- productNamePrefix → String?
-
final
- productNameSuffix → String?
-
final
- rechargeFeeRate → Sub2ApiDecimal?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriptionUsdToCnyRate → Sub2ApiDecimal?
-
final
- visibleMethodAlipayEnabled → bool?
-
final
- visibleMethodAlipaySource → String?
-
final
- visibleMethodWxpayEnabled → bool?
-
final
- visibleMethodWxpaySource → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited