Sub2ApiAdminUpdatePaymentProviderRequest class final

Constructors

Sub2ApiAdminUpdatePaymentProviderRequest({String? name, Map<String, Sub2ApiAdminCredentialSecret>? config, List<String>? supportedTypes, bool? enabled, String? paymentMode, int? sortOrder, String? limits, bool? refundEnabled, bool? allowUserRefund})

Properties

allowUserRefund → bool?
final
config → Map<String, Sub2ApiAdminCredentialSecret>?
final
enabled → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
limits → String?
final
name → String?
final
paymentMode → String?
final
refundEnabled → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortOrder → int?
final
supportedTypes → List<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited