Sub2ApiAdminUpdatePlatformQuotasRequestPatterns extension

Adds pattern-matching-related methods to Sub2ApiAdminUpdatePlatformQuotasRequest.

on

Methods

map<TResult extends Object?>(TResult $default(_Sub2ApiAdminUpdatePlatformQuotasRequest value)) → TResult

Available on Sub2ApiAdminUpdatePlatformQuotasRequest, provided by the Sub2ApiAdminUpdatePlatformQuotasRequestPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Sub2ApiAdminUpdatePlatformQuotasRequest value)?) → TResult?

Available on Sub2ApiAdminUpdatePlatformQuotasRequest, provided by the Sub2ApiAdminUpdatePlatformQuotasRequestPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Sub2ApiAdminUpdatePlatformQuotasRequest value)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminUpdatePlatformQuotasRequest, provided by the Sub2ApiAdminUpdatePlatformQuotasRequestPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<Sub2ApiAdminPlatformQuotaInput> quotas)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminUpdatePlatformQuotasRequest, provided by the Sub2ApiAdminUpdatePlatformQuotasRequestPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(List<Sub2ApiAdminPlatformQuotaInput> quotas)) → TResult

Available on Sub2ApiAdminUpdatePlatformQuotasRequest, provided by the Sub2ApiAdminUpdatePlatformQuotasRequestPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<Sub2ApiAdminPlatformQuotaInput> quotas)?) → TResult?

Available on Sub2ApiAdminUpdatePlatformQuotasRequest, provided by the Sub2ApiAdminUpdatePlatformQuotasRequestPatterns extension

A variant of when that fallback to returning null