Sub2ApiAdminUpdatePromoCodeRequest class final

Constructors

Sub2ApiAdminUpdatePromoCodeRequest({Sub2ApiPromoCode? code, Sub2ApiDecimal? bonusAmount, int? maxUses, Sub2ApiAdminPromoCodeStatus? status, Sub2ApiAdminPromoExpirationUpdate expiresAt = const Sub2ApiAdminPromoExpirationUpdate.unchanged(), String? notes})
const

Properties

bonusAmount → Sub2ApiDecimal?
final
code → Sub2ApiPromoCode?
final
expiresAt → Sub2ApiAdminPromoExpirationUpdate
final
hashCode → int
The hash code for this object.
no setterinherited
maxUses → int?
final
notes → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → Sub2ApiAdminPromoCodeStatus?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited