Sub2ApiAdminUpdatePromptAuditConfigRequest class final

Constructors

Sub2ApiAdminUpdatePromptAuditConfigRequest({required int expectedConfigVersion, required bool enabled, required bool blockingEnabled, required bool blockingLatestTurnOnly, required bool storePassEvents, Sub2ApiAdminPromptAuditStrategy strategy = Sub2ApiAdminPromptAuditStrategy.priority, required int workerCount, required int queueCapacity, required List<String> scanners, required bool allGroups, required List<int> groupIds, required List<Sub2ApiAdminPromptAuditEndpointUpdate> endpoints})

Properties

allGroups → bool
final
blockingEnabled → bool
final
blockingLatestTurnOnly → bool
final
enabled → bool
final
endpoints → List<Sub2ApiAdminPromptAuditEndpointUpdate>
final
expectedConfigVersion → int
final
groupIds → List<int>
final
hashCode → int
The hash code for this object.
no setterinherited
queueCapacity → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanners → List<String>
final
storePassEvents → bool
final
strategy → Sub2ApiAdminPromptAuditStrategy
final
workerCount → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited