Sub2ApiAdminUpdateProxyRequest class final

Proxy update with explicit replacement state for server-replaced fields.

Constructors

Sub2ApiAdminUpdateProxyRequest({required DateTime? expiresAt, required Sub2ApiAdminProxyFallbackMode fallbackMode, required int? backupProxyId, required int expiryWarnDays, String? name, Sub2ApiAdminProxyProtocol? protocol, String? host, int? port, String? username, Sub2ApiAdminProxyPassword? password, Sub2ApiAdminProxyStatus? status})
const

Properties

backupProxyId → int?
final
expiresAt → DateTime?
final
expiryWarnDays → int
final
fallbackMode → Sub2ApiAdminProxyFallbackMode
final
hashCode → int
The hash code for this object.
no setterinherited
host → String?
final
name → String?
final
password → Sub2ApiAdminProxyPassword?
final
port → int?
final
protocol → Sub2ApiAdminProxyProtocol?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → Sub2ApiAdminProxyStatus?
final
username → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited