Sub2ApiAdminUpdateUserAttributeDefinitionRequest class final
Constructors
-
Sub2ApiAdminUpdateUserAttributeDefinitionRequest({String? name, String? description, Sub2ApiAdminUserAttributeType? type, List<
Sub2ApiAdminUserAttributeOption> ? options, bool? required, Sub2ApiAdminUserAttributeValidation? validation, String? placeholder, bool? enabled})
Properties
- description → String?
-
final
- enabled → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
final
-
options
→ List<
Sub2ApiAdminUserAttributeOption> ? -
final
- placeholder → String?
-
final
- required → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Sub2ApiAdminUserAttributeType?
-
final
- validation → Sub2ApiAdminUserAttributeValidation?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited