Sub2ApiAdminUpdateUserRequest class final

Partial Admin update for one user.

Constructors

Sub2ApiAdminUpdateUserRequest({String? email, Sub2ApiPassword? password, String? username, String? notes, Sub2ApiAdminUserRole? role, Sub2ApiDecimal? balance, int? concurrency, int? rpmLimit, Sub2ApiAdminUserStatus? status, List<int>? allowedGroups, Map<int, Sub2ApiDecimal?>? groupRates})
const

Properties

allowedGroups → List<int>?
final
balance → Sub2ApiDecimal?
final
concurrency → int?
final
email → String?
final
groupRates → Map<int, Sub2ApiDecimal?>?
final
hashCode → int
The hash code for this object.
no setterinherited
notes → String?
final
password → Sub2ApiPassword?
final
role → Sub2ApiAdminUserRole?
final
rpmLimit → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → Sub2ApiAdminUserStatus?
final
username → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited