Sub2ApiAdminUpstreamBillingProbeResult class final
Constructors
- Sub2ApiAdminUpstreamBillingProbeResult({required int accountId, required String error, Sub2ApiAdminUpstreamBillingProbeSnapshot? snapshot})
-
const
Properties
- accountId → int
-
final
- error → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapshot → Sub2ApiAdminUpstreamBillingProbeSnapshot?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited