Sub2ApiAdminUpstreamModelPreviewRequest class final

Constructors

Sub2ApiAdminUpstreamModelPreviewRequest({required Sub2ApiAdminAccountPlatform platform, required Sub2ApiAdminAccountType type, required Sub2ApiApiKeySecret apiKey, Uri? baseUrl})
const

Properties

apiKey → Sub2ApiApiKeySecret
final
baseUrl → Uri?
final
hashCode → int
The hash code for this object.
no setterinherited
platform → Sub2ApiAdminAccountPlatform
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Sub2ApiAdminAccountType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited