Sub2ApiAdminUsageCleanupFilters class final

Constructors

Sub2ApiAdminUsageCleanupFilters({required DateTime startTime, required DateTime endTime, int? userId, int? apiKeyId, int? accountId, int? groupId, String? model, Sub2ApiAdminUsageRequestType? requestType, bool? stream, Sub2ApiAdminBillingType? billingType})
const

Properties

accountId → int?
final
apiKeyId → int?
final
billingType → Sub2ApiAdminBillingType?
final
endTime → DateTime
final
groupId → int?
final
hashCode → int
The hash code for this object.
no setterinherited
model → String?
final
requestType → Sub2ApiAdminUsageRequestType?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → DateTime
final
stream → bool?
final
userId → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited