Sub2ApiAdminUsageCleanupTask class final
Constructors
- Sub2ApiAdminUsageCleanupTask({required int id, required Sub2ApiAdminUsageCleanupStatus status, required Sub2ApiAdminUsageCleanupFilters filters, required int createdBy, required int deletedRows, required DateTime createdAt, required DateTime updatedAt, String? errorMessage, int? canceledBy, DateTime? canceledAt, DateTime? startedAt, DateTime? finishedAt})
-
const
Properties
- canceledAt → DateTime?
-
final
- canceledBy → int?
-
final
- createdAt → DateTime
-
final
- createdBy → int
-
final
- deletedRows → int
-
final
- errorMessage → String?
-
final
- filters → Sub2ApiAdminUsageCleanupFilters
-
final
- finishedAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startedAt → DateTime?
-
final
- status → Sub2ApiAdminUsageCleanupStatus
-
final
- updatedAt → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited