Sub2ApiAdminUsageQuery class final
Constructors
- Sub2ApiAdminUsageQuery({int page = 1, int pageSize = 20, bool exactTotal = false, int? userId, int? apiKeyId, int? accountId, int? groupId, String? requestId, String? model, Sub2ApiAdminUsageRequestType? requestType, bool? stream, Sub2ApiAdminBillingType? billingType, String? billingMode, bool? upstreamModelMismatch, DateTime? startDate, DateTime? endDate, String? timezone, String sortBy = 'created_at', Sub2ApiAdminUsageSortOrder sortOrder = Sub2ApiAdminUsageSortOrder.descending})
-
const
Properties
- accountId → int?
-
final
- apiKeyId → int?
-
final
- billingMode → String?
-
final
- billingType → Sub2ApiAdminBillingType?
-
final
- endDate → DateTime?
-
final
- exactTotal → bool
-
final
- groupId → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- model → String?
-
final
- page → int
-
final
- pageSize → int
-
final
- requestId → String?
-
final
- requestType → Sub2ApiAdminUsageRequestType?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortBy → String
-
final
- sortOrder → Sub2ApiAdminUsageSortOrder
-
final
- startDate → DateTime?
-
final
- stream → bool?
-
final
- timezone → String?
-
final
- upstreamModelMismatch → bool?
-
final
- userId → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited