Sub2ApiAdminUserAttributeValidation class final

Constructors

Sub2ApiAdminUserAttributeValidation({int? minLength, int? maxLength, int? min, int? max, String? pattern, String? message})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
max → int?
final
maxLength → int?
final
message → String?
final
min → int?
final
minLength → int?
final
pattern → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited