Sub2ApiAdminUserBreakdownQuery class abstract

Query for per-user usage within a selected group, model, or endpoint.

Available extensions
Annotations
  • @freezed

Constructors

Sub2ApiAdminUserBreakdownQuery({DateTime? startDate, DateTime? endDate, String? timezone, int? groupId, String? model, @Default.new(Sub2ApiAdminModelSource.requested) Sub2ApiAdminModelSource modelSource, String? endpoint, @Default.new(Sub2ApiAdminEndpointType.inbound) Sub2ApiAdminEndpointType endpointType, int? userId, int? apiKeyId, int? accountId, Sub2ApiAdminUsageRequestType? requestType, bool? stream, Sub2ApiAdminBillingType? billingType, Sub2ApiAdminUserBreakdownSort? sortBy, @Default.new(50) int limit})
const
factory

Properties

accountId → int?
no setterinherited
apiKeyId → int?
no setterinherited
billingType → Sub2ApiAdminBillingType?
no setterinherited
copyWith → $Sub2ApiAdminUserBreakdownQueryCopyWith<Sub2ApiAdminUserBreakdownQuery>
Create a copy of Sub2ApiAdminUserBreakdownQuery with the given fields replaced by the non-null parameter values.
no setterinherited
endDate → DateTime?
no setterinherited
endpoint → String?
no setterinherited
endpointType → Sub2ApiAdminEndpointType
no setterinherited
groupId → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
limit → int
no setterinherited
model → String?
no setterinherited
modelSource → Sub2ApiAdminModelSource
no setterinherited
requestType → Sub2ApiAdminUsageRequestType?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortBy → Sub2ApiAdminUserBreakdownSort?
no setterinherited
startDate → DateTime?
no setterinherited
stream → bool?
no setterinherited
timezone → String?
no setterinherited
userId → int?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Sub2ApiAdminUserBreakdownQuery value)) → TResult

Available on Sub2ApiAdminUserBreakdownQuery, provided by the Sub2ApiAdminUserBreakdownQueryPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Sub2ApiAdminUserBreakdownQuery value)?) → TResult?

Available on Sub2ApiAdminUserBreakdownQuery, provided by the Sub2ApiAdminUserBreakdownQueryPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Sub2ApiAdminUserBreakdownQuery value)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminUserBreakdownQuery, provided by the Sub2ApiAdminUserBreakdownQueryPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(DateTime? startDate, DateTime? endDate, String? timezone, int? groupId, String? model, Sub2ApiAdminModelSource modelSource, String? endpoint, Sub2ApiAdminEndpointType endpointType, int? userId, int? apiKeyId, int? accountId, Sub2ApiAdminUsageRequestType? requestType, bool? stream, Sub2ApiAdminBillingType? billingType, Sub2ApiAdminUserBreakdownSort? sortBy, int limit)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminUserBreakdownQuery, provided by the Sub2ApiAdminUserBreakdownQueryPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(DateTime? startDate, DateTime? endDate, String? timezone, int? groupId, String? model, Sub2ApiAdminModelSource modelSource, String? endpoint, Sub2ApiAdminEndpointType endpointType, int? userId, int? apiKeyId, int? accountId, Sub2ApiAdminUsageRequestType? requestType, bool? stream, Sub2ApiAdminBillingType? billingType, Sub2ApiAdminUserBreakdownSort? sortBy, int limit)) → TResult

Available on Sub2ApiAdminUserBreakdownQuery, provided by the Sub2ApiAdminUserBreakdownQueryPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(DateTime? startDate, DateTime? endDate, String? timezone, int? groupId, String? model, Sub2ApiAdminModelSource modelSource, String? endpoint, Sub2ApiAdminEndpointType endpointType, int? userId, int? apiKeyId, int? accountId, Sub2ApiAdminUsageRequestType? requestType, bool? stream, Sub2ApiAdminBillingType? billingType, Sub2ApiAdminUserBreakdownSort? sortBy, int limit)?) → TResult?

Available on Sub2ApiAdminUserBreakdownQuery, provided by the Sub2ApiAdminUserBreakdownQueryPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited