Sub2ApiAdminUserGroupRpmStatus class abstract
Current RPM state for one user/group pair.
- Available extensions
- Annotations
-
- @freezed
Constructors
Properties
-
copyWith
→ $Sub2ApiAdminUserGroupRpmStatusCopyWith<
Sub2ApiAdminUserGroupRpmStatus> -
Create a copy of Sub2ApiAdminUserGroupRpmStatus
with the given fields replaced by the non-null parameter values.
no setterinherited
- groupId → int
-
no setterinherited
- groupName → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
no setterinherited
- used → int
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_Sub2ApiAdminUserGroupRpmStatus value)) → TResult -
Available on Sub2ApiAdminUserGroupRpmStatus, provided by the Sub2ApiAdminUserGroupRpmStatusPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_Sub2ApiAdminUserGroupRpmStatus value)?) → TResult? -
Available on Sub2ApiAdminUserGroupRpmStatus, provided by the Sub2ApiAdminUserGroupRpmStatusPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_Sub2ApiAdminUserGroupRpmStatus value)?, {required TResult orElse()}) → TResult -
Available on Sub2ApiAdminUserGroupRpmStatus, provided by the Sub2ApiAdminUserGroupRpmStatusPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(int groupId, String groupName, int used, int limit, String source)?, {required TResult orElse()}) → TResult -
Available on Sub2ApiAdminUserGroupRpmStatus, provided by the Sub2ApiAdminUserGroupRpmStatusPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(int groupId, String groupName, int used, int limit, String source)) → TResult -
Available on Sub2ApiAdminUserGroupRpmStatus, provided by the Sub2ApiAdminUserGroupRpmStatusPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(int groupId, String groupName, int used, int limit, String source)?) → TResult? -
Available on Sub2ApiAdminUserGroupRpmStatus, provided by the Sub2ApiAdminUserGroupRpmStatusPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited