Sub2ApiAdminUserPlatformQuota class abstract

One platform's usage and limit windows in the Admin quota view.

Available extensions
Annotations
  • @freezed

Constructors

Sub2ApiAdminUserPlatformQuota({required Sub2ApiAdminQuotaPlatform platform, required Sub2ApiDecimal dailyUsageUsd, Sub2ApiDecimal? dailyLimitUsd, DateTime? dailyWindowResetsAt, DateTime? dailyWindowStart, required Sub2ApiDecimal weeklyUsageUsd, Sub2ApiDecimal? weeklyLimitUsd, DateTime? weeklyWindowResetsAt, DateTime? weeklyWindowStart, required Sub2ApiDecimal monthlyUsageUsd, Sub2ApiDecimal? monthlyLimitUsd, DateTime? monthlyWindowResetsAt, DateTime? monthlyWindowStart})
const
factory

Properties

copyWith → $Sub2ApiAdminUserPlatformQuotaCopyWith<Sub2ApiAdminUserPlatformQuota>
Create a copy of Sub2ApiAdminUserPlatformQuota with the given fields replaced by the non-null parameter values.
no setterinherited
dailyLimitUsd → Sub2ApiDecimal?
no setterinherited
dailyUsageUsd → Sub2ApiDecimal
no setterinherited
dailyWindowResetsAt → DateTime?
no setterinherited
dailyWindowStart → DateTime?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
monthlyLimitUsd → Sub2ApiDecimal?
no setterinherited
monthlyUsageUsd → Sub2ApiDecimal
no setterinherited
monthlyWindowResetsAt → DateTime?
no setterinherited
monthlyWindowStart → DateTime?
no setterinherited
platform → Sub2ApiAdminQuotaPlatform
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weeklyLimitUsd → Sub2ApiDecimal?
no setterinherited
weeklyUsageUsd → Sub2ApiDecimal
no setterinherited
weeklyWindowResetsAt → DateTime?
no setterinherited
weeklyWindowStart → DateTime?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Sub2ApiAdminUserPlatformQuota value)) → TResult

Available on Sub2ApiAdminUserPlatformQuota, provided by the Sub2ApiAdminUserPlatformQuotaPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Sub2ApiAdminUserPlatformQuota value)?) → TResult?

Available on Sub2ApiAdminUserPlatformQuota, provided by the Sub2ApiAdminUserPlatformQuotaPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Sub2ApiAdminUserPlatformQuota value)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminUserPlatformQuota, provided by the Sub2ApiAdminUserPlatformQuotaPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(Sub2ApiAdminQuotaPlatform platform, Sub2ApiDecimal dailyUsageUsd, Sub2ApiDecimal? dailyLimitUsd, DateTime? dailyWindowResetsAt, DateTime? dailyWindowStart, Sub2ApiDecimal weeklyUsageUsd, Sub2ApiDecimal? weeklyLimitUsd, DateTime? weeklyWindowResetsAt, DateTime? weeklyWindowStart, Sub2ApiDecimal monthlyUsageUsd, Sub2ApiDecimal? monthlyLimitUsd, DateTime? monthlyWindowResetsAt, DateTime? monthlyWindowStart)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminUserPlatformQuota, provided by the Sub2ApiAdminUserPlatformQuotaPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(Sub2ApiAdminQuotaPlatform platform, Sub2ApiDecimal dailyUsageUsd, Sub2ApiDecimal? dailyLimitUsd, DateTime? dailyWindowResetsAt, DateTime? dailyWindowStart, Sub2ApiDecimal weeklyUsageUsd, Sub2ApiDecimal? weeklyLimitUsd, DateTime? weeklyWindowResetsAt, DateTime? weeklyWindowStart, Sub2ApiDecimal monthlyUsageUsd, Sub2ApiDecimal? monthlyLimitUsd, DateTime? monthlyWindowResetsAt, DateTime? monthlyWindowStart)) → TResult

Available on Sub2ApiAdminUserPlatformQuota, provided by the Sub2ApiAdminUserPlatformQuotaPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(Sub2ApiAdminQuotaPlatform platform, Sub2ApiDecimal dailyUsageUsd, Sub2ApiDecimal? dailyLimitUsd, DateTime? dailyWindowResetsAt, DateTime? dailyWindowStart, Sub2ApiDecimal weeklyUsageUsd, Sub2ApiDecimal? weeklyLimitUsd, DateTime? weeklyWindowResetsAt, DateTime? weeklyWindowStart, Sub2ApiDecimal monthlyUsageUsd, Sub2ApiDecimal? monthlyLimitUsd, DateTime? monthlyWindowResetsAt, DateTime? monthlyWindowStart)?) → TResult?

Available on Sub2ApiAdminUserPlatformQuota, provided by the Sub2ApiAdminUserPlatformQuotaPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited