Sub2ApiAdminUserPlatformQuotaPatterns extension

Adds pattern-matching-related methods to Sub2ApiAdminUserPlatformQuota.

on

Methods

map<TResult extends Object?>(TResult $default(_Sub2ApiAdminUserPlatformQuota value)) → TResult

Available on Sub2ApiAdminUserPlatformQuota, provided by the Sub2ApiAdminUserPlatformQuotaPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Sub2ApiAdminUserPlatformQuota value)?) → TResult?

Available on Sub2ApiAdminUserPlatformQuota, provided by the Sub2ApiAdminUserPlatformQuotaPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Sub2ApiAdminUserPlatformQuota value)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminUserPlatformQuota, provided by the Sub2ApiAdminUserPlatformQuotaPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(Sub2ApiAdminQuotaPlatform platform, Sub2ApiDecimal dailyUsageUsd, Sub2ApiDecimal? dailyLimitUsd, DateTime? dailyWindowResetsAt, DateTime? dailyWindowStart, Sub2ApiDecimal weeklyUsageUsd, Sub2ApiDecimal? weeklyLimitUsd, DateTime? weeklyWindowResetsAt, DateTime? weeklyWindowStart, Sub2ApiDecimal monthlyUsageUsd, Sub2ApiDecimal? monthlyLimitUsd, DateTime? monthlyWindowResetsAt, DateTime? monthlyWindowStart)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminUserPlatformQuota, provided by the Sub2ApiAdminUserPlatformQuotaPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(Sub2ApiAdminQuotaPlatform platform, Sub2ApiDecimal dailyUsageUsd, Sub2ApiDecimal? dailyLimitUsd, DateTime? dailyWindowResetsAt, DateTime? dailyWindowStart, Sub2ApiDecimal weeklyUsageUsd, Sub2ApiDecimal? weeklyLimitUsd, DateTime? weeklyWindowResetsAt, DateTime? weeklyWindowStart, Sub2ApiDecimal monthlyUsageUsd, Sub2ApiDecimal? monthlyLimitUsd, DateTime? monthlyWindowResetsAt, DateTime? monthlyWindowStart)) → TResult

Available on Sub2ApiAdminUserPlatformQuota, provided by the Sub2ApiAdminUserPlatformQuotaPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(Sub2ApiAdminQuotaPlatform platform, Sub2ApiDecimal dailyUsageUsd, Sub2ApiDecimal? dailyLimitUsd, DateTime? dailyWindowResetsAt, DateTime? dailyWindowStart, Sub2ApiDecimal weeklyUsageUsd, Sub2ApiDecimal? weeklyLimitUsd, DateTime? weeklyWindowResetsAt, DateTime? weeklyWindowStart, Sub2ApiDecimal monthlyUsageUsd, Sub2ApiDecimal? monthlyLimitUsd, DateTime? monthlyWindowResetsAt, DateTime? monthlyWindowStart)?) → TResult?

Available on Sub2ApiAdminUserPlatformQuota, provided by the Sub2ApiAdminUserPlatformQuotaPatterns extension

A variant of when that fallback to returning null