Sub2ApiAdminUserPlatformQuotasPatterns extension

Adds pattern-matching-related methods to Sub2ApiAdminUserPlatformQuotas.

on

Methods

map<TResult extends Object?>(TResult $default(_Sub2ApiAdminUserPlatformQuotas value)) → TResult

Available on Sub2ApiAdminUserPlatformQuotas, provided by the Sub2ApiAdminUserPlatformQuotasPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Sub2ApiAdminUserPlatformQuotas value)?) → TResult?

Available on Sub2ApiAdminUserPlatformQuotas, provided by the Sub2ApiAdminUserPlatformQuotasPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Sub2ApiAdminUserPlatformQuotas value)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminUserPlatformQuotas, provided by the Sub2ApiAdminUserPlatformQuotasPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<Sub2ApiAdminUserPlatformQuota> quotas)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminUserPlatformQuotas, provided by the Sub2ApiAdminUserPlatformQuotasPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(List<Sub2ApiAdminUserPlatformQuota> quotas)) → TResult

Available on Sub2ApiAdminUserPlatformQuotas, provided by the Sub2ApiAdminUserPlatformQuotasPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<Sub2ApiAdminUserPlatformQuota> quotas)?) → TResult?

Available on Sub2ApiAdminUserPlatformQuotas, provided by the Sub2ApiAdminUserPlatformQuotasPatterns extension

A variant of when that fallback to returning null