Sub2ApiAdminUserUsage class final

Aggregate usage returned for one user and fixed period.

Constructors

Sub2ApiAdminUserUsage({required String period, required int totalRequests, required Sub2ApiDecimal totalCost, required int totalTokens, required Sub2ApiDecimal averageDurationMs})
const

Properties

averageDurationMs → Sub2ApiDecimal
final
hashCode → int
The hash code for this object.
no setterinherited
period → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCost → Sub2ApiDecimal
final
totalRequests → int
final
totalTokens → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited