Sub2ApiAdminWebSearchConfig class final
Constructors
-
Sub2ApiAdminWebSearchConfig({required bool enabled, required List<
Sub2ApiAdminWebSearchProvider> providers})
Properties
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
providers
→ List<
Sub2ApiAdminWebSearchProvider> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited