Sub2ApiAdminWebSearchResult class final

Constructors

Sub2ApiAdminWebSearchResult({required Uri url, required String title, required String snippet, required String pageAge})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
pageAge → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snippet → String
final
title → String
final
url → Uri
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited