Sub2ApiAdminWebSearchTestResult class final

Constructors

Sub2ApiAdminWebSearchTestResult({required String provider, required String query, required List<Sub2ApiAdminWebSearchResult> results})

Properties

hashCode → int
The hash code for this object.
no setterinherited
provider → String
final
query → String
final
results → List<Sub2ApiAdminWebSearchResult>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited