Sub2ApiStaticAdminApiKeyProvider class final

Immutable provider suitable when key rotation recreates the Ops client.

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Sub2ApiAdminApiKey
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

load() → Future<Sub2ApiAdminApiKey>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited