Sub2ApiMonitorDimension class final
String-valued V2 platform or model dimension.
Constructors
- Sub2ApiMonitorDimension({required String value, required String label, required String platform, required int requestCount})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited