Sub2ApiAdminAccountBatchDeleteResult class final

Constructors

Sub2ApiAdminAccountBatchDeleteResult({required int total, required int success, required int failed, required List<int> successIds, required List<int> failedIds, required List<Sub2ApiAdminAccountBatchError> errors})

Properties

errors → List<Sub2ApiAdminAccountBatchError>
final
failed → int
final
failedIds → List<int>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → int
final
successIds → List<int>
final
total → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited