Sub2ApiAdminAccountCreateInput class final
Constructors
-
Sub2ApiAdminAccountCreateInput({required String name, required Sub2ApiAdminAccountPlatform platform, required Sub2ApiAdminAccountType type, required Sub2ApiAdminCredentialSet credentials, String? notes, Sub2ApiAdminJsonObject extra = const Sub2ApiAdminJsonObject({}), int? proxyId, int concurrency = 0, int priority = 0, Sub2ApiDecimal? rateMultiplier, int? loadFactor, List<
int> groupIds = const [], DateTime? expiresAt, bool? autoPauseOnExpired, bool? upstreamBillingProbeEnabled, bool confirmMixedChannelRisk = false})
Properties
- autoPauseOnExpired → bool?
-
final
- concurrency → int
-
final
- confirmMixedChannelRisk → bool
-
final
- credentials → Sub2ApiAdminCredentialSet
-
final
- expiresAt → DateTime?
-
final
- extra → Sub2ApiAdminJsonObject
-
final
-
groupIds
→ List<
int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- loadFactor → int?
-
final
- name → String
-
final
- notes → String?
-
final
- platform → Sub2ApiAdminAccountPlatform
-
final
- priority → int
-
final
- proxyId → int?
-
final
- rateMultiplier → Sub2ApiDecimal?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Sub2ApiAdminAccountType
-
final
- upstreamBillingProbeEnabled → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited