Sub2ApiAdminAccountDataImportResult class final
Constructors
-
Sub2ApiAdminAccountDataImportResult({required int proxyCreated, required int proxyReused, required int proxyFailed, required int accountCreated, required int accountFailed, required List<
Sub2ApiAdminAccountDataImportError> errors})
Properties
- accountCreated → int
-
final
- accountFailed → int
-
final
-
errors
→ List<
Sub2ApiAdminAccountDataImportError> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- proxyCreated → int
-
final
- proxyFailed → int
-
final
- proxyReused → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited