Sub2ApiAdminAccountModel class final
Constructors
Properties
- created → int?
-
final
- createdAt → DateTime?
-
final
- displayName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- object → String
-
final
- ownedBy → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited