Sub2ApiAdminAccountModelStats class final
Constructors
- Sub2ApiAdminAccountModelStats({required String model, required int requests, required int inputTokens, required int outputTokens, required int cacheCreationTokens, required int cacheReadTokens, required int totalTokens, required Sub2ApiDecimal cost, required Sub2ApiDecimal actualCost, required Sub2ApiDecimal accountCost})
-
const
Properties
- accountCost → Sub2ApiDecimal
-
final
- actualCost → Sub2ApiDecimal
-
final
- cacheCreationTokens → int
-
final
- cacheReadTokens → int
-
final
- cost → Sub2ApiDecimal
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputTokens → int
-
final
- model → String
-
final
- outputTokens → int
-
final
- requests → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalTokens → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited