Sub2ApiAdminAccountTierRefreshResult class final
Constructors
- Sub2ApiAdminAccountTierRefreshResult({required String tierId, required Sub2ApiAdminJsonObject storageInfo, required int driveStorageLimit, required int driveStorageUsage, required DateTime updatedAt})
-
const
Properties
- driveStorageLimit → int
-
final
- driveStorageUsage → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageInfo → Sub2ApiAdminJsonObject
-
final
- tierId → String
-
final
- updatedAt → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited