Sub2ApiAdminAccountUsage class final
Constructors
-
Sub2ApiAdminAccountUsage({required String source, required Map<
String, Sub2ApiAdminAccountUsageProgress> windows, required Sub2ApiAdminJsonObject providerDetails, DateTime? updatedAt})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- providerDetails → Sub2ApiAdminJsonObject
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
final
- updatedAt → DateTime?
-
final
-
windows
→ Map<
String, Sub2ApiAdminAccountUsageProgress> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited