Sub2ApiAdminAccountUsageProgress class final

Constructors

Sub2ApiAdminAccountUsageProgress({required Sub2ApiDecimal utilization, required int remainingSeconds, required int usedRequests, required int limitRequests, DateTime? resetsAt, Sub2ApiAdminAccountTodayStats? windowStats})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
limitRequests → int
final
remainingSeconds → int
final
resetsAt → DateTime?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usedRequests → int
final
utilization → Sub2ApiDecimal
final
windowStats → Sub2ApiAdminAccountTodayStats?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited