Sub2ApiAdminAffiliateRecordQuery class final

Constructors

Sub2ApiAdminAffiliateRecordQuery({int page = 1, int pageSize = 20, String? search, DateTime? startAt, DateTime? endAt, Sub2ApiAdminAffiliateRecordSort sortBy = Sub2ApiAdminAffiliateRecordSort.createdAt, Sub2ApiAdminAffiliateSortOrder sortOrder = Sub2ApiAdminAffiliateSortOrder.descending})
const

Properties

endAt → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
page → int
final
pageSize → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
final
sortBy → Sub2ApiAdminAffiliateRecordSort
final
sortOrder → Sub2ApiAdminAffiliateSortOrder
final
startAt → DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited