Sub2ApiAdminAffiliateTransferRecord class final
Constructors
- Sub2ApiAdminAffiliateTransferRecord({required int ledgerId, required int userId, required String userEmail, required String username, required Sub2ApiDecimal amount, required bool snapshotAvailable, required DateTime createdAt, Sub2ApiDecimal? balanceAfter, Sub2ApiDecimal? availableQuotaAfter, Sub2ApiDecimal? frozenQuotaAfter, Sub2ApiDecimal? historyQuotaAfter})
-
const
Properties
- amount → Sub2ApiDecimal
-
final
- availableQuotaAfter → Sub2ApiDecimal?
-
final
- balanceAfter → Sub2ApiDecimal?
-
final
- createdAt → DateTime
-
final
- frozenQuotaAfter → Sub2ApiDecimal?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- historyQuotaAfter → Sub2ApiDecimal?
-
final
- ledgerId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapshotAvailable → bool
-
final
- userEmail → String
-
final
- userId → int
-
final
- username → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited