Sub2ApiAdminAffiliateUser class final
Constructors
- Sub2ApiAdminAffiliateUser({required int userId, required String email, required String username, required String affiliateCode, required bool affiliateCodeCustom, required int affiliateCount, Sub2ApiDecimal? rebateRatePercent})
-
const
Properties
- affiliateCode → String
-
final
- affiliateCodeCustom → bool
-
final
- affiliateCount → int
-
final
- email → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rebateRatePercent → Sub2ApiDecimal?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
final
- username → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited