Sub2ApiAdminAffiliateUserOverview class final
Constructors
- Sub2ApiAdminAffiliateUserOverview({required int userId, required String email, required String username, required String affiliateCode, required Sub2ApiDecimal rebateRatePercent, required int invitedCount, required int rebatedInviteeCount, required Sub2ApiDecimal availableQuota, required Sub2ApiDecimal historyQuota})
-
const
Properties
- affiliateCode → String
-
final
- availableQuota → Sub2ApiDecimal
-
final
- email → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- historyQuota → Sub2ApiDecimal
-
final
- invitedCount → int
-
final
- rebatedInviteeCount → int
-
final
- rebateRatePercent → Sub2ApiDecimal
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
final
- username → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited