Sub2ApiAdminAggregationBackfillRequest class abstract
Requested aggregation interval for a controlled dashboard backfill.
- Available extensions
- Annotations
-
- @freezed
Constructors
- Sub2ApiAdminAggregationBackfillRequest({required DateTime start, required DateTime end})
-
constfactory
Properties
-
copyWith
→ $Sub2ApiAdminAggregationBackfillRequestCopyWith<
Sub2ApiAdminAggregationBackfillRequest> -
Create a copy of Sub2ApiAdminAggregationBackfillRequest
with the given fields replaced by the non-null parameter values.
no setterinherited
- end → DateTime
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → DateTime
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_Sub2ApiAdminAggregationBackfillRequest value)) → TResult -
Available on Sub2ApiAdminAggregationBackfillRequest, provided by the Sub2ApiAdminAggregationBackfillRequestPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_Sub2ApiAdminAggregationBackfillRequest value)?) → TResult? -
Available on Sub2ApiAdminAggregationBackfillRequest, provided by the Sub2ApiAdminAggregationBackfillRequestPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_Sub2ApiAdminAggregationBackfillRequest value)?, {required TResult orElse()}) → TResult -
Available on Sub2ApiAdminAggregationBackfillRequest, provided by the Sub2ApiAdminAggregationBackfillRequestPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(DateTime start, DateTime end)?, {required TResult orElse()}) → TResult -
Available on Sub2ApiAdminAggregationBackfillRequest, provided by the Sub2ApiAdminAggregationBackfillRequestPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(DateTime start, DateTime end)) → TResult -
Available on Sub2ApiAdminAggregationBackfillRequest, provided by the Sub2ApiAdminAggregationBackfillRequestPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(DateTime start, DateTime end)?) → TResult? -
Available on Sub2ApiAdminAggregationBackfillRequest, provided by the Sub2ApiAdminAggregationBackfillRequestPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited