Sub2ApiAdminAnnouncementReadStatus class final
Constructors
- Sub2ApiAdminAnnouncementReadStatus({required int userId, required String email, required String username, required Sub2ApiDecimal balance, required bool eligible, required DateTime? readAt})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited