Sub2ApiAdminAnnouncementReadStatusQuery class final
Constructors
- Sub2ApiAdminAnnouncementReadStatusQuery({int? page, int? pageSize, String? search, Sub2ApiAdminAnnouncementReadSortBy sortBy = Sub2ApiAdminAnnouncementReadSortBy.email, Sub2ApiAdminAnnouncementSortOrder sortOrder = Sub2ApiAdminAnnouncementSortOrder.asc})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- page → int?
-
final
- pageSize → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- search → String?
-
final
- sortBy → Sub2ApiAdminAnnouncementReadSortBy
-
final
- sortOrder → Sub2ApiAdminAnnouncementSortOrder
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited