Sub2ApiAdminBackupDownload class final
Constructors
-
Sub2ApiAdminBackupDownload({Sub2ApiAdminBackupDownloadUrl? url, List<
Sub2ApiAdminBackupDownloadPart> parts = const <Sub2ApiAdminBackupDownloadPart>[]})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
parts
→ List<
Sub2ApiAdminBackupDownloadPart> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → Sub2ApiAdminBackupDownloadUrl?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited