Sub2ApiAdminBackupS3Config class final
Constructors
- Sub2ApiAdminBackupS3Config({Uri? endpoint, required String region, required String bucket, Sub2ApiAdminBackupAccessKeyId? accessKeyId, required String prefix, required bool forcePathStyle})
-
const
Properties
- accessKeyId → Sub2ApiAdminBackupAccessKeyId?
-
final
- bucket → String
-
final
- endpoint → Uri?
-
final
- forcePathStyle → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- prefix → String
-
final
- region → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited