Sub2ApiAdminBalanceHistoryPage class final

Paginated balance history with the user's all-time recharge total.

Constructors

Sub2ApiAdminBalanceHistoryPage({required List<Sub2ApiAdminBalanceHistoryRecord> items, required int page, required int pageSize, required int total, required int pages, required Sub2ApiDecimal totalRecharged})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
items → List<Sub2ApiAdminBalanceHistoryRecord>
final
page → int
final
pages → int
final
pageSize → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total → int
final
totalRecharged → Sub2ApiDecimal
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited