Sub2ApiAdminBatchConcurrencyRequest class abstract
Request to set or add concurrency for selected users or all users.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
Sub2ApiAdminBatchConcurrencyRequest({@Default.new(<int>[]) List<
int> userIds, @Default.new(false) bool all, required int concurrency, required Sub2ApiAdminBatchConcurrencyMode mode}) -
constfactory
Properties
- all → bool
-
no setterinherited
- concurrency → int
-
no setterinherited
-
copyWith
→ $Sub2ApiAdminBatchConcurrencyRequestCopyWith<
Sub2ApiAdminBatchConcurrencyRequest> -
Create a copy of Sub2ApiAdminBatchConcurrencyRequest
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → Sub2ApiAdminBatchConcurrencyMode
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
userIds
→ List<
int> -
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_Sub2ApiAdminBatchConcurrencyRequest value)) → TResult -
Available on Sub2ApiAdminBatchConcurrencyRequest, provided by the Sub2ApiAdminBatchConcurrencyRequestPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_Sub2ApiAdminBatchConcurrencyRequest value)?) → TResult? -
Available on Sub2ApiAdminBatchConcurrencyRequest, provided by the Sub2ApiAdminBatchConcurrencyRequestPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_Sub2ApiAdminBatchConcurrencyRequest value)?, {required TResult orElse()}) → TResult -
Available on Sub2ApiAdminBatchConcurrencyRequest, provided by the Sub2ApiAdminBatchConcurrencyRequestPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(List< int> userIds, bool all, int concurrency, Sub2ApiAdminBatchConcurrencyMode mode)?, {required TResult orElse()}) → TResult -
Available on Sub2ApiAdminBatchConcurrencyRequest, provided by the Sub2ApiAdminBatchConcurrencyRequestPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(List< int> userIds, bool all, int concurrency, Sub2ApiAdminBatchConcurrencyMode mode)) → TResult -
Available on Sub2ApiAdminBatchConcurrencyRequest, provided by the Sub2ApiAdminBatchConcurrencyRequestPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(List< int> userIds, bool all, int concurrency, Sub2ApiAdminBatchConcurrencyMode mode)?) → TResult? -
Available on Sub2ApiAdminBatchConcurrencyRequest, provided by the Sub2ApiAdminBatchConcurrencyRequestPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited