Sub2ApiAdminBatchCreateProxyInput class final

Constructors

Sub2ApiAdminBatchCreateProxyInput({required Sub2ApiAdminProxyProtocol protocol, required String host, required int port, String? username, Sub2ApiAdminProxyPassword? password})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
host → String
final
password → Sub2ApiAdminProxyPassword?
final
port → int
final
protocol → Sub2ApiAdminProxyProtocol
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited