Sub2ApiAdminBindIdentityChannelRequest class final
Optional channel binding attached to an Admin identity bind request.
Constructors
- Sub2ApiAdminBindIdentityChannelRequest({required String channel, required String channelAppId, required String channelSubject, Sub2ApiAdminJsonObject? metadata})
-
const
Properties
- channel → String
-
final
- channelAppId → String
-
final
- channelSubject → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metadata → Sub2ApiAdminJsonObject?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited