Sub2ApiAdminCNQuotaResult class final
Constructors
-
Sub2ApiAdminCNQuotaResult({required Sub2ApiAdminCNProvider provider, required String source, required bool success, required bool credentialValid, required List<
Sub2ApiAdminCNQuotaTier> tiers, required String planLevel, required int? statusCode, required DateTime fetchedAt, required bool persisted, required String error})
Properties
- credentialValid → bool
-
final
- error → String
-
final
- fetchedAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- persisted → bool
-
final
- planLevel → String
-
final
- provider → Sub2ApiAdminCNProvider
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
final
- statusCode → int?
-
final
- success → bool
-
final
-
tiers
→ List<
Sub2ApiAdminCNQuotaTier> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited