Sub2ApiAdminChannel class final
Constructors
-
Sub2ApiAdminChannel({required int id, required String name, required String description, required Sub2ApiAdminChannelStatus status, required Sub2ApiAdminChannelBillingModelSource billingModelSource, required bool restrictModels, required String features, required Sub2ApiAdminJsonObject? featuresConfig, required List<
int> groupIds, required List<Sub2ApiAdminChannelModelPricing> modelPricing, required Map<String, Map< modelMapping, required bool applyPricingToAccountStats, required List<String, String> >Sub2ApiAdminChannelAccountStatsPricingRule> accountStatsPricingRules, required DateTime createdAt, required DateTime updatedAt})
Properties
-
accountStatsPricingRules
→ List<
Sub2ApiAdminChannelAccountStatsPricingRule> -
final
- applyPricingToAccountStats → bool
-
final
- billingModelSource → Sub2ApiAdminChannelBillingModelSource
-
final
- createdAt → DateTime
-
final
- description → String
-
final
- features → String
-
final
- featuresConfig → Sub2ApiAdminJsonObject?
-
final
-
groupIds
→ List<
int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
-
modelMapping
→ Map<
String, Map< String, String> > -
final
-
modelPricing
→ List<
Sub2ApiAdminChannelModelPricing> -
final
- name → String
-
final
- restrictModels → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → Sub2ApiAdminChannelStatus
-
final
- updatedAt → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited