Sub2ApiAdminChannelAccountStatsPricingRuleInput class final
Constructors
-
Sub2ApiAdminChannelAccountStatsPricingRuleInput({required String name, required List<
int> groupIds, required List<int> accountIds, required List<Sub2ApiAdminChannelModelPricingInput> pricing})
Properties
-
accountIds
→ List<
int> -
final
-
groupIds
→ List<
int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
-
pricing
→ List<
Sub2ApiAdminChannelModelPricingInput> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited