Sub2ApiAdminChannelMonitorHistoryItem class final
Constructors
- Sub2ApiAdminChannelMonitorHistoryItem({required int id, required String model, required String status, required String message, required DateTime checkedAt, int? latencyMs, int? pingLatencyMs, Sub2ApiMonitorQuotaSnapshot? quota})
-
const
Properties
- checkedAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- latencyMs → int?
-
final
- message → String
-
final
- model → String
-
final
- pingLatencyMs → int?
-
final
- quota → Sub2ApiMonitorQuotaSnapshot?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited