Sub2ApiAdminChannelMonitorTemplate class final
Constructors
-
Sub2ApiAdminChannelMonitorTemplate({required int id, required String name, required Sub2ApiAdminMonitorTemplateProvider provider, required Sub2ApiAdminMonitorTemplateApiMode apiMode, required String description, required Map<
String, String> extraHeaders, required Sub2ApiAdminMonitorTemplateBodyMode bodyOverrideMode, required Sub2ApiAdminJsonObject? bodyOverride, required DateTime createdAt, required DateTime updatedAt, required int associatedMonitors})
Properties
- apiMode → Sub2ApiAdminMonitorTemplateApiMode
-
final
- associatedMonitors → int
-
final
- bodyOverride → Sub2ApiAdminJsonObject?
-
final
- bodyOverrideMode → Sub2ApiAdminMonitorTemplateBodyMode
-
final
- createdAt → DateTime
-
final
- description → String
-
final
-
extraHeaders
→ Map<
String, String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- name → String
-
final
- provider → Sub2ApiAdminMonitorTemplateProvider
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited