Sub2ApiAdminCompositeRoute class final
Constructors
- Sub2ApiAdminCompositeRoute({required int id, required int groupId, required String publicModel, required Sub2ApiAdminCompositeRouteMatchType matchType, required Sub2ApiAdminGroupPlatform targetPlatform, required String upstreamModel, required Sub2ApiAdminCompositeRouteEndpoint endpoint, required int priority, required bool enabled, required String notes, required DateTime createdAt, required DateTime updatedAt})
-
const
Properties
- createdAt → DateTime
-
final
- enabled → bool
-
final
- endpoint → Sub2ApiAdminCompositeRouteEndpoint
-
final
- groupId → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- matchType → Sub2ApiAdminCompositeRouteMatchType
-
final
- notes → String
-
final
- priority → int
-
final
- publicModel → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetPlatform → Sub2ApiAdminGroupPlatform
-
final
- updatedAt → DateTime
-
final
- upstreamModel → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited