Sub2ApiAdminCompositeRouteRequest class final

Constructors

Sub2ApiAdminCompositeRouteRequest({required String publicModel, required Sub2ApiAdminGroupPlatform targetPlatform, Sub2ApiAdminCompositeRouteMatchType matchType = Sub2ApiAdminCompositeRouteMatchType.exact, String upstreamModel = '', Sub2ApiAdminCompositeRouteEndpoint endpoint = Sub2ApiAdminCompositeRouteEndpoint.any, int priority = 0, bool enabled = true, String notes = ''})
const

Properties

enabled → bool
final
endpoint → Sub2ApiAdminCompositeRouteEndpoint
final
hashCode → int
The hash code for this object.
no setterinherited
matchType → Sub2ApiAdminCompositeRouteMatchType
final
notes → String
final
priority → int
final
publicModel → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetPlatform → Sub2ApiAdminGroupPlatform
final
upstreamModel → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited