Sub2ApiAdminCreateChannelMonitorRequest class final
Constructors
-
Sub2ApiAdminCreateChannelMonitorRequest({required String name, required Sub2ApiAdminChannelMonitorProvider provider, required int intervalSeconds, Sub2ApiAdminChannelMonitorApiMode apiMode = Sub2ApiAdminChannelMonitorApiMode.chatCompletions, Uri? endpoint, Sub2ApiAdminCredentialSecret? apiKey, String primaryModel = '', List<
String> extraModels = const [], String groupName = '', bool enabled = true, int jitterSeconds = 0, int? templateId, Map<String, String> extraHeaders = const {}, Sub2ApiAdminChannelMonitorBodyMode bodyOverrideMode = Sub2ApiAdminChannelMonitorBodyMode.off, Sub2ApiAdminJsonObject? bodyOverride, Sub2ApiAdminChannelMonitorCheckMode checkMode = Sub2ApiAdminChannelMonitorCheckMode.probe, int? accountId})
Properties
- accountId → int?
-
final
- apiKey → Sub2ApiAdminCredentialSecret?
-
final
- apiMode → Sub2ApiAdminChannelMonitorApiMode
-
final
- bodyOverride → Sub2ApiAdminJsonObject?
-
final
- bodyOverrideMode → Sub2ApiAdminChannelMonitorBodyMode
-
final
- checkMode → Sub2ApiAdminChannelMonitorCheckMode
-
final
- enabled → bool
-
final
- endpoint → Uri?
-
final
-
extraHeaders
→ Map<
String, String> -
final
-
extraModels
→ List<
String> -
final
- groupName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- intervalSeconds → int
-
final
- jitterSeconds → int
-
final
- name → String
-
final
- primaryModel → String
-
final
- provider → Sub2ApiAdminChannelMonitorProvider
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- templateId → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited