Sub2ApiAdminCreateOpenAIFromOAuthRequest class final
Constructors
-
Sub2ApiAdminCreateOpenAIFromOAuthRequest({required Sub2ApiAdminOpenAIExchangeCodeRequest exchange, String name = '', int concurrency = 0, int priority = 0, List<
int> groupIds = const []})
Properties
- concurrency → int
-
final
- exchange → Sub2ApiAdminOpenAIExchangeCodeRequest
-
final
-
groupIds
→ List<
int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- priority → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited