Sub2ApiAdminCreateSubscriptionPlanRequest class final
Constructors
- Sub2ApiAdminCreateSubscriptionPlanRequest({required int groupId, required String name, String description = '', required Sub2ApiDecimal price, Sub2ApiDecimal? originalPrice, String currency = '', required int validityDays, String validityUnit = 'day', String features = '', String productName = '', bool forSale = true, int sortOrder = 0})
-
const
Properties
- currency → String
-
final
- description → String
-
final
- features → String
-
final
- forSale → bool
-
final
- groupId → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- originalPrice → Sub2ApiDecimal?
-
final
- price → Sub2ApiDecimal
-
final
- productName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortOrder → int
-
final
- validityDays → int
-
final
- validityUnit → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited