Sub2ApiAdminCrsPreviewResult class final

Constructors

Sub2ApiAdminCrsPreviewResult({required List<Sub2ApiAdminCrsPreviewAccount> newAccounts, required List<Sub2ApiAdminCrsPreviewAccount> existingAccounts})

Properties

existingAccounts → List<Sub2ApiAdminCrsPreviewAccount>
final
hashCode → int
The hash code for this object.
no setterinherited
newAccounts → List<Sub2ApiAdminCrsPreviewAccount>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited