Sub2ApiAdminCrsSyncResult class final
Constructors
-
Sub2ApiAdminCrsSyncResult({required int created, required int updated, required int skipped, required int failed, required List<
Sub2ApiAdminCrsSyncItem> items})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited