Sub2ApiAdminDataArtifact class final

Constructors

Sub2ApiAdminDataArtifact({required Sub2ApiAdminDataManagementPath localPath, required int sizeBytes, required String sha256})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
localPath → Sub2ApiAdminDataManagementPath
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sha256 → String
final
sizeBytes → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited