Sub2ApiAdminDataBackupJob class final

Constructors

Sub2ApiAdminDataBackupJob({required String jobId, required Sub2ApiAdminDataBackupType backupType, required String status, required String triggeredBy, required String idempotencyKey, required bool uploadToS3, required String s3ProfileId, required String postgresProfileId, required String redisProfileId, DateTime? startedAt, DateTime? finishedAt, required Sub2ApiAdminOpsErrorContent errorMessage, required Sub2ApiAdminDataArtifact artifact, required Sub2ApiAdminDataS3Object s3Object})
const

Properties

artifact → Sub2ApiAdminDataArtifact
final
backupType → Sub2ApiAdminDataBackupType
final
errorMessage → Sub2ApiAdminOpsErrorContent
final
finishedAt → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
idempotencyKey → String
final
jobId → String
final
postgresProfileId → String
final
redisProfileId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Object → Sub2ApiAdminDataS3Object
final
s3ProfileId → String
final
startedAt → DateTime?
final
status → String
final
triggeredBy → String
final
uploadToS3 → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited