Sub2ApiAdminDataBackupJobQuery class final
Constructors
- Sub2ApiAdminDataBackupJobQuery({int pageSize = 20, String pageToken = '', String status = '', Sub2ApiAdminDataBackupType? backupType})
-
const
Properties
- backupType → Sub2ApiAdminDataBackupType?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pageSize → int
-
final
- pageToken → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited