Sub2ApiAdminDataBackupJobRequest class final

Constructors

Sub2ApiAdminDataBackupJobRequest({required Sub2ApiAdminDataBackupType backupType, required bool uploadToS3, String s3ProfileId = '', String postgresProfileId = '', String redisProfileId = '', required String idempotencyKey})
const

Properties

backupType → Sub2ApiAdminDataBackupType
final
hashCode → int
The hash code for this object.
no setterinherited
idempotencyKey → String
final
postgresProfileId → String
final
redisProfileId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3ProfileId → String
final
uploadToS3 → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited