Sub2ApiAdminDataS3Config class final
Constructors
- Sub2ApiAdminDataS3Config({required bool enabled, Uri? endpoint, required String region, required String bucket, Sub2ApiAdminBackupAccessKeyId? accessKeyId, Sub2ApiAdminBackupSecretAccessKey? secretAccessKey, required bool secretConfigured, required String prefix, required bool forcePathStyle, required bool useSsl})
-
const
Properties
- accessKeyId → Sub2ApiAdminBackupAccessKeyId?
-
final
- bucket → String
-
final
- enabled → bool
-
final
- endpoint → Uri?
-
final
- forcePathStyle → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- prefix → String
-
final
- region → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secretAccessKey → Sub2ApiAdminBackupSecretAccessKey?
-
final
- secretConfigured → bool
-
final
- useSsl → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited