Sub2ApiAdminDataS3Profile class final
Constructors
- Sub2ApiAdminDataS3Profile({required String profileId, required String name, required bool isActive, required Sub2ApiAdminDataS3Config s3, required bool secretConfigured, DateTime? createdAt, DateTime? updatedAt})
-
const
Properties
- createdAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
final
- name → String
-
final
- profileId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- s3 → Sub2ApiAdminDataS3Config
-
final
- secretConfigured → bool
-
final
- updatedAt → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited