Sub2ApiAdminEmailTemplateList class final
Constructors
-
Sub2ApiAdminEmailTemplateList({required List<
Sub2ApiAdminEmailTemplateEvent> events, required List<String> locales, required List<Sub2ApiAdminEmailTemplateSummary> templates, required List<String> placeholders})
Properties
-
events
→ List<
Sub2ApiAdminEmailTemplateEvent> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
locales
→ List<
String> -
final
-
placeholders
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
templates
→ List<
Sub2ApiAdminEmailTemplateSummary> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited