Sub2ApiAdminErrorPassthroughRule class final
Constructors
-
Sub2ApiAdminErrorPassthroughRule({required int id, required String name, required bool enabled, required int priority, required List<
int> errorCodes, required List<String> keywords, required Sub2ApiAdminErrorPassthroughMatchMode matchMode, required List<String> platforms, required bool passthroughCode, required int? responseCode, required bool passthroughBody, required String? customMessage, required bool skipMonitoring, required String? description, required DateTime createdAt, required DateTime updatedAt})
Properties
- createdAt → DateTime
-
final
- customMessage → String?
-
final
- description → String?
-
final
- enabled → bool
-
final
-
errorCodes
→ List<
int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
-
keywords
→ List<
String> -
final
- matchMode → Sub2ApiAdminErrorPassthroughMatchMode
-
final
- name → String
-
final
- passthroughBody → bool
-
final
- passthroughCode → bool
-
final
-
platforms
→ List<
String> -
final
- priority → int
-
final
- responseCode → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipMonitoring → bool
-
final
- updatedAt → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited