Sub2ApiAdminGrokBillingSummary class final
Constructors
-
Sub2ApiAdminGrokBillingSummary({required String periodType, Sub2ApiDecimal? usagePercent, required String periodStart, required String periodEnd, required List<
Sub2ApiAdminGrokBillingProduct> productUsage, Sub2ApiDecimal? monthlyLimitCents, Sub2ApiDecimal? usedCents, Sub2ApiDecimal? includedUsedCents, required String billingPeriodStart, required String billingPeriodEnd, Sub2ApiDecimal? usedPercent, Sub2ApiDecimal? prepaidBalance, Sub2ApiDecimal? monthlyLimit, Sub2ApiDecimal? monthlyUsed, Sub2ApiDecimal? onDemandCap, Sub2ApiDecimal? onDemandUsed, required String topUpMethod, required bool isUnifiedBillingUser, required String plan, required int statusCode, required int weeklyStatusCode, required int monthlyStatusCode, required String source, DateTime? fetchedAt, DateTime? updatedAt, DateTime? weeklyUpdatedAt, DateTime? monthlyUpdatedAt, required bool partial, required List<String> failedWindows})
Properties
- billingPeriodEnd → String
-
final
- billingPeriodStart → String
-
final
-
failedWindows
→ List<
String> -
final
- fetchedAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- includedUsedCents → Sub2ApiDecimal?
-
final
- isUnifiedBillingUser → bool
-
final
- monthlyLimit → Sub2ApiDecimal?
-
final
- monthlyLimitCents → Sub2ApiDecimal?
-
final
- monthlyStatusCode → int
-
final
- monthlyUpdatedAt → DateTime?
-
final
- monthlyUsed → Sub2ApiDecimal?
-
final
- onDemandCap → Sub2ApiDecimal?
-
final
- onDemandUsed → Sub2ApiDecimal?
-
final
- partial → bool
-
final
- periodEnd → String
-
final
- periodStart → String
-
final
- periodType → String
-
final
- plan → String
-
final
- prepaidBalance → Sub2ApiDecimal?
-
final
-
productUsage
→ List<
Sub2ApiAdminGrokBillingProduct> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
final
- statusCode → int
-
final
- topUpMethod → String
-
final
- updatedAt → DateTime?
-
final
- usagePercent → Sub2ApiDecimal?
-
final
- usedCents → Sub2ApiDecimal?
-
final
- usedPercent → Sub2ApiDecimal?
-
final
- weeklyStatusCode → int
-
final
- weeklyUpdatedAt → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited