Sub2ApiAdminGrokExchangeCodeRequest class final
Constructors
- Sub2ApiAdminGrokExchangeCodeRequest({required Sub2ApiGrokOAuthSessionId sessionId, required Sub2ApiOAuthAuthorizationCode code, required Sub2ApiGrokOAuthState state, Uri? redirectUri, int? proxyId})
-
const
Properties
- code → Sub2ApiOAuthAuthorizationCode
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- proxyId → int?
-
final
- redirectUri → Uri?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → Sub2ApiGrokOAuthSessionId
-
final
- state → Sub2ApiGrokOAuthState
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited