Sub2ApiAdminGrokPasswordRequest class final
Constructors
- Sub2ApiAdminGrokPasswordRequest({required String email, required Sub2ApiPassword password, int? proxyId})
-
const
Properties
- email → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- password → Sub2ApiPassword
-
final
- proxyId → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited