Sub2ApiAdminGrokReconcileResult class final
Constructors
-
Sub2ApiAdminGrokReconcileResult({required bool dryRun, required int scanned, required int actionable, required int wouldBlock, required int wouldRefresh, required int blocked, required int refreshed, required int skipped, required int failed, required int partial, required List<
Sub2ApiAdminGrokReconcileItem> items, required int nextAfterId, required bool hasMore})
Properties
- actionable → int
-
final
- blocked → int
-
final
- dryRun → bool
-
final
- failed → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMore → bool
-
final
-
items
→ List<
Sub2ApiAdminGrokReconcileItem> -
final
- nextAfterId → int
-
final
- partial → int
-
final
- refreshed → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanned → int
-
final
- skipped → int
-
final
- wouldBlock → int
-
final
- wouldRefresh → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited