Sub2ApiAdminGrokRuntimeCheck class final

Constructors

Sub2ApiAdminGrokRuntimeCheck({required String value, required bool valid, required String error, required bool isDefault})
const

Properties

error → String
final
hashCode → int
The hash code for this object.
no setterinherited
isDefault → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valid → bool
final
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited