Sub2ApiAdminGrokSsoImportResult class final

Properties

created → List<Sub2ApiAdminGrokSsoImportItem>
final
failed → List<Sub2ApiAdminGrokSsoImportItem>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited