Sub2ApiAdminGrokTokenInfo class final
Constructors
- Sub2ApiAdminGrokTokenInfo({required Sub2ApiAccessToken accessToken, required int expiresIn, required DateTime expiresAt, required String tokenType, required String clientId, required String scope, required String email, required String subject, required String teamId, required String subscriptionTier, required String entitlementStatus, Sub2ApiRefreshToken? refreshToken, Sub2ApiGrokIdToken? idToken})
-
const
Properties
- accessToken → Sub2ApiAccessToken
-
final
- clientId → String
-
final
- email → String
-
final
- entitlementStatus → String
-
final
- expiresAt → DateTime
-
final
- expiresIn → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idToken → Sub2ApiGrokIdToken?
-
final
- refreshToken → Sub2ApiRefreshToken?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → String
-
final
- subject → String
-
final
- subscriptionTier → String
-
final
- teamId → String
-
final
- tokenType → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited