Sub2ApiAdminGroupRateEntry class final
Constructors
- Sub2ApiAdminGroupRateEntry({required int userId, required String userName, required String userEmail, required String userNotes, required String userStatus, Sub2ApiDecimal? rateMultiplier, int? rpmOverride})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- rateMultiplier → Sub2ApiDecimal?
-
final
- rpmOverride → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userEmail → String
-
final
- userId → int
-
final
- userName → String
-
final
- userNotes → String
-
final
- userStatus → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited