Sub2ApiAdminImageStorageSettingsInput class final
Constructors
- Sub2ApiAdminImageStorageSettingsInput({required bool enabled, required bool reuseBackupS3, required String bucket, required String prefix, Uri? publicBaseUrl, required int presignExpiryHours, required int maxDownloadBytes, Uri? endpoint, required String region, Sub2ApiAdminBackupAccessKeyId? accessKeyId, Sub2ApiAdminBackupSecretAccessKey? secretAccessKey, required bool forcePathStyle})
-
const
Properties
- accessKeyId → Sub2ApiAdminBackupAccessKeyId?
-
final
- bucket → String
-
final
- enabled → bool
-
final
- endpoint → Uri?
-
final
- forcePathStyle → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxDownloadBytes → int
-
final
- prefix → String
-
final
- presignExpiryHours → int
-
final
- publicBaseUrl → Uri?
-
final
- region → String
-
final
- reuseBackupS3 → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secretAccessKey → Sub2ApiAdminBackupSecretAccessKey?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited