Sub2ApiAdminJsonArray class final
JSON array metadata value.
- Inheritance
-
- Object
- Sub2ApiAdminJsonValue
- Sub2ApiAdminJsonArray
Constructors
-
Sub2ApiAdminJsonArray(List<
Sub2ApiAdminJsonValue> values) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ List<
Sub2ApiAdminJsonValue> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toWire(
) → Object -
Converts this typed value to the package-internal JSON wire shape.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited