Sub2ApiAdminJsonValue class sealed
Typed recursive JSON value used for provider-owned identity metadata.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toWire(
) → Object? - Converts this typed value to the package-internal JSON wire shape.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited