Sub2ApiAdminOAuthTokenInfo class final
Constructors
- Sub2ApiAdminOAuthTokenInfo({required Sub2ApiAccessToken accessToken, required String tokenType, required Duration expiresIn, required DateTime expiresAt, required String scope, required String organizationUuid, required String accountUuid, required String emailAddress, Sub2ApiRefreshToken? refreshToken})
-
const
Properties
- accessToken → Sub2ApiAccessToken
-
final
- accountUuid → String
-
final
- emailAddress → String
-
final
- expiresAt → DateTime
-
final
- expiresIn → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- organizationUuid → String
-
final
- refreshToken → Sub2ApiRefreshToken?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → String
-
final
- tokenType → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited