Sub2ApiAdminOllamaCloudUsageState class final

Constructors

Sub2ApiAdminOllamaCloudUsageState({required int accountId, required bool eligible, required bool configured, required bool autoRefreshEnabled, required bool encryptionKeyConfigured, Sub2ApiAdminOllamaCloudUsageSnapshot? snapshot})
const

Properties

accountId → int
final
autoRefreshEnabled → bool
final
configured → bool
final
eligible → bool
final
encryptionKeyConfigured → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshot → Sub2ApiAdminOllamaCloudUsageSnapshot?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited