Sub2ApiAdminOpenAIRateLimit class final
Constructors
- Sub2ApiAdminOpenAIRateLimit({required bool allowed, required bool limitReached, Sub2ApiAdminOpenAIRateLimitWindow? primaryWindow, Sub2ApiAdminOpenAIRateLimitWindow? secondaryWindow})
-
const
Properties
- allowed → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limitReached → bool
-
final
- primaryWindow → Sub2ApiAdminOpenAIRateLimitWindow?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryWindow → Sub2ApiAdminOpenAIRateLimitWindow?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited