Sub2ApiAdminOpsAlertEvent class final
Constructors
- Sub2ApiAdminOpsAlertEvent({required int id, required int ruleId, required Sub2ApiAdminOpsAlertSeverity severity, required Sub2ApiAdminOpsAlertEventStatus status, required String title, required String description, Sub2ApiDecimal? metricValue, Sub2ApiDecimal? thresholdValue, required Sub2ApiAdminJsonObject dimensions, required DateTime firedAt, DateTime? resolvedAt, required bool emailSent, required DateTime createdAt})
-
const
Properties
- createdAt → DateTime
-
final
- description → String
-
final
- dimensions → Sub2ApiAdminJsonObject
-
final
- emailSent → bool
-
final
- firedAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- metricValue → Sub2ApiDecimal?
-
final
- resolvedAt → DateTime?
-
final
- ruleId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → Sub2ApiAdminOpsAlertSeverity
-
final
- status → Sub2ApiAdminOpsAlertEventStatus
-
final
- thresholdValue → Sub2ApiDecimal?
-
final
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited