Sub2ApiAdminOpsAlertEventQuery class final
Constructors
- Sub2ApiAdminOpsAlertEventQuery({int limit = 20, DateTime? beforeFiredAt, int? beforeId, Sub2ApiAdminOpsAlertEventStatus? status, Sub2ApiAdminOpsAlertSeverity? severity, bool? emailSent, Sub2ApiAdminOpsTimeRange? timeRange, DateTime? startAt, DateTime? endAt, String? platform, int? groupId})
-
const
Properties
- beforeFiredAt → DateTime?
-
final
- beforeId → int?
-
final
- emailSent → bool?
-
final
- endAt → DateTime?
-
final
- groupId → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int
-
final
- platform → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → Sub2ApiAdminOpsAlertSeverity?
-
final
- startAt → DateTime?
-
final
- status → Sub2ApiAdminOpsAlertEventStatus?
-
final
- timeRange → Sub2ApiAdminOpsTimeRange?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited