Sub2ApiAdminOpsAlertRuleInput class final
Constructors
- Sub2ApiAdminOpsAlertRuleInput({required String name, required Sub2ApiAdminOpsAlertMetricType metricType, required Sub2ApiAdminOpsAlertOperator operator, required Sub2ApiDecimal threshold, String description = '', bool enabled = true, Sub2ApiAdminOpsAlertSeverity severity = Sub2ApiAdminOpsAlertSeverity.p2, int windowMinutes = 1, int sustainedMinutes = 1, int cooldownMinutes = 0, bool notifyEmail = true, Sub2ApiAdminJsonObject filters = const Sub2ApiAdminJsonObject({})})
-
const
Properties
- cooldownMinutes → int
-
final
- description → String
-
final
- enabled → bool
-
final
- filters → Sub2ApiAdminJsonObject
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metricType → Sub2ApiAdminOpsAlertMetricType
-
final
- name → String
-
final
- notifyEmail → bool
-
final
- operator → Sub2ApiAdminOpsAlertOperator
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → Sub2ApiAdminOpsAlertSeverity
-
final
- sustainedMinutes → int
-
final
- threshold → Sub2ApiDecimal
-
final
- windowMinutes → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited