Sub2ApiAdminOpsAlertSilencingSettings class final

Constructors

Sub2ApiAdminOpsAlertSilencingSettings({required bool enabled, DateTime? globalUntil, String globalReason = '', List<Sub2ApiAdminOpsAlertSilenceEntry> entries = const <Sub2ApiAdminOpsAlertSilenceEntry>[]})

Properties

enabled → bool
final
entries → List<Sub2ApiAdminOpsAlertSilenceEntry>
final
globalReason → String
final
globalUntil → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited