Sub2ApiAdminOpsConcurrencySnapshot class final
Constructors
-
Sub2ApiAdminOpsConcurrencySnapshot({required bool enabled, required Map<
String, Sub2ApiAdminOpsPlatformConcurrency> platforms, required Map<int, Sub2ApiAdminOpsGroupConcurrency> groups, required Map<int, Sub2ApiAdminOpsAccountConcurrency> accounts, required DateTime timestamp})
Properties
-
accounts
→ Map<
int, Sub2ApiAdminOpsAccountConcurrency> -
final
- enabled → bool
-
final
-
groups
→ Map<
int, Sub2ApiAdminOpsGroupConcurrency> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
platforms
→ Map<
String, Sub2ApiAdminOpsPlatformConcurrency> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited