Sub2ApiAdminOpsDashboardQuery class final

Constructors

Sub2ApiAdminOpsDashboardQuery({Sub2ApiAdminOpsTimeRange timeRange = Sub2ApiAdminOpsTimeRange.oneHour, DateTime? startAt, DateTime? endAt, String? platform, int? groupId, Sub2ApiAdminOpsQueryMode queryMode = Sub2ApiAdminOpsQueryMode.serverDefault})
const

Properties

endAt → DateTime?
final
groupId → int?
final
hashCode → int
The hash code for this object.
no setterinherited
platform → String?
final
queryMode → Sub2ApiAdminOpsQueryMode
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startAt → DateTime?
final
timeRange → Sub2ApiAdminOpsTimeRange
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited