Sub2ApiAdminOpsEmailAlertConfig class final
Constructors
-
Sub2ApiAdminOpsEmailAlertConfig({required bool enabled, List<
String> recipients = const <String>[], Sub2ApiAdminOpsEmailAlertMinSeverity? minSeverity, required int rateLimitPerHour, required int batchingWindowSeconds, required bool includeResolvedAlerts})
Properties
- batchingWindowSeconds → int
-
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeResolvedAlerts → bool
-
final
- minSeverity → Sub2ApiAdminOpsEmailAlertMinSeverity?
-
final
- rateLimitPerHour → int
-
final
-
recipients
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited