Sub2ApiAdminOpsEmailReportConfig class final
Constructors
-
Sub2ApiAdminOpsEmailReportConfig({required bool enabled, List<
String> recipients = const <String>[], required bool dailySummaryEnabled, required String dailySummarySchedule, required bool weeklySummaryEnabled, required String weeklySummarySchedule, required bool errorDigestEnabled, required String errorDigestSchedule, required int errorDigestMinCount, required bool accountHealthEnabled, required String accountHealthSchedule, required Sub2ApiDecimal accountHealthErrorRateThreshold})
Properties
- accountHealthEnabled → bool
-
final
- accountHealthErrorRateThreshold → Sub2ApiDecimal
-
final
- accountHealthSchedule → String
-
final
- dailySummaryEnabled → bool
-
final
- dailySummarySchedule → String
-
final
- enabled → bool
-
final
- errorDigestEnabled → bool
-
final
- errorDigestMinCount → int
-
final
- errorDigestSchedule → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
recipients
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- weeklySummaryEnabled → bool
-
final
- weeklySummarySchedule → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited