Sub2ApiAdminOpsIngressRejectQuery class final
Constructors
- Sub2ApiAdminOpsIngressRejectQuery({int page = 1, int pageSize = 20, Sub2ApiAdminOpsTimeRange timeRange = Sub2ApiAdminOpsTimeRange.oneHour, DateTime? startAt, DateTime? endAt, Sub2ApiAdminOpsIngressRejectReason? reason, Sub2ApiAdminOpsIngressRouteFamily? routeFamily, Sub2ApiAdminOpsIngressProtocol? protocol, String? clientAddress, int? userId, int? apiKeyId})
-
const
Properties
- apiKeyId → int?
-
final
- clientAddress → String?
-
final
- endAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- page → int
-
final
- pageSize → int
-
final
- protocol → Sub2ApiAdminOpsIngressProtocol?
-
final
- reason → Sub2ApiAdminOpsIngressRejectReason?
-
final
- routeFamily → Sub2ApiAdminOpsIngressRouteFamily?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startAt → DateTime?
-
final
- timeRange → Sub2ApiAdminOpsTimeRange
-
final
- userId → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited