Sub2ApiAdminOpsLatencyHistogram class final
Constructors
-
Sub2ApiAdminOpsLatencyHistogram({required DateTime startAt, required DateTime endAt, required String platform, int? groupId, required int totalRequests, required List<
Sub2ApiAdminOpsLatencyBucket> buckets})
Properties
-
buckets
→ List<
Sub2ApiAdminOpsLatencyBucket> -
final
- endAt → DateTime
-
final
- groupId → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- platform → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startAt → DateTime
-
final
- totalRequests → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited