Sub2ApiAdminOpsRealtimeTraffic class final
Constructors
- Sub2ApiAdminOpsRealtimeTraffic({required bool enabled, required String window, required DateTime startAt, required DateTime endAt, required String platform, int? groupId, required Sub2ApiAdminOpsRateSummary qps, required Sub2ApiAdminOpsRateSummary tps, required DateTime timestamp})
-
const
Properties
- enabled → bool
-
final
- endAt → DateTime
-
final
- groupId → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- platform → String
-
final
- qps → Sub2ApiAdminOpsRateSummary
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startAt → DateTime
-
final
- timestamp → DateTime
-
final
- tps → Sub2ApiAdminOpsRateSummary
-
final
- window → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited