Sub2ApiAdminOpsSettingsClient class abstract interface

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAdvanced({Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminOpsAdvancedSettings>
getAlertRuntime({Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminOpsAlertRuntimeSettings>
getEmailNotification({Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminOpsEmailNotificationConfig>
getMetricThresholds({Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminOpsMetricThresholds>
getRuntimeLogging({Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminOpsRuntimeLogConfig>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetRuntimeLogging({Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminOpsRuntimeLogConfig>
toString() → String
A string representation of this object.
inherited
updateAdvanced(Sub2ApiAdminOpsAdvancedSettings settings, {Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminOpsAdvancedSettings>
updateAlertRuntime(Sub2ApiAdminOpsAlertRuntimeSettings settings, {Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminOpsAlertRuntimeSettings>
updateEmailNotification(Sub2ApiAdminOpsEmailNotificationUpdate update, {Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminOpsEmailNotificationConfig>
updateMetricThresholds(Sub2ApiAdminOpsMetricThresholds thresholds, {Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminOpsMetricThresholds>
updateRuntimeLogging(Sub2ApiAdminOpsRuntimeLogInput input, {Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminOpsRuntimeLogConfig>

Operators

operator ==(Object other) → bool
The equality operator.
inherited