Sub2ApiAdminOpsSystemLogQuery class final
Constructors
- Sub2ApiAdminOpsSystemLogQuery({int page = 1, int pageSize = 20, Sub2ApiAdminOpsTimeRange timeRange = Sub2ApiAdminOpsTimeRange.oneHour, Sub2ApiAdminOpsSystemLogFilter filter = const Sub2ApiAdminOpsSystemLogFilter()})
-
const
Properties
- filter → Sub2ApiAdminOpsSystemLogFilter
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- page → int
-
final
- pageSize → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeRange → Sub2ApiAdminOpsTimeRange
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited