Sub2ApiAdminPaymentAuditLog class final
Constructors
- Sub2ApiAdminPaymentAuditLog({required int id, required String orderId, required String action, required Sub2ApiAdminPaymentAuditDetail detail, required String operatorName, required DateTime createdAt})
-
const
Properties
- action → String
-
final
- createdAt → DateTime
-
final
- detail → Sub2ApiAdminPaymentAuditDetail
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- operatorName → String
-
final
- orderId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited