Sub2ApiAdminPreviewEmailTemplateRequest class final

Constructors

Sub2ApiAdminPreviewEmailTemplateRequest({required String event, required String locale, required String subject, required Sub2ApiAdminEmailTemplateContent html, Map<String, String> variables = const <String, String>{}})

Properties

event → String
final
hashCode → int
The hash code for this object.
no setterinherited
html → Sub2ApiAdminEmailTemplateContent
final
locale → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String
final
variables → Map<String, String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited