Sub2ApiAdminPromoCodeUsage class final

Constructors

Sub2ApiAdminPromoCodeUsage({required int id, required int promoCodeId, required int userId, required Sub2ApiDecimal bonusAmount, required DateTime usedAt, required Sub2ApiAdminPromoCodeUsageUser? user})
const

Properties

bonusAmount → Sub2ApiDecimal
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
promoCodeId → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usedAt → DateTime
final
user → Sub2ApiAdminPromoCodeUsageUser?
final
userId → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited