Sub2ApiAdminProxyAccountSummary class final

Constructors

Sub2ApiAdminProxyAccountSummary({required int id, required String name, required Sub2ApiAdminAccountPlatform platform, required Sub2ApiAdminAccountType type, required String? notes})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
final
name → String
final
notes → String?
final
platform → Sub2ApiAdminAccountPlatform
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Sub2ApiAdminAccountType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited