Sub2ApiAdminProxyDataExport class final
Constructors
- Sub2ApiAdminProxyDataExport({required DateTime exportedAt, required int proxyCount, required Sub2ApiAdminProxyDataArchive archive})
-
const
Properties
- archive → Sub2ApiAdminProxyDataArchive
-
final
- exportedAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- proxyCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited