Sub2ApiAdminProxyQualityItem class final
Constructors
- Sub2ApiAdminProxyQualityItem({required String target, required Sub2ApiAdminProxyQualityItemStatus status, required int? httpStatus, required int? latencyMs, required String message, required String cfRay})
-
const
Properties
- cfRay → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpStatus → int?
-
final
- latencyMs → int?
-
final
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → Sub2ApiAdminProxyQualityItemStatus
-
final
- target → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited