Sub2ApiAdminProxyStats class final
Constructors
- Sub2ApiAdminProxyStats({required int totalAccounts, required int activeAccounts, required int totalRequests, required Sub2ApiDecimal successRate, required Sub2ApiDecimal averageLatency})
-
const
Properties
- activeAccounts → int
-
final
- averageLatency → Sub2ApiDecimal
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- successRate → Sub2ApiDecimal
-
final
- totalAccounts → int
-
final
- totalRequests → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited