Sub2ApiAdminProxyTestResult class final
Constructors
Properties
- city → String
-
final
- country → String
-
final
- countryCode → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ipAddress → String
-
final
- latencyMs → int?
-
final
- message → String
-
final
- region → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited