Sub2ApiAdminRiskControlLogQuery class final
Constructors
- Sub2ApiAdminRiskControlLogQuery({int page = 1, int pageSize = 20, Sub2ApiAdminRiskControlAction? result, int? groupId, String? endpoint, String? search, DateTime? from, DateTime? to})
-
const
Properties
- endpoint → String?
-
final
- from → DateTime?
-
final
- groupId → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- page → int
-
final
- pageSize → int
-
final
- result → Sub2ApiAdminRiskControlAction?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- search → String?
-
final
- to → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited