Sub2ApiAdminSystemUpdateInfo class final
Constructors
- Sub2ApiAdminSystemUpdateInfo({required String currentVersion, required String latestVersion, required bool hasUpdate, required Sub2ApiAdminSystemReleaseInfo? releaseInfo, required bool cached, required String warning, required Sub2ApiAdminSystemBuildType buildType})
-
const
Properties
- buildType → Sub2ApiAdminSystemBuildType
-
final
- cached → bool
-
final
- currentVersion → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasUpdate → bool
-
final
- latestVersion → String
-
final
- releaseInfo → Sub2ApiAdminSystemReleaseInfo?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- warning → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited