Sub2ApiAdminUpdateMonitorV2ConfigRequest class final
Constructors
-
Sub2ApiAdminUpdateMonitorV2ConfigRequest({required int version, required bool enabled, required int refreshIntervalSeconds, required List<
Sub2ApiMonitorPlatformConfig> platforms, required List<int> groupIds, required Sub2ApiMonitorThresholds healthThresholds, required List<Sub2ApiAdminMonitorV2ErrorCategory> ignoredErrorCategories})
Properties
- enabled → bool
-
final
-
groupIds
→ List<
int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- healthThresholds → Sub2ApiMonitorThresholds
-
final
-
ignoredErrorCategories
→ List<
Sub2ApiAdminMonitorV2ErrorCategory> -
final
-
platforms
→ List<
Sub2ApiMonitorPlatformConfig> -
final
- refreshIntervalSeconds → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited