Sub2ApiAdminUpdateScheduledTestPlanRequest class final
Constructors
Properties
- autoRecover → bool?
-
final
- cronExpression → String?
-
final
- enabled → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxResults → int?
-
final
- modelId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited