Sub2ApiAdminUpdateTLSFingerprintProfileRequest class final

Constructors

Sub2ApiAdminUpdateTLSFingerprintProfileRequest({String? name, String? description, bool? enableGrease, List<int>? cipherSuites, List<int>? curves, List<int>? pointFormats, List<int>? signatureAlgorithms, List<String>? alpnProtocols, List<int>? supportedVersions, List<int>? keyShareGroups, List<int>? pskModes, List<int>? extensions})

Properties

alpnProtocols → List<String>?
final
cipherSuites → List<int>?
final
curves → List<int>?
final
description → String?
final
enableGrease → bool?
final
extensions → List<int>?
final
hashCode → int
The hash code for this object.
no setterinherited
keyShareGroups → List<int>?
final
name → String?
final
pointFormats → List<int>?
final
pskModes → List<int>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signatureAlgorithms → List<int>?
final
supportedVersions → List<int>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited