Sub2ApiAdminUpstreamBillingProbeData class final

Constructors

Sub2ApiAdminUpstreamBillingProbeData({required String object, required int schemaVersion, required String billingScope, required DateTime observedAt, Sub2ApiDecimal? groupRateMultiplier, Sub2ApiDecimal? userRateMultiplier, Sub2ApiDecimal? resolvedRateMultiplier, bool? peakRateEnabled, String? peakStart, String? peakEnd, Sub2ApiDecimal? peakRateMultiplier, Sub2ApiDecimal? appliedPeakMultiplier, Sub2ApiDecimal? effectiveRateMultiplier, String? timezone})
const

Properties

appliedPeakMultiplier → Sub2ApiDecimal?
final
billingScope → String
final
effectiveRateMultiplier → Sub2ApiDecimal?
final
groupRateMultiplier → Sub2ApiDecimal?
final
hashCode → int
The hash code for this object.
no setterinherited
object → String
final
observedAt → DateTime
final
peakEnd → String?
final
peakRateEnabled → bool?
final
peakRateMultiplier → Sub2ApiDecimal?
final
peakStart → String?
final
resolvedRateMultiplier → Sub2ApiDecimal?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaVersion → int
final
timezone → String?
final
userRateMultiplier → Sub2ApiDecimal?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited