Sub2ApiAdminUpstreamBillingProbeSnapshot class final
Constructors
- Sub2ApiAdminUpstreamBillingProbeSnapshot({required String status, required DateTime lastAttemptAt, required DateTime nextProbeAt, required int failureCount, required int httpStatus, required String lastError, Sub2ApiAdminUpstreamBillingProbeData? data, DateTime? receivedAt, DateTime? freshUntil, Sub2ApiDecimal? syncedRateMultiplier})
-
const
Properties
- data → Sub2ApiAdminUpstreamBillingProbeData?
-
final
- failureCount → int
-
final
- freshUntil → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpStatus → int
-
final
- lastAttemptAt → DateTime
-
final
- lastError → String
-
final
- nextProbeAt → DateTime
-
final
- receivedAt → DateTime?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
final
- syncedRateMultiplier → Sub2ApiDecimal?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited