Sub2ApiAdminUsageRecord class final
Constructors
- Sub2ApiAdminUsageRecord({required Sub2ApiUsageRecord usage, required int imageInputTokens, required Sub2ApiDecimal imageInputCost, String? sessionId, String? upstreamModel, String? upstreamResponseModel, bool? upstreamModelMismatch, int? channelId, String? modelMappingChain, String? billingTier, Sub2ApiDecimal? accountRateMultiplier, Sub2ApiDecimal? accountStatsCost, Sub2ApiAdminUsageAccountSummary? account})
-
const
Properties
- account → Sub2ApiAdminUsageAccountSummary?
-
final
- accountRateMultiplier → Sub2ApiDecimal?
-
final
- accountStatsCost → Sub2ApiDecimal?
-
final
- billingTier → String?
-
final
- channelId → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageInputCost → Sub2ApiDecimal
-
final
- imageInputTokens → int
-
final
- modelMappingChain → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String?
-
final
- upstreamModel → String?
-
final
- upstreamModelMismatch → bool?
-
final
- upstreamResponseModel → String?
-
final
- usage → Sub2ApiUsageRecord
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited