Sub2ApiAdminUsageStats class final

Constructors

Sub2ApiAdminUsageStats({required Sub2ApiUsageStats usage, required List<Sub2ApiAdminUsageEndpointStat> endpoints, required List<Sub2ApiAdminUsageEndpointStat> upstreamEndpoints, required List<Sub2ApiAdminUsageEndpointStat> endpointPaths, Sub2ApiDecimal? totalAccountCost})

Properties

endpointPaths → List<Sub2ApiAdminUsageEndpointStat>
final
endpoints → List<Sub2ApiAdminUsageEndpointStat>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalAccountCost → Sub2ApiDecimal?
final
upstreamEndpoints → List<Sub2ApiAdminUsageEndpointStat>
final
usage → Sub2ApiUsageStats
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited