Sub2ApiAdminUsageStatsQuery class final
Constructors
- Sub2ApiAdminUsageStatsQuery({int? userId, int? apiKeyId, int? accountId, int? groupId, String? model, Sub2ApiAdminUsageRequestType? requestType, bool? stream, Sub2ApiAdminBillingType? billingType, String? billingMode, bool? upstreamModelMismatch, DateTime? startDate, DateTime? endDate, Sub2ApiAdminUsageStatsPeriod period = Sub2ApiAdminUsageStatsPeriod.today, String? timezone, bool bypassCache = false})
-
const
Properties
- accountId → int?
-
final
- apiKeyId → int?
-
final
- billingMode → String?
-
final
- billingType → Sub2ApiAdminBillingType?
-
final
- bypassCache → bool
-
final
- endDate → DateTime?
-
final
- groupId → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- model → String?
-
final
- period → Sub2ApiAdminUsageStatsPeriod
-
final
- requestType → Sub2ApiAdminUsageRequestType?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate → DateTime?
-
final
- stream → bool?
-
final
- timezone → String?
-
final
- upstreamModelMismatch → bool?
-
final
- userId → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited