Sub2ApiAdminUserAttributeDefinition class final
Constructors
-
Sub2ApiAdminUserAttributeDefinition({required int id, required String key, required String name, required String description, required Sub2ApiAdminUserAttributeType type, required List<
Sub2ApiAdminUserAttributeOption> options, required bool required, required Sub2ApiAdminUserAttributeValidation validation, required String placeholder, required int displayOrder, required bool enabled, required DateTime createdAt, required DateTime updatedAt})
Properties
- createdAt → DateTime
-
final
- description → String
-
final
- displayOrder → int
-
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- key → String
-
final
- name → String
-
final
-
options
→ List<
Sub2ApiAdminUserAttributeOption> -
final
- placeholder → String
-
final
- required → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Sub2ApiAdminUserAttributeType
-
final
- updatedAt → DateTime
-
final
- validation → Sub2ApiAdminUserAttributeValidation
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited