Sub2ApiAdminUserAttributeSnapshot class final
Constructors
-
Sub2ApiAdminUserAttributeSnapshot({required int userId, required List<
Sub2ApiAdminUserAttributeSnapshotValue> values})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
final
-
values
→ List<
Sub2ApiAdminUserAttributeSnapshotValue> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited