Sub2ApiAdminUserAttributeValue class abstract

One persisted custom attribute value for a user.

Available extensions
Annotations
  • @freezed

Constructors

Sub2ApiAdminUserAttributeValue({required int id, required int userId, required int attributeId, required String value, required DateTime createdAt, required DateTime updatedAt})
const
factory

Properties

attributeId → int
no setterinherited
copyWith → $Sub2ApiAdminUserAttributeValueCopyWith<Sub2ApiAdminUserAttributeValue>
Create a copy of Sub2ApiAdminUserAttributeValue with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → DateTime
no setterinherited
userId → int
no setterinherited
value → String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Sub2ApiAdminUserAttributeValue value)) → TResult

Available on Sub2ApiAdminUserAttributeValue, provided by the Sub2ApiAdminUserAttributeValuePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Sub2ApiAdminUserAttributeValue value)?) → TResult?

Available on Sub2ApiAdminUserAttributeValue, provided by the Sub2ApiAdminUserAttributeValuePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Sub2ApiAdminUserAttributeValue value)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminUserAttributeValue, provided by the Sub2ApiAdminUserAttributeValuePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int id, int userId, int attributeId, String value, DateTime createdAt, DateTime updatedAt)?, {required TResult orElse()}) → TResult

Available on Sub2ApiAdminUserAttributeValue, provided by the Sub2ApiAdminUserAttributeValuePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int id, int userId, int attributeId, String value, DateTime createdAt, DateTime updatedAt)) → TResult

Available on Sub2ApiAdminUserAttributeValue, provided by the Sub2ApiAdminUserAttributeValuePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int id, int userId, int attributeId, String value, DateTime createdAt, DateTime updatedAt)?) → TResult?

Available on Sub2ApiAdminUserAttributeValue, provided by the Sub2ApiAdminUserAttributeValuePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited