Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
Sub2ApiAdminCreateUserAttributeDefinitionRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminUserAttributeDefinition> -
delete(
int id, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminUserAttributeActionResult> -
getBatch(
List< int> userIds, {Sub2ApiRequestOptions? requestOptions}) → Future<List< Sub2ApiAdminUserAttributeSnapshot> > -
list(
{bool enabledOnly = false, Sub2ApiRequestOptions? requestOptions}) → Future< List< Sub2ApiAdminUserAttributeDefinition> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reorder(
List< int> ids, {Sub2ApiRequestOptions? requestOptions}) → Future<Sub2ApiAdminUserAttributeActionResult> -
toString(
) → String -
A string representation of this object.
inherited
-
update(
int id, Sub2ApiAdminUpdateUserAttributeDefinitionRequest request, {Sub2ApiRequestOptions? requestOptions}) → Future< Sub2ApiAdminUserAttributeDefinition>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited