Sub2ApiAdminUserListQuery class final
Query for the paginated Admin user list.
Constructors
-
Sub2ApiAdminUserListQuery({int? page, int? pageSize, Sub2ApiAdminUserStatus? status, Sub2ApiAdminUserRole? role, String? search, String? groupName, int? apiKeyGroupId, Map<
int, String> attributes = const <int, String>{}, bool? includeSubscriptions, String? sortBy, String? sortOrder}) -
const
Properties
- apiKeyGroupId → int?
-
final
-
attributes
→ Map<
int, String> -
final
- groupName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeSubscriptions → bool?
-
final
- page → int?
-
final
- pageSize → int?
-
final
- role → Sub2ApiAdminUserRole?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- search → String?
-
final
- sortBy → String?
-
final
- sortOrder → String?
-
final
- status → Sub2ApiAdminUserStatus?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited