Sub2ApiAdminWebSearchProvider class final
Constructors
- Sub2ApiAdminWebSearchProvider({required Sub2ApiAdminWebSearchProviderType type, Sub2ApiAdminCredentialSecret? apiKey, required bool apiKeyConfigured, int? quotaLimit, DateTime? subscribedAt, required int quotaUsed, int? proxyId, DateTime? expiresAt})
-
const
Properties
- apiKey → Sub2ApiAdminCredentialSecret?
-
final
- apiKeyConfigured → bool
-
final
- expiresAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- proxyId → int?
-
final
- quotaLimit → int?
-
final
- quotaUsed → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscribedAt → DateTime?
-
final
- type → Sub2ApiAdminWebSearchProviderType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited