Sub2ApiAdminWebSearchResult class final
Constructors
- Sub2ApiAdminWebSearchResult({required Uri url, required String title, required String snippet, required String pageAge})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited